/*===---- riscv_vector.h - RISC-V V-extension RVVIntrinsics -------------------===
 *
 *
 * Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 * See https://llvm.org/LICENSE.txt for license information.
 * SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 *
 *===-----------------------------------------------------------------------===
 */

#ifndef __RISCV_VECTOR_H
#define __RISCV_VECTOR_H

#include <stdint.h>
#include <stddef.h>

#ifndef __riscv_xtheadvector
#error "Vector intrinsics require either Vector extension or XTheadVector extension."
#endif

#ifdef __cplusplus
extern "C" {
#endif

#pragma clang riscv intrinsic thead_vector


// Vector Bitwise Logical Operations
#define __riscv_vand_vv_i8m1(op1_v, op2_v, vl) __riscv_th_vand_vv_i8m1(op1_v, op2_v, vl)
#define __riscv_vand_vv_i8m2(op1_v, op2_v, vl) __riscv_th_vand_vv_i8m2(op1_v, op2_v, vl)
#define __riscv_vand_vv_i8m4(op1_v, op2_v, vl) __riscv_th_vand_vv_i8m4(op1_v, op2_v, vl)
#define __riscv_vand_vv_i8m8(op1_v, op2_v, vl) __riscv_th_vand_vv_i8m8(op1_v, op2_v, vl)
#define __riscv_vand_vv_i16m1(op1_v, op2_v, vl) __riscv_th_vand_vv_i16m1(op1_v, op2_v, vl)
#define __riscv_vand_vv_i16m2(op1_v, op2_v, vl) __riscv_th_vand_vv_i16m2(op1_v, op2_v, vl)
#define __riscv_vand_vv_i16m4(op1_v, op2_v, vl) __riscv_th_vand_vv_i16m4(op1_v, op2_v, vl)
#define __riscv_vand_vv_i16m8(op1_v, op2_v, vl) __riscv_th_vand_vv_i16m8(op1_v, op2_v, vl)
#define __riscv_vand_vv_i32m1(op1_v, op2_v, vl) __riscv_th_vand_vv_i32m1(op1_v, op2_v, vl)
#define __riscv_vand_vv_i32m2(op1_v, op2_v, vl) __riscv_th_vand_vv_i32m2(op1_v, op2_v, vl)
#define __riscv_vand_vv_i32m4(op1_v, op2_v, vl) __riscv_th_vand_vv_i32m4(op1_v, op2_v, vl)
#define __riscv_vand_vv_i32m8(op1_v, op2_v, vl) __riscv_th_vand_vv_i32m8(op1_v, op2_v, vl)
#define __riscv_vand_vv_i64m1(op1_v, op2_v, vl) __riscv_th_vand_vv_i64m1(op1_v, op2_v, vl)
#define __riscv_vand_vv_i64m2(op1_v, op2_v, vl) __riscv_th_vand_vv_i64m2(op1_v, op2_v, vl)
#define __riscv_vand_vv_i64m4(op1_v, op2_v, vl) __riscv_th_vand_vv_i64m4(op1_v, op2_v, vl)
#define __riscv_vand_vv_i64m8(op1_v, op2_v, vl) __riscv_th_vand_vv_i64m8(op1_v, op2_v, vl)

#define __riscv_vand_vv_u8m1(op1_v, op2_v, vl) __riscv_th_vand_vv_u8m1(op1_v, op2_v, vl)
#define __riscv_vand_vv_u8m2(op1_v, op2_v, vl) __riscv_th_vand_vv_u8m2(op1_v, op2_v, vl)
#define __riscv_vand_vv_u8m4(op1_v, op2_v, vl) __riscv_th_vand_vv_u8m4(op1_v, op2_v, vl)
#define __riscv_vand_vv_u8m8(op1_v, op2_v, vl) __riscv_th_vand_vv_u8m8(op1_v, op2_v, vl)
#define __riscv_vand_vv_u16m1(op1_v, op2_v, vl) __riscv_th_vand_vv_u16m1(op1_v, op2_v, vl)
#define __riscv_vand_vv_u16m2(op1_v, op2_v, vl) __riscv_th_vand_vv_u16m2(op1_v, op2_v, vl)
#define __riscv_vand_vv_u16m4(op1_v, op2_v, vl) __riscv_th_vand_vv_u16m4(op1_v, op2_v, vl)
#define __riscv_vand_vv_u16m8(op1_v, op2_v, vl) __riscv_th_vand_vv_u16m8(op1_v, op2_v, vl)
#define __riscv_vand_vv_u32m1(op1_v, op2_v, vl) __riscv_th_vand_vv_u32m1(op1_v, op2_v, vl)
#define __riscv_vand_vv_u32m2(op1_v, op2_v, vl) __riscv_th_vand_vv_u32m2(op1_v, op2_v, vl)
#define __riscv_vand_vv_u32m4(op1_v, op2_v, vl) __riscv_th_vand_vv_u32m4(op1_v, op2_v, vl)
#define __riscv_vand_vv_u32m8(op1_v, op2_v, vl) __riscv_th_vand_vv_u32m8(op1_v, op2_v, vl)
#define __riscv_vand_vv_u64m1(op1_v, op2_v, vl) __riscv_th_vand_vv_u64m1(op1_v, op2_v, vl)
#define __riscv_vand_vv_u64m2(op1_v, op2_v, vl) __riscv_th_vand_vv_u64m2(op1_v, op2_v, vl)
#define __riscv_vand_vv_u64m4(op1_v, op2_v, vl) __riscv_th_vand_vv_u64m4(op1_v, op2_v, vl)
#define __riscv_vand_vv_u64m8(op1_v, op2_v, vl) __riscv_th_vand_vv_u64m8(op1_v, op2_v, vl)

#define __riscv_vand_vx_i8m1(op1_v, op2_x, vl) __riscv_th_vand_vx_i8m1(op1_v, op2_x, vl)
#define __riscv_vand_vx_i8m2(op1_v, op2_x, vl) __riscv_th_vand_vx_i8m2(op1_v, op2_x, vl)
#define __riscv_vand_vx_i8m4(op1_v, op2_x, vl) __riscv_th_vand_vx_i8m4(op1_v, op2_x, vl)
#define __riscv_vand_vx_i8m8(op1_v, op2_x, vl) __riscv_th_vand_vx_i8m8(op1_v, op2_x, vl)
#define __riscv_vand_vx_i16m1(op1_v, op2_x, vl) __riscv_th_vand_vx_i16m1(op1_v, op2_x, vl)
#define __riscv_vand_vx_i16m2(op1_v, op2_x, vl) __riscv_th_vand_vx_i16m2(op1_v, op2_x, vl)
#define __riscv_vand_vx_i16m4(op1_v, op2_x, vl) __riscv_th_vand_vx_i16m4(op1_v, op2_x, vl)
#define __riscv_vand_vx_i16m8(op1_v, op2_x, vl) __riscv_th_vand_vx_i16m8(op1_v, op2_x, vl)
#define __riscv_vand_vx_i32m1(op1_v, op2_x, vl) __riscv_th_vand_vx_i32m1(op1_v, op2_x, vl)
#define __riscv_vand_vx_i32m2(op1_v, op2_x, vl) __riscv_th_vand_vx_i32m2(op1_v, op2_x, vl)
#define __riscv_vand_vx_i32m4(op1_v, op2_x, vl) __riscv_th_vand_vx_i32m4(op1_v, op2_x, vl)
#define __riscv_vand_vx_i32m8(op1_v, op2_x, vl) __riscv_th_vand_vx_i32m8(op1_v, op2_x, vl)
#define __riscv_vand_vx_i64m1(op1_v, op2_x, vl) __riscv_th_vand_vx_i64m1(op1_v, op2_x, vl)
#define __riscv_vand_vx_i64m2(op1_v, op2_x, vl) __riscv_th_vand_vx_i64m2(op1_v, op2_x, vl)
#define __riscv_vand_vx_i64m4(op1_v, op2_x, vl) __riscv_th_vand_vx_i64m4(op1_v, op2_x, vl)
#define __riscv_vand_vx_i64m8(op1_v, op2_x, vl) __riscv_th_vand_vx_i64m8(op1_v, op2_x, vl)

#define __riscv_vand_vx_u8m1(op1_v, op2_x, vl) __riscv_th_vand_vx_u8m1(op1_v, op2_x, vl)
#define __riscv_vand_vx_u8m2(op1_v, op2_x, vl) __riscv_th_vand_vx_u8m2(op1_v, op2_x, vl)
#define __riscv_vand_vx_u8m4(op1_v, op2_x, vl) __riscv_th_vand_vx_u8m4(op1_v, op2_x, vl)
#define __riscv_vand_vx_u8m8(op1_v, op2_x, vl) __riscv_th_vand_vx_u8m8(op1_v, op2_x, vl)
#define __riscv_vand_vx_u16m1(op1_v, op2_x, vl) __riscv_th_vand_vx_u16m1(op1_v, op2_x, vl)
#define __riscv_vand_vx_u16m2(op1_v, op2_x, vl) __riscv_th_vand_vx_u16m2(op1_v, op2_x, vl)
#define __riscv_vand_vx_u16m4(op1_v, op2_x, vl) __riscv_th_vand_vx_u16m4(op1_v, op2_x, vl)
#define __riscv_vand_vx_u16m8(op1_v, op2_x, vl) __riscv_th_vand_vx_u16m8(op1_v, op2_x, vl)
#define __riscv_vand_vx_u32m1(op1_v, op2_x, vl) __riscv_th_vand_vx_u32m1(op1_v, op2_x, vl)
#define __riscv_vand_vx_u32m2(op1_v, op2_x, vl) __riscv_th_vand_vx_u32m2(op1_v, op2_x, vl)
#define __riscv_vand_vx_u32m4(op1_v, op2_x, vl) __riscv_th_vand_vx_u32m4(op1_v, op2_x, vl)
#define __riscv_vand_vx_u32m8(op1_v, op2_x, vl) __riscv_th_vand_vx_u32m8(op1_v, op2_x, vl)
#define __riscv_vand_vx_u64m1(op1_v, op2_x, vl) __riscv_th_vand_vx_u64m1(op1_v, op2_x, vl)
#define __riscv_vand_vx_u64m2(op1_v, op2_x, vl) __riscv_th_vand_vx_u64m2(op1_v, op2_x, vl)
#define __riscv_vand_vx_u64m4(op1_v, op2_x, vl) __riscv_th_vand_vx_u64m4(op1_v, op2_x, vl)
#define __riscv_vand_vx_u64m8(op1_v, op2_x, vl) __riscv_th_vand_vx_u64m8(op1_v, op2_x, vl)

#define __riscv_vor_vv_i8m1(op1_v, op2_v, vl) __riscv_th_vor_vv_i8m1(op1_v, op2_v, vl)
#define __riscv_vor_vv_i8m2(op1_v, op2_v, vl) __riscv_th_vor_vv_i8m2(op1_v, op2_v, vl)
#define __riscv_vor_vv_i8m4(op1_v, op2_v, vl) __riscv_th_vor_vv_i8m4(op1_v, op2_v, vl)
#define __riscv_vor_vv_i8m8(op1_v, op2_v, vl) __riscv_th_vor_vv_i8m8(op1_v, op2_v, vl)
#define __riscv_vor_vv_i16m1(op1_v, op2_v, vl) __riscv_th_vor_vv_i16m1(op1_v, op2_v, vl)
#define __riscv_vor_vv_i16m2(op1_v, op2_v, vl) __riscv_th_vor_vv_i16m2(op1_v, op2_v, vl)
#define __riscv_vor_vv_i16m4(op1_v, op2_v, vl) __riscv_th_vor_vv_i16m4(op1_v, op2_v, vl)
#define __riscv_vor_vv_i16m8(op1_v, op2_v, vl) __riscv_th_vor_vv_i16m8(op1_v, op2_v, vl)
#define __riscv_vor_vv_i32m1(op1_v, op2_v, vl) __riscv_th_vor_vv_i32m1(op1_v, op2_v, vl)
#define __riscv_vor_vv_i32m2(op1_v, op2_v, vl) __riscv_th_vor_vv_i32m2(op1_v, op2_v, vl)
#define __riscv_vor_vv_i32m4(op1_v, op2_v, vl) __riscv_th_vor_vv_i32m4(op1_v, op2_v, vl)
#define __riscv_vor_vv_i32m8(op1_v, op2_v, vl) __riscv_th_vor_vv_i32m8(op1_v, op2_v, vl)
#define __riscv_vor_vv_i64m1(op1_v, op2_v, vl) __riscv_th_vor_vv_i64m1(op1_v, op2_v, vl)
#define __riscv_vor_vv_i64m2(op1_v, op2_v, vl) __riscv_th_vor_vv_i64m2(op1_v, op2_v, vl)
#define __riscv_vor_vv_i64m4(op1_v, op2_v, vl) __riscv_th_vor_vv_i64m4(op1_v, op2_v, vl)
#define __riscv_vor_vv_i64m8(op1_v, op2_v, vl) __riscv_th_vor_vv_i64m8(op1_v, op2_v, vl)

#define __riscv_vor_vv_u8m1(op1_v, op2_v, vl) __riscv_th_vor_vv_u8m1(op1_v, op2_v, vl)
#define __riscv_vor_vv_u8m2(op1_v, op2_v, vl) __riscv_th_vor_vv_u8m2(op1_v, op2_v, vl)
#define __riscv_vor_vv_u8m4(op1_v, op2_v, vl) __riscv_th_vor_vv_u8m4(op1_v, op2_v, vl)
#define __riscv_vor_vv_u8m8(op1_v, op2_v, vl) __riscv_th_vor_vv_u8m8(op1_v, op2_v, vl)
#define __riscv_vor_vv_u16m1(op1_v, op2_v, vl) __riscv_th_vor_vv_u16m1(op1_v, op2_v, vl)
#define __riscv_vor_vv_u16m2(op1_v, op2_v, vl) __riscv_th_vor_vv_u16m2(op1_v, op2_v, vl)
#define __riscv_vor_vv_u16m4(op1_v, op2_v, vl) __riscv_th_vor_vv_u16m4(op1_v, op2_v, vl)
#define __riscv_vor_vv_u16m8(op1_v, op2_v, vl) __riscv_th_vor_vv_u16m8(op1_v, op2_v, vl)
#define __riscv_vor_vv_u32m1(op1_v, op2_v, vl) __riscv_th_vor_vv_u32m1(op1_v, op2_v, vl)
#define __riscv_vor_vv_u32m2(op1_v, op2_v, vl) __riscv_th_vor_vv_u32m2(op1_v, op2_v, vl)
#define __riscv_vor_vv_u32m4(op1_v, op2_v, vl) __riscv_th_vor_vv_u32m4(op1_v, op2_v, vl)
#define __riscv_vor_vv_u32m8(op1_v, op2_v, vl) __riscv_th_vor_vv_u32m8(op1_v, op2_v, vl)
#define __riscv_vor_vv_u64m1(op1_v, op2_v, vl) __riscv_th_vor_vv_u64m1(op1_v, op2_v, vl)
#define __riscv_vor_vv_u64m2(op1_v, op2_v, vl) __riscv_th_vor_vv_u64m2(op1_v, op2_v, vl)
#define __riscv_vor_vv_u64m4(op1_v, op2_v, vl) __riscv_th_vor_vv_u64m4(op1_v, op2_v, vl)
#define __riscv_vor_vv_u64m8(op1_v, op2_v, vl) __riscv_th_vor_vv_u64m8(op1_v, op2_v, vl)

#define __riscv_vor_vx_i8m1(op1_v, op2_x, vl) __riscv_th_vor_vx_i8m1(op1_v, op2_x, vl)
#define __riscv_vor_vx_i8m2(op1_v, op2_x, vl) __riscv_th_vor_vx_i8m2(op1_v, op2_x, vl)
#define __riscv_vor_vx_i8m4(op1_v, op2_x, vl) __riscv_th_vor_vx_i8m4(op1_v, op2_x, vl)
#define __riscv_vor_vx_i8m8(op1_v, op2_x, vl) __riscv_th_vor_vx_i8m8(op1_v, op2_x, vl)
#define __riscv_vor_vx_i16m1(op1_v, op2_x, vl) __riscv_th_vor_vx_i16m1(op1_v, op2_x, vl)
#define __riscv_vor_vx_i16m2(op1_v, op2_x, vl) __riscv_th_vor_vx_i16m2(op1_v, op2_x, vl)
#define __riscv_vor_vx_i16m4(op1_v, op2_x, vl) __riscv_th_vor_vx_i16m4(op1_v, op2_x, vl)
#define __riscv_vor_vx_i16m8(op1_v, op2_x, vl) __riscv_th_vor_vx_i16m8(op1_v, op2_x, vl)
#define __riscv_vor_vx_i32m1(op1_v, op2_x, vl) __riscv_th_vor_vx_i32m1(op1_v, op2_x, vl)
#define __riscv_vor_vx_i32m2(op1_v, op2_x, vl) __riscv_th_vor_vx_i32m2(op1_v, op2_x, vl)
#define __riscv_vor_vx_i32m4(op1_v, op2_x, vl) __riscv_th_vor_vx_i32m4(op1_v, op2_x, vl)
#define __riscv_vor_vx_i32m8(op1_v, op2_x, vl) __riscv_th_vor_vx_i32m8(op1_v, op2_x, vl)
#define __riscv_vor_vx_i64m1(op1_v, op2_x, vl) __riscv_th_vor_vx_i64m1(op1_v, op2_x, vl)
#define __riscv_vor_vx_i64m2(op1_v, op2_x, vl) __riscv_th_vor_vx_i64m2(op1_v, op2_x, vl)
#define __riscv_vor_vx_i64m4(op1_v, op2_x, vl) __riscv_th_vor_vx_i64m4(op1_v, op2_x, vl)
#define __riscv_vor_vx_i64m8(op1_v, op2_x, vl) __riscv_th_vor_vx_i64m8(op1_v, op2_x, vl)

#define __riscv_vor_vx_u8m1(op1_v, op2_x, vl) __riscv_th_vor_vx_u8m1(op1_v, op2_x, vl)
#define __riscv_vor_vx_u8m2(op1_v, op2_x, vl) __riscv_th_vor_vx_u8m2(op1_v, op2_x, vl)
#define __riscv_vor_vx_u8m4(op1_v, op2_x, vl) __riscv_th_vor_vx_u8m4(op1_v, op2_x, vl)
#define __riscv_vor_vx_u8m8(op1_v, op2_x, vl) __riscv_th_vor_vx_u8m8(op1_v, op2_x, vl)
#define __riscv_vor_vx_u16m1(op1_v, op2_x, vl) __riscv_th_vor_vx_u16m1(op1_v, op2_x, vl)
#define __riscv_vor_vx_u16m2(op1_v, op2_x, vl) __riscv_th_vor_vx_u16m2(op1_v, op2_x, vl)
#define __riscv_vor_vx_u16m4(op1_v, op2_x, vl) __riscv_th_vor_vx_u16m4(op1_v, op2_x, vl)
#define __riscv_vor_vx_u16m8(op1_v, op2_x, vl) __riscv_th_vor_vx_u16m8(op1_v, op2_x, vl)
#define __riscv_vor_vx_u32m1(op1_v, op2_x, vl) __riscv_th_vor_vx_u32m1(op1_v, op2_x, vl)
#define __riscv_vor_vx_u32m2(op1_v, op2_x, vl) __riscv_th_vor_vx_u32m2(op1_v, op2_x, vl)
#define __riscv_vor_vx_u32m4(op1_v, op2_x, vl) __riscv_th_vor_vx_u32m4(op1_v, op2_x, vl)
#define __riscv_vor_vx_u32m8(op1_v, op2_x, vl) __riscv_th_vor_vx_u32m8(op1_v, op2_x, vl)
#define __riscv_vor_vx_u64m1(op1_v, op2_x, vl) __riscv_th_vor_vx_u64m1(op1_v, op2_x, vl)
#define __riscv_vor_vx_u64m2(op1_v, op2_x, vl) __riscv_th_vor_vx_u64m2(op1_v, op2_x, vl)
#define __riscv_vor_vx_u64m4(op1_v, op2_x, vl) __riscv_th_vor_vx_u64m4(op1_v, op2_x, vl)
#define __riscv_vor_vx_u64m8(op1_v, op2_x, vl) __riscv_th_vor_vx_u64m8(op1_v, op2_x, vl)

#define __riscv_vxor_vv_i8m1(op1_v, op2_v, vl) __riscv_th_vxor_vv_i8m1(op1_v, op2_v, vl)
#define __riscv_vxor_vv_i8m2(op1_v, op2_v, vl) __riscv_th_vxor_vv_i8m2(op1_v, op2_v, vl)
#define __riscv_vxor_vv_i8m4(op1_v, op2_v, vl) __riscv_th_vxor_vv_i8m4(op1_v, op2_v, vl)
#define __riscv_vxor_vv_i8m8(op1_v, op2_v, vl) __riscv_th_vxor_vv_i8m8(op1_v, op2_v, vl)
#define __riscv_vxor_vv_i16m1(op1_v, op2_v, vl) __riscv_th_vxor_vv_i16m1(op1_v, op2_v, vl)
#define __riscv_vxor_vv_i16m2(op1_v, op2_v, vl) __riscv_th_vxor_vv_i16m2(op1_v, op2_v, vl)
#define __riscv_vxor_vv_i16m4(op1_v, op2_v, vl) __riscv_th_vxor_vv_i16m4(op1_v, op2_v, vl)
#define __riscv_vxor_vv_i16m8(op1_v, op2_v, vl) __riscv_th_vxor_vv_i16m8(op1_v, op2_v, vl)
#define __riscv_vxor_vv_i32m1(op1_v, op2_v, vl) __riscv_th_vxor_vv_i32m1(op1_v, op2_v, vl)
#define __riscv_vxor_vv_i32m2(op1_v, op2_v, vl) __riscv_th_vxor_vv_i32m2(op1_v, op2_v, vl)
#define __riscv_vxor_vv_i32m4(op1_v, op2_v, vl) __riscv_th_vxor_vv_i32m4(op1_v, op2_v, vl)
#define __riscv_vxor_vv_i32m8(op1_v, op2_v, vl) __riscv_th_vxor_vv_i32m8(op1_v, op2_v, vl)
#define __riscv_vxor_vv_i64m1(op1_v, op2_v, vl) __riscv_th_vxor_vv_i64m1(op1_v, op2_v, vl)
#define __riscv_vxor_vv_i64m2(op1_v, op2_v, vl) __riscv_th_vxor_vv_i64m2(op1_v, op2_v, vl)
#define __riscv_vxor_vv_i64m4(op1_v, op2_v, vl) __riscv_th_vxor_vv_i64m4(op1_v, op2_v, vl)
#define __riscv_vxor_vv_i64m8(op1_v, op2_v, vl) __riscv_th_vxor_vv_i64m8(op1_v, op2_v, vl)

#define __riscv_vxor_vv_u8m1(op1_v, op2_v, vl) __riscv_th_vxor_vv_u8m1(op1_v, op2_v, vl)
#define __riscv_vxor_vv_u8m2(op1_v, op2_v, vl) __riscv_th_vxor_vv_u8m2(op1_v, op2_v, vl)
#define __riscv_vxor_vv_u8m4(op1_v, op2_v, vl) __riscv_th_vxor_vv_u8m4(op1_v, op2_v, vl)
#define __riscv_vxor_vv_u8m8(op1_v, op2_v, vl) __riscv_th_vxor_vv_u8m8(op1_v, op2_v, vl)
#define __riscv_vxor_vv_u16m1(op1_v, op2_v, vl) __riscv_th_vxor_vv_u16m1(op1_v, op2_v, vl)
#define __riscv_vxor_vv_u16m2(op1_v, op2_v, vl) __riscv_th_vxor_vv_u16m2(op1_v, op2_v, vl)
#define __riscv_vxor_vv_u16m4(op1_v, op2_v, vl) __riscv_th_vxor_vv_u16m4(op1_v, op2_v, vl)
#define __riscv_vxor_vv_u16m8(op1_v, op2_v, vl) __riscv_th_vxor_vv_u16m8(op1_v, op2_v, vl)
#define __riscv_vxor_vv_u32m1(op1_v, op2_v, vl) __riscv_th_vxor_vv_u32m1(op1_v, op2_v, vl)
#define __riscv_vxor_vv_u32m2(op1_v, op2_v, vl) __riscv_th_vxor_vv_u32m2(op1_v, op2_v, vl)
#define __riscv_vxor_vv_u32m4(op1_v, op2_v, vl) __riscv_th_vxor_vv_u32m4(op1_v, op2_v, vl)
#define __riscv_vxor_vv_u32m8(op1_v, op2_v, vl) __riscv_th_vxor_vv_u32m8(op1_v, op2_v, vl)
#define __riscv_vxor_vv_u64m1(op1_v, op2_v, vl) __riscv_th_vxor_vv_u64m1(op1_v, op2_v, vl)
#define __riscv_vxor_vv_u64m2(op1_v, op2_v, vl) __riscv_th_vxor_vv_u64m2(op1_v, op2_v, vl)
#define __riscv_vxor_vv_u64m4(op1_v, op2_v, vl) __riscv_th_vxor_vv_u64m4(op1_v, op2_v, vl)
#define __riscv_vxor_vv_u64m8(op1_v, op2_v, vl) __riscv_th_vxor_vv_u64m8(op1_v, op2_v, vl)

#define __riscv_vxor_vx_i8m1(op1_v, op2_x, vl) __riscv_th_vxor_vx_i8m1(op1_v, op2_x, vl)
#define __riscv_vxor_vx_i8m2(op1_v, op2_x, vl) __riscv_th_vxor_vx_i8m2(op1_v, op2_x, vl)
#define __riscv_vxor_vx_i8m4(op1_v, op2_x, vl) __riscv_th_vxor_vx_i8m4(op1_v, op2_x, vl)
#define __riscv_vxor_vx_i8m8(op1_v, op2_x, vl) __riscv_th_vxor_vx_i8m8(op1_v, op2_x, vl)
#define __riscv_vxor_vx_i16m1(op1_v, op2_x, vl) __riscv_th_vxor_vx_i16m1(op1_v, op2_x, vl)
#define __riscv_vxor_vx_i16m2(op1_v, op2_x, vl) __riscv_th_vxor_vx_i16m2(op1_v, op2_x, vl)
#define __riscv_vxor_vx_i16m4(op1_v, op2_x, vl) __riscv_th_vxor_vx_i16m4(op1_v, op2_x, vl)
#define __riscv_vxor_vx_i16m8(op1_v, op2_x, vl) __riscv_th_vxor_vx_i16m8(op1_v, op2_x, vl)
#define __riscv_vxor_vx_i32m1(op1_v, op2_x, vl) __riscv_th_vxor_vx_i32m1(op1_v, op2_x, vl)
#define __riscv_vxor_vx_i32m2(op1_v, op2_x, vl) __riscv_th_vxor_vx_i32m2(op1_v, op2_x, vl)
#define __riscv_vxor_vx_i32m4(op1_v, op2_x, vl) __riscv_th_vxor_vx_i32m4(op1_v, op2_x, vl)
#define __riscv_vxor_vx_i32m8(op1_v, op2_x, vl) __riscv_th_vxor_vx_i32m8(op1_v, op2_x, vl)
#define __riscv_vxor_vx_i64m1(op1_v, op2_x, vl) __riscv_th_vxor_vx_i64m1(op1_v, op2_x, vl)
#define __riscv_vxor_vx_i64m2(op1_v, op2_x, vl) __riscv_th_vxor_vx_i64m2(op1_v, op2_x, vl)
#define __riscv_vxor_vx_i64m4(op1_v, op2_x, vl) __riscv_th_vxor_vx_i64m4(op1_v, op2_x, vl)
#define __riscv_vxor_vx_i64m8(op1_v, op2_x, vl) __riscv_th_vxor_vx_i64m8(op1_v, op2_x, vl)

#define __riscv_vxor_vx_u8m1(op1_v, op2_x, vl) __riscv_th_vxor_vx_u8m1(op1_v, op2_x, vl)
#define __riscv_vxor_vx_u8m2(op1_v, op2_x, vl) __riscv_th_vxor_vx_u8m2(op1_v, op2_x, vl)
#define __riscv_vxor_vx_u8m4(op1_v, op2_x, vl) __riscv_th_vxor_vx_u8m4(op1_v, op2_x, vl)
#define __riscv_vxor_vx_u8m8(op1_v, op2_x, vl) __riscv_th_vxor_vx_u8m8(op1_v, op2_x, vl)
#define __riscv_vxor_vx_u16m1(op1_v, op2_x, vl) __riscv_th_vxor_vx_u16m1(op1_v, op2_x, vl)
#define __riscv_vxor_vx_u16m2(op1_v, op2_x, vl) __riscv_th_vxor_vx_u16m2(op1_v, op2_x, vl)
#define __riscv_vxor_vx_u16m4(op1_v, op2_x, vl) __riscv_th_vxor_vx_u16m4(op1_v, op2_x, vl)
#define __riscv_vxor_vx_u16m8(op1_v, op2_x, vl) __riscv_th_vxor_vx_u16m8(op1_v, op2_x, vl)
#define __riscv_vxor_vx_u32m1(op1_v, op2_x, vl) __riscv_th_vxor_vx_u32m1(op1_v, op2_x, vl)
#define __riscv_vxor_vx_u32m2(op1_v, op2_x, vl) __riscv_th_vxor_vx_u32m2(op1_v, op2_x, vl)
#define __riscv_vxor_vx_u32m4(op1_v, op2_x, vl) __riscv_th_vxor_vx_u32m4(op1_v, op2_x, vl)
#define __riscv_vxor_vx_u32m8(op1_v, op2_x, vl) __riscv_th_vxor_vx_u32m8(op1_v, op2_x, vl)
#define __riscv_vxor_vx_u64m1(op1_v, op2_x, vl) __riscv_th_vxor_vx_u64m1(op1_v, op2_x, vl)
#define __riscv_vxor_vx_u64m2(op1_v, op2_x, vl) __riscv_th_vxor_vx_u64m2(op1_v, op2_x, vl)
#define __riscv_vxor_vx_u64m4(op1_v, op2_x, vl) __riscv_th_vxor_vx_u64m4(op1_v, op2_x, vl)
#define __riscv_vxor_vx_u64m8(op1_v, op2_x, vl) __riscv_th_vxor_vx_u64m8(op1_v, op2_x, vl)

#define __riscv_vnot_v_i8m1(op1_v, vl) __riscv_th_vnot_v_i8m1(op1_v, vl)
#define __riscv_vnot_v_i8m2(op1_v, vl) __riscv_th_vnot_v_i8m2(op1_v, vl)
#define __riscv_vnot_v_i8m4(op1_v, vl) __riscv_th_vnot_v_i8m4(op1_v, vl)
#define __riscv_vnot_v_i8m8(op1_v, vl) __riscv_th_vnot_v_i8m8(op1_v, vl)
#define __riscv_vnot_v_i16m1(op1_v, vl) __riscv_th_vnot_v_i16m1(op1_v, vl)
#define __riscv_vnot_v_i16m2(op1_v, vl) __riscv_th_vnot_v_i16m2(op1_v, vl)
#define __riscv_vnot_v_i16m4(op1_v, vl) __riscv_th_vnot_v_i16m4(op1_v, vl)
#define __riscv_vnot_v_i16m8(op1_v, vl) __riscv_th_vnot_v_i16m8(op1_v, vl)
#define __riscv_vnot_v_i32m1(op1_v, vl) __riscv_th_vnot_v_i32m1(op1_v, vl)
#define __riscv_vnot_v_i32m2(op1_v, vl) __riscv_th_vnot_v_i32m2(op1_v, vl)
#define __riscv_vnot_v_i32m4(op1_v, vl) __riscv_th_vnot_v_i32m4(op1_v, vl)
#define __riscv_vnot_v_i32m8(op1_v, vl) __riscv_th_vnot_v_i32m8(op1_v, vl)
#define __riscv_vnot_v_i64m1(op1_v, vl) __riscv_th_vnot_v_i64m1(op1_v, vl)
#define __riscv_vnot_v_i64m2(op1_v, vl) __riscv_th_vnot_v_i64m2(op1_v, vl)
#define __riscv_vnot_v_i64m4(op1_v, vl) __riscv_th_vnot_v_i64m4(op1_v, vl)
#define __riscv_vnot_v_i64m8(op1_v, vl) __riscv_th_vnot_v_i64m8(op1_v, vl)

#define __riscv_vnot_v_u8m1(op1_v, vl) __riscv_th_vnot_v_u8m1(op1_v, vl)
#define __riscv_vnot_v_u8m2(op1_v, vl) __riscv_th_vnot_v_u8m2(op1_v, vl)
#define __riscv_vnot_v_u8m4(op1_v, vl) __riscv_th_vnot_v_u8m4(op1_v, vl)
#define __riscv_vnot_v_u8m8(op1_v, vl) __riscv_th_vnot_v_u8m8(op1_v, vl)
#define __riscv_vnot_v_u16m1(op1_v, vl) __riscv_th_vnot_v_u16m1(op1_v, vl)
#define __riscv_vnot_v_u16m2(op1_v, vl) __riscv_th_vnot_v_u16m2(op1_v, vl)
#define __riscv_vnot_v_u16m4(op1_v, vl) __riscv_th_vnot_v_u16m4(op1_v, vl)
#define __riscv_vnot_v_u16m8(op1_v, vl) __riscv_th_vnot_v_u16m8(op1_v, vl)
#define __riscv_vnot_v_u32m1(op1_v, vl) __riscv_th_vnot_v_u32m1(op1_v, vl)
#define __riscv_vnot_v_u32m2(op1_v, vl) __riscv_th_vnot_v_u32m2(op1_v, vl)
#define __riscv_vnot_v_u32m4(op1_v, vl) __riscv_th_vnot_v_u32m4(op1_v, vl)
#define __riscv_vnot_v_u32m8(op1_v, vl) __riscv_th_vnot_v_u32m8(op1_v, vl)
#define __riscv_vnot_v_u64m1(op1_v, vl) __riscv_th_vnot_v_u64m1(op1_v, vl)
#define __riscv_vnot_v_u64m2(op1_v, vl) __riscv_th_vnot_v_u64m2(op1_v, vl)
#define __riscv_vnot_v_u64m4(op1_v, vl) __riscv_th_vnot_v_u64m4(op1_v, vl)
#define __riscv_vnot_v_u64m8(op1_v, vl) __riscv_th_vnot_v_u64m8(op1_v, vl)


// Vector Indexed Load/Store Operations
#define __riscv_vlxb_v_i8m1(src_ptr, indexed, vl) __riscv_th_vlxb_v_i8m1(src_ptr, indexed, vl)
#define __riscv_vlxb_v_i8m2(src_ptr, indexed, vl) __riscv_th_vlxb_v_i8m2(src_ptr, indexed, vl)
#define __riscv_vlxb_v_i8m4(src_ptr, indexed, vl) __riscv_th_vlxb_v_i8m4(src_ptr, indexed, vl)
#define __riscv_vlxb_v_i8m8(src_ptr, indexed, vl) __riscv_th_vlxb_v_i8m8(src_ptr, indexed, vl)
#define __riscv_vlxb_v_i16m1(src_ptr, indexed, vl) __riscv_th_vlxb_v_i16m1(src_ptr, indexed, vl)
#define __riscv_vlxb_v_i16m2(src_ptr, indexed, vl) __riscv_th_vlxb_v_i16m2(src_ptr, indexed, vl)
#define __riscv_vlxb_v_i16m4(src_ptr, indexed, vl) __riscv_th_vlxb_v_i16m4(src_ptr, indexed, vl)
#define __riscv_vlxb_v_i16m8(src_ptr, indexed, vl) __riscv_th_vlxb_v_i16m8(src_ptr, indexed, vl)
#define __riscv_vlxb_v_i32m1(src_ptr, indexed, vl) __riscv_th_vlxb_v_i32m1(src_ptr, indexed, vl)
#define __riscv_vlxb_v_i32m2(src_ptr, indexed, vl) __riscv_th_vlxb_v_i32m2(src_ptr, indexed, vl)
#define __riscv_vlxb_v_i32m4(src_ptr, indexed, vl) __riscv_th_vlxb_v_i32m4(src_ptr, indexed, vl)
#define __riscv_vlxb_v_i32m8(src_ptr, indexed, vl) __riscv_th_vlxb_v_i32m8(src_ptr, indexed, vl)
#define __riscv_vlxb_v_i64m1(src_ptr, indexed, vl) __riscv_th_vlxb_v_i64m1(src_ptr, indexed, vl)
#define __riscv_vlxb_v_i64m2(src_ptr, indexed, vl) __riscv_th_vlxb_v_i64m2(src_ptr, indexed, vl)
#define __riscv_vlxb_v_i64m4(src_ptr, indexed, vl) __riscv_th_vlxb_v_i64m4(src_ptr, indexed, vl)
#define __riscv_vlxb_v_i64m8(src_ptr, indexed, vl) __riscv_th_vlxb_v_i64m8(src_ptr, indexed, vl)
#define __riscv_vlxh_v_i8m1(src_ptr, indexed, vl) __riscv_th_vlxh_v_i8m1(src_ptr, indexed, vl)
#define __riscv_vlxh_v_i8m2(src_ptr, indexed, vl) __riscv_th_vlxh_v_i8m2(src_ptr, indexed, vl)
#define __riscv_vlxh_v_i8m4(src_ptr, indexed, vl) __riscv_th_vlxh_v_i8m4(src_ptr, indexed, vl)
#define __riscv_vlxh_v_i8m8(src_ptr, indexed, vl) __riscv_th_vlxh_v_i8m8(src_ptr, indexed, vl)
#define __riscv_vlxh_v_i16m1(src_ptr, indexed, vl) __riscv_th_vlxh_v_i16m1(src_ptr, indexed, vl)
#define __riscv_vlxh_v_i16m2(src_ptr, indexed, vl) __riscv_th_vlxh_v_i16m2(src_ptr, indexed, vl)
#define __riscv_vlxh_v_i16m4(src_ptr, indexed, vl) __riscv_th_vlxh_v_i16m4(src_ptr, indexed, vl)
#define __riscv_vlxh_v_i16m8(src_ptr, indexed, vl) __riscv_th_vlxh_v_i16m8(src_ptr, indexed, vl)
#define __riscv_vlxh_v_i32m1(src_ptr, indexed, vl) __riscv_th_vlxh_v_i32m1(src_ptr, indexed, vl)
#define __riscv_vlxh_v_i32m2(src_ptr, indexed, vl) __riscv_th_vlxh_v_i32m2(src_ptr, indexed, vl)
#define __riscv_vlxh_v_i32m4(src_ptr, indexed, vl) __riscv_th_vlxh_v_i32m4(src_ptr, indexed, vl)
#define __riscv_vlxh_v_i32m8(src_ptr, indexed, vl) __riscv_th_vlxh_v_i32m8(src_ptr, indexed, vl)
#define __riscv_vlxh_v_i64m1(src_ptr, indexed, vl) __riscv_th_vlxh_v_i64m1(src_ptr, indexed, vl)
#define __riscv_vlxh_v_i64m2(src_ptr, indexed, vl) __riscv_th_vlxh_v_i64m2(src_ptr, indexed, vl)
#define __riscv_vlxh_v_i64m4(src_ptr, indexed, vl) __riscv_th_vlxh_v_i64m4(src_ptr, indexed, vl)
#define __riscv_vlxh_v_i64m8(src_ptr, indexed, vl) __riscv_th_vlxh_v_i64m8(src_ptr, indexed, vl)
#define __riscv_vlxw_v_i8m1(src_ptr, indexed, vl) __riscv_th_vlxw_v_i8m1(src_ptr, indexed, vl)
#define __riscv_vlxw_v_i8m2(src_ptr, indexed, vl) __riscv_th_vlxw_v_i8m2(src_ptr, indexed, vl)
#define __riscv_vlxw_v_i8m4(src_ptr, indexed, vl) __riscv_th_vlxw_v_i8m4(src_ptr, indexed, vl)
#define __riscv_vlxw_v_i8m8(src_ptr, indexed, vl) __riscv_th_vlxw_v_i8m8(src_ptr, indexed, vl)
#define __riscv_vlxw_v_i16m1(src_ptr, indexed, vl) __riscv_th_vlxw_v_i16m1(src_ptr, indexed, vl)
#define __riscv_vlxw_v_i16m2(src_ptr, indexed, vl) __riscv_th_vlxw_v_i16m2(src_ptr, indexed, vl)
#define __riscv_vlxw_v_i16m4(src_ptr, indexed, vl) __riscv_th_vlxw_v_i16m4(src_ptr, indexed, vl)
#define __riscv_vlxw_v_i16m8(src_ptr, indexed, vl) __riscv_th_vlxw_v_i16m8(src_ptr, indexed, vl)
#define __riscv_vlxw_v_i32m1(src_ptr, indexed, vl) __riscv_th_vlxw_v_i32m1(src_ptr, indexed, vl)
#define __riscv_vlxw_v_i32m2(src_ptr, indexed, vl) __riscv_th_vlxw_v_i32m2(src_ptr, indexed, vl)
#define __riscv_vlxw_v_i32m4(src_ptr, indexed, vl) __riscv_th_vlxw_v_i32m4(src_ptr, indexed, vl)
#define __riscv_vlxw_v_i32m8(src_ptr, indexed, vl) __riscv_th_vlxw_v_i32m8(src_ptr, indexed, vl)
#define __riscv_vlxw_v_i64m1(src_ptr, indexed, vl) __riscv_th_vlxw_v_i64m1(src_ptr, indexed, vl)
#define __riscv_vlxw_v_i64m2(src_ptr, indexed, vl) __riscv_th_vlxw_v_i64m2(src_ptr, indexed, vl)
#define __riscv_vlxw_v_i64m4(src_ptr, indexed, vl) __riscv_th_vlxw_v_i64m4(src_ptr, indexed, vl)
#define __riscv_vlxw_v_i64m8(src_ptr, indexed, vl) __riscv_th_vlxw_v_i64m8(src_ptr, indexed, vl)
#define __riscv_vlxbu_v_u8m1(src_ptr, indexed, vl) __riscv_th_vlxbu_v_u8m1(src_ptr, indexed, vl)
#define __riscv_vlxbu_v_u8m2(src_ptr, indexed, vl) __riscv_th_vlxbu_v_u8m2(src_ptr, indexed, vl)
#define __riscv_vlxbu_v_u8m4(src_ptr, indexed, vl) __riscv_th_vlxbu_v_u8m4(src_ptr, indexed, vl)
#define __riscv_vlxbu_v_u8m8(src_ptr, indexed, vl) __riscv_th_vlxbu_v_u8m8(src_ptr, indexed, vl)
#define __riscv_vlxbu_v_u16m1(src_ptr, indexed, vl) __riscv_th_vlxbu_v_u16m1(src_ptr, indexed, vl)
#define __riscv_vlxbu_v_u16m2(src_ptr, indexed, vl) __riscv_th_vlxbu_v_u16m2(src_ptr, indexed, vl)
#define __riscv_vlxbu_v_u16m4(src_ptr, indexed, vl) __riscv_th_vlxbu_v_u16m4(src_ptr, indexed, vl)
#define __riscv_vlxbu_v_u16m8(src_ptr, indexed, vl) __riscv_th_vlxbu_v_u16m8(src_ptr, indexed, vl)
#define __riscv_vlxbu_v_u32m1(src_ptr, indexed, vl) __riscv_th_vlxbu_v_u32m1(src_ptr, indexed, vl)
#define __riscv_vlxbu_v_u32m2(src_ptr, indexed, vl) __riscv_th_vlxbu_v_u32m2(src_ptr, indexed, vl)
#define __riscv_vlxbu_v_u32m4(src_ptr, indexed, vl) __riscv_th_vlxbu_v_u32m4(src_ptr, indexed, vl)
#define __riscv_vlxbu_v_u32m8(src_ptr, indexed, vl) __riscv_th_vlxbu_v_u32m8(src_ptr, indexed, vl)
#define __riscv_vlxbu_v_u64m1(src_ptr, indexed, vl) __riscv_th_vlxbu_v_u64m1(src_ptr, indexed, vl)
#define __riscv_vlxbu_v_u64m2(src_ptr, indexed, vl) __riscv_th_vlxbu_v_u64m2(src_ptr, indexed, vl)
#define __riscv_vlxbu_v_u64m4(src_ptr, indexed, vl) __riscv_th_vlxbu_v_u64m4(src_ptr, indexed, vl)
#define __riscv_vlxbu_v_u64m8(src_ptr, indexed, vl) __riscv_th_vlxbu_v_u64m8(src_ptr, indexed, vl)
#define __riscv_vlxhu_v_u8m1(src_ptr, indexed, vl) __riscv_th_vlxhu_v_u8m1(src_ptr, indexed, vl)
#define __riscv_vlxhu_v_u8m2(src_ptr, indexed, vl) __riscv_th_vlxhu_v_u8m2(src_ptr, indexed, vl)
#define __riscv_vlxhu_v_u8m4(src_ptr, indexed, vl) __riscv_th_vlxhu_v_u8m4(src_ptr, indexed, vl)
#define __riscv_vlxhu_v_u8m8(src_ptr, indexed, vl) __riscv_th_vlxhu_v_u8m8(src_ptr, indexed, vl)
#define __riscv_vlxhu_v_u16m1(src_ptr, indexed, vl) __riscv_th_vlxhu_v_u16m1(src_ptr, indexed, vl)
#define __riscv_vlxhu_v_u16m2(src_ptr, indexed, vl) __riscv_th_vlxhu_v_u16m2(src_ptr, indexed, vl)
#define __riscv_vlxhu_v_u16m4(src_ptr, indexed, vl) __riscv_th_vlxhu_v_u16m4(src_ptr, indexed, vl)
#define __riscv_vlxhu_v_u16m8(src_ptr, indexed, vl) __riscv_th_vlxhu_v_u16m8(src_ptr, indexed, vl)
#define __riscv_vlxhu_v_u32m1(src_ptr, indexed, vl) __riscv_th_vlxhu_v_u32m1(src_ptr, indexed, vl)
#define __riscv_vlxhu_v_u32m2(src_ptr, indexed, vl) __riscv_th_vlxhu_v_u32m2(src_ptr, indexed, vl)
#define __riscv_vlxhu_v_u32m4(src_ptr, indexed, vl) __riscv_th_vlxhu_v_u32m4(src_ptr, indexed, vl)
#define __riscv_vlxhu_v_u32m8(src_ptr, indexed, vl) __riscv_th_vlxhu_v_u32m8(src_ptr, indexed, vl)
#define __riscv_vlxhu_v_u64m1(src_ptr, indexed, vl) __riscv_th_vlxhu_v_u64m1(src_ptr, indexed, vl)
#define __riscv_vlxhu_v_u64m2(src_ptr, indexed, vl) __riscv_th_vlxhu_v_u64m2(src_ptr, indexed, vl)
#define __riscv_vlxhu_v_u64m4(src_ptr, indexed, vl) __riscv_th_vlxhu_v_u64m4(src_ptr, indexed, vl)
#define __riscv_vlxhu_v_u64m8(src_ptr, indexed, vl) __riscv_th_vlxhu_v_u64m8(src_ptr, indexed, vl)
#define __riscv_vlxwu_v_u8m1(src_ptr, indexed, vl) __riscv_th_vlxwu_v_u8m1(src_ptr, indexed, vl)
#define __riscv_vlxwu_v_u8m2(src_ptr, indexed, vl) __riscv_th_vlxwu_v_u8m2(src_ptr, indexed, vl)
#define __riscv_vlxwu_v_u8m4(src_ptr, indexed, vl) __riscv_th_vlxwu_v_u8m4(src_ptr, indexed, vl)
#define __riscv_vlxwu_v_u8m8(src_ptr, indexed, vl) __riscv_th_vlxwu_v_u8m8(src_ptr, indexed, vl)
#define __riscv_vlxwu_v_u16m1(src_ptr, indexed, vl) __riscv_th_vlxwu_v_u16m1(src_ptr, indexed, vl)
#define __riscv_vlxwu_v_u16m2(src_ptr, indexed, vl) __riscv_th_vlxwu_v_u16m2(src_ptr, indexed, vl)
#define __riscv_vlxwu_v_u16m4(src_ptr, indexed, vl) __riscv_th_vlxwu_v_u16m4(src_ptr, indexed, vl)
#define __riscv_vlxwu_v_u16m8(src_ptr, indexed, vl) __riscv_th_vlxwu_v_u16m8(src_ptr, indexed, vl)
#define __riscv_vlxwu_v_u32m1(src_ptr, indexed, vl) __riscv_th_vlxwu_v_u32m1(src_ptr, indexed, vl)
#define __riscv_vlxwu_v_u32m2(src_ptr, indexed, vl) __riscv_th_vlxwu_v_u32m2(src_ptr, indexed, vl)
#define __riscv_vlxwu_v_u32m4(src_ptr, indexed, vl) __riscv_th_vlxwu_v_u32m4(src_ptr, indexed, vl)
#define __riscv_vlxwu_v_u32m8(src_ptr, indexed, vl) __riscv_th_vlxwu_v_u32m8(src_ptr, indexed, vl)
#define __riscv_vlxwu_v_u64m1(src_ptr, indexed, vl) __riscv_th_vlxwu_v_u64m1(src_ptr, indexed, vl)
#define __riscv_vlxwu_v_u64m2(src_ptr, indexed, vl) __riscv_th_vlxwu_v_u64m2(src_ptr, indexed, vl)
#define __riscv_vlxwu_v_u64m4(src_ptr, indexed, vl) __riscv_th_vlxwu_v_u64m4(src_ptr, indexed, vl)
#define __riscv_vlxwu_v_u64m8(src_ptr, indexed, vl) __riscv_th_vlxwu_v_u64m8(src_ptr, indexed, vl)
#define __riscv_vsxb_v_i8m1(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_i8m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_i8m2(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_i8m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_i8m4(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_i8m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_i8m8(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_i8m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_i16m1(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_i16m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_i16m2(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_i16m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_i16m4(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_i16m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_i16m8(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_i16m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_i32m1(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_i32m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_i32m2(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_i32m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_i32m4(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_i32m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_i32m8(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_i32m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_i64m1(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_i64m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_i64m2(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_i64m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_i64m4(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_i64m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_i64m8(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_i64m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_i8m1(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_i8m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_i8m2(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_i8m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_i8m4(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_i8m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_i8m8(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_i8m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_i16m1(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_i16m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_i16m2(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_i16m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_i16m4(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_i16m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_i16m8(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_i16m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_i32m1(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_i32m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_i32m2(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_i32m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_i32m4(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_i32m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_i32m8(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_i32m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_i64m1(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_i64m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_i64m2(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_i64m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_i64m4(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_i64m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_i64m8(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_i64m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_i8m1(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_i8m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_i8m2(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_i8m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_i8m4(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_i8m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_i8m8(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_i8m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_i16m1(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_i16m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_i16m2(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_i16m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_i16m4(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_i16m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_i16m8(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_i16m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_i32m1(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_i32m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_i32m2(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_i32m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_i32m4(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_i32m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_i32m8(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_i32m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_i64m1(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_i64m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_i64m2(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_i64m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_i64m4(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_i64m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_i64m8(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_i64m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_u8m1(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_u8m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_u8m2(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_u8m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_u8m4(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_u8m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_u8m8(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_u8m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_u16m1(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_u16m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_u16m2(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_u16m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_u16m4(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_u16m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_u16m8(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_u16m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_u32m1(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_u32m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_u32m2(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_u32m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_u32m4(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_u32m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_u32m8(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_u32m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_u64m1(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_u64m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_u64m2(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_u64m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_u64m4(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_u64m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxb_v_u64m8(dst_ptr, indexed, value, vl) __riscv_th_vsxb_v_u64m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_u8m1(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_u8m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_u8m2(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_u8m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_u8m4(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_u8m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_u8m8(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_u8m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_u16m1(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_u16m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_u16m2(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_u16m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_u16m4(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_u16m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_u16m8(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_u16m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_u32m1(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_u32m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_u32m2(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_u32m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_u32m4(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_u32m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_u32m8(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_u32m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_u64m1(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_u64m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_u64m2(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_u64m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_u64m4(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_u64m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxh_v_u64m8(dst_ptr, indexed, value, vl) __riscv_th_vsxh_v_u64m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_u8m1(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_u8m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_u8m2(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_u8m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_u8m4(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_u8m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_u8m8(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_u8m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_u16m1(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_u16m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_u16m2(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_u16m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_u16m4(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_u16m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_u16m8(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_u16m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_u32m1(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_u32m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_u32m2(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_u32m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_u32m4(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_u32m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_u32m8(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_u32m8(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_u64m1(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_u64m1(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_u64m2(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_u64m2(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_u64m4(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_u64m4(dst_ptr, indexed, value, vl)
#define __riscv_vsxw_v_u64m8(dst_ptr, indexed, value, vl) __riscv_th_vsxw_v_u64m8(dst_ptr, indexed, value, vl)

// Vector Narrowing Integer Right Shift Operations
#define __riscv_vnsrl_wv_u8m1(op1_v, shift_v, vl) __riscv_th_vnsrl_wv_u8m1(op1_v, shift_v, vl)
#define __riscv_vnsrl_wv_u8m2(op1_v, shift_v, vl) __riscv_th_vnsrl_wv_u8m2(op1_v, shift_v, vl)
#define __riscv_vnsrl_wv_u8m4(op1_v, shift_v, vl) __riscv_th_vnsrl_wv_u8m4(op1_v, shift_v, vl)
#define __riscv_vnsrl_wv_u16m1(op1_v, shift_v, vl) __riscv_th_vnsrl_wv_u16m1(op1_v, shift_v, vl)
#define __riscv_vnsrl_wv_u16m2(op1_v, shift_v, vl) __riscv_th_vnsrl_wv_u16m2(op1_v, shift_v, vl)
#define __riscv_vnsrl_wv_u16m4(op1_v, shift_v, vl) __riscv_th_vnsrl_wv_u16m4(op1_v, shift_v, vl)
#define __riscv_vnsrl_wv_u32m1(op1_v, shift_v, vl) __riscv_th_vnsrl_wv_u32m1(op1_v, shift_v, vl)
#define __riscv_vnsrl_wv_u32m2(op1_v, shift_v, vl) __riscv_th_vnsrl_wv_u32m2(op1_v, shift_v, vl)
#define __riscv_vnsrl_wv_u32m4(op1_v, shift_v, vl) __riscv_th_vnsrl_wv_u32m4(op1_v, shift_v, vl)

#define __riscv_vnsrl_wx_u8m1(op1_v, shift_x, vl) __riscv_th_vnsrl_wx_u8m1(op1_v, shift_x, vl)
#define __riscv_vnsrl_wx_u8m2(op1_v, shift_x, vl) __riscv_th_vnsrl_wx_u8m2(op1_v, shift_x, vl)
#define __riscv_vnsrl_wx_u8m4(op1_v, shift_x, vl) __riscv_th_vnsrl_wx_u8m4(op1_v, shift_x, vl)
#define __riscv_vnsrl_wx_u16m1(op1_v, shift_x, vl) __riscv_th_vnsrl_wx_u16m1(op1_v, shift_x, vl)
#define __riscv_vnsrl_wx_u16m2(op1_v, shift_x, vl) __riscv_th_vnsrl_wx_u16m2(op1_v, shift_x, vl)
#define __riscv_vnsrl_wx_u16m4(op1_v, shift_x, vl) __riscv_th_vnsrl_wx_u16m4(op1_v, shift_x, vl)
#define __riscv_vnsrl_wx_u32m1(op1_v, shift_x, vl) __riscv_th_vnsrl_wx_u32m1(op1_v, shift_x, vl)
#define __riscv_vnsrl_wx_u32m2(op1_v, shift_x, vl) __riscv_th_vnsrl_wx_u32m2(op1_v, shift_x, vl)
#define __riscv_vnsrl_wx_u32m4(op1_v, shift_x, vl) __riscv_th_vnsrl_wx_u32m4(op1_v, shift_x, vl)

#define __riscv_vnsra_wv_i8m1(op1_v, shift_v, vl) __riscv_th_vnsra_wv_i8m1(op1_v, shift_v, vl)
#define __riscv_vnsra_wv_i8m2(op1_v, shift_v, vl) __riscv_th_vnsra_wv_i8m2(op1_v, shift_v, vl)
#define __riscv_vnsra_wv_i8m4(op1_v, shift_v, vl) __riscv_th_vnsra_wv_i8m4(op1_v, shift_v, vl)
#define __riscv_vnsra_wv_i16m1(op1_v, shift_v, vl) __riscv_th_vnsra_wv_i16m1(op1_v, shift_v, vl)
#define __riscv_vnsra_wv_i16m2(op1_v, shift_v, vl) __riscv_th_vnsra_wv_i16m2(op1_v, shift_v, vl)
#define __riscv_vnsra_wv_i16m4(op1_v, shift_v, vl) __riscv_th_vnsra_wv_i16m4(op1_v, shift_v, vl)
#define __riscv_vnsra_wv_i32m1(op1_v, shift_v, vl) __riscv_th_vnsra_wv_i32m1(op1_v, shift_v, vl)
#define __riscv_vnsra_wv_i32m2(op1_v, shift_v, vl) __riscv_th_vnsra_wv_i32m2(op1_v, shift_v, vl)
#define __riscv_vnsra_wv_i32m4(op1_v, shift_v, vl) __riscv_th_vnsra_wv_i32m4(op1_v, shift_v, vl)

#define __riscv_vnsra_wx_i8m1(op1_v, shift_x, vl) __riscv_th_vnsra_wx_i8m1(op1_v, shift_x, vl)
#define __riscv_vnsra_wx_i8m2(op1_v, shift_x, vl) __riscv_th_vnsra_wx_i8m2(op1_v, shift_x, vl)
#define __riscv_vnsra_wx_i8m4(op1_v, shift_x, vl) __riscv_th_vnsra_wx_i8m4(op1_v, shift_x, vl)
#define __riscv_vnsra_wx_i16m1(op1_v, shift_x, vl) __riscv_th_vnsra_wx_i16m1(op1_v, shift_x, vl)
#define __riscv_vnsra_wx_i16m2(op1_v, shift_x, vl) __riscv_th_vnsra_wx_i16m2(op1_v, shift_x, vl)
#define __riscv_vnsra_wx_i16m4(op1_v, shift_x, vl) __riscv_th_vnsra_wx_i16m4(op1_v, shift_x, vl)
#define __riscv_vnsra_wx_i32m1(op1_v, shift_x, vl) __riscv_th_vnsra_wx_i32m1(op1_v, shift_x, vl)
#define __riscv_vnsra_wx_i32m2(op1_v, shift_x, vl) __riscv_th_vnsra_wx_i32m2(op1_v, shift_x, vl)
#define __riscv_vnsra_wx_i32m4(op1_v, shift_x, vl) __riscv_th_vnsra_wx_i32m4(op1_v, shift_x, vl)


// Vector Narrowing Fixed-Point Clip Operations
#define __riscv_vnclip_wv_i8m1(op1, op2, rm, vl) __riscv_th_vnclip_wv_i8m1(op1, op2, rm, vl)
#define __riscv_vnclip_wx_i8m1(op1, op2, rm, vl) __riscv_th_vnclip_wx_i8m1(op1, op2, rm, vl)
#define __riscv_vnclip_wv_i8m2(op1, op2, rm, vl) __riscv_th_vnclip_wv_i8m2(op1, op2, rm, vl)
#define __riscv_vnclip_wx_i8m2(op1, op2, rm, vl) __riscv_th_vnclip_wx_i8m2(op1, op2, rm, vl)
#define __riscv_vnclip_wv_i8m4(op1, op2, rm, vl) __riscv_th_vnclip_wv_i8m4(op1, op2, rm, vl)
#define __riscv_vnclip_wx_i8m4(op1, op2, rm, vl) __riscv_th_vnclip_wx_i8m4(op1, op2, rm, vl)
#define __riscv_vnclip_wv_i16m1(op1, op2, rm, vl) __riscv_th_vnclip_wv_i16m1(op1, op2, rm, vl)
#define __riscv_vnclip_wx_i16m1(op1, op2, rm, vl) __riscv_th_vnclip_wx_i16m1(op1, op2, rm, vl)
#define __riscv_vnclip_wv_i16m2(op1, op2, rm, vl) __riscv_th_vnclip_wv_i16m2(op1, op2, rm, vl)
#define __riscv_vnclip_wx_i16m2(op1, op2, rm, vl) __riscv_th_vnclip_wx_i16m2(op1, op2, rm, vl)
#define __riscv_vnclip_wv_i16m4(op1, op2, rm, vl) __riscv_th_vnclip_wv_i16m4(op1, op2, rm, vl)
#define __riscv_vnclip_wx_i16m4(op1, op2, rm, vl) __riscv_th_vnclip_wx_i16m4(op1, op2, rm, vl)
#define __riscv_vnclip_wv_i32m1(op1, op2, rm, vl) __riscv_th_vnclip_wv_i32m1(op1, op2, rm, vl)
#define __riscv_vnclip_wx_i32m1(op1, op2, rm, vl) __riscv_th_vnclip_wx_i32m1(op1, op2, rm, vl)
#define __riscv_vnclip_wv_i32m2(op1, op2, rm, vl) __riscv_th_vnclip_wv_i32m2(op1, op2, rm, vl)
#define __riscv_vnclip_wx_i32m2(op1, op2, rm, vl) __riscv_th_vnclip_wx_i32m2(op1, op2, rm, vl)
#define __riscv_vnclip_wv_i32m4(op1, op2, rm, vl) __riscv_th_vnclip_wv_i32m4(op1, op2, rm, vl)
#define __riscv_vnclip_wx_i32m4(op1, op2, rm, vl) __riscv_th_vnclip_wx_i32m4(op1, op2, rm, vl)

#define __riscv_vnclip_wv_i8m1_m(mask, op1, op2, rm, vl) __riscv_th_vnclip_wv_i8m1_m(mask, op1, op2, rm, vl)
#define __riscv_vnclip_wx_i8m1_m(mask, op1, op2, rm, vl) __riscv_th_vnclip_wx_i8m1_m(mask, op1, op2, rm, vl)
#define __riscv_vnclip_wv_i8m2_m(mask, op1, op2, rm, vl) __riscv_th_vnclip_wv_i8m2_m(mask, op1, op2, rm, vl)
#define __riscv_vnclip_wx_i8m2_m(mask, op1, op2, rm, vl) __riscv_th_vnclip_wx_i8m2_m(mask, op1, op2, rm, vl)
#define __riscv_vnclip_wv_i8m4_m(mask, op1, op2, rm, vl) __riscv_th_vnclip_wv_i8m4_m(mask, op1, op2, rm, vl)
#define __riscv_vnclip_wx_i8m4_m(mask, op1, op2, rm, vl) __riscv_th_vnclip_wx_i8m4_m(mask, op1, op2, rm, vl)
#define __riscv_vnclip_wv_i16m1_m(mask, op1, op2, rm, vl) __riscv_th_vnclip_wv_i16m1_m(mask, op1, op2, rm, vl)
#define __riscv_vnclip_wx_i16m1_m(mask, op1, op2, rm, vl) __riscv_th_vnclip_wx_i16m1_m(mask, op1, op2, rm, vl)
#define __riscv_vnclip_wv_i16m2_m(mask, op1, op2, rm, vl) __riscv_th_vnclip_wv_i16m2_m(mask, op1, op2, rm, vl)
#define __riscv_vnclip_wx_i16m2_m(mask, op1, op2, rm, vl) __riscv_th_vnclip_wx_i16m2_m(mask, op1, op2, rm, vl)
#define __riscv_vnclip_wv_i16m4_m(mask, op1, op2, rm, vl) __riscv_th_vnclip_wv_i16m4_m(mask, op1, op2, rm, vl)
#define __riscv_vnclip_wx_i16m4_m(mask, op1, op2, rm, vl) __riscv_th_vnclip_wx_i16m4_m(mask, op1, op2, rm, vl)
#define __riscv_vnclip_wv_i32m1_m(mask, op1, op2, rm, vl) __riscv_th_vnclip_wv_i32m1_m(mask, op1, op2, rm, vl)
#define __riscv_vnclip_wx_i32m1_m(mask, op1, op2, rm, vl) __riscv_th_vnclip_wx_i32m1_m(mask, op1, op2, rm, vl)
#define __riscv_vnclip_wv_i32m2_m(mask, op1, op2, rm, vl) __riscv_th_vnclip_wv_i32m2_m(mask, op1, op2, rm, vl)
#define __riscv_vnclip_wx_i32m2_m(mask, op1, op2, rm, vl) __riscv_th_vnclip_wx_i32m2_m(mask, op1, op2, rm, vl)
#define __riscv_vnclip_wv_i32m4_m(mask, op1, op2, rm, vl) __riscv_th_vnclip_wv_i32m4_m(mask, op1, op2, rm, vl)
#define __riscv_vnclip_wx_i32m4_m(mask, op1, op2, rm, vl) __riscv_th_vnclip_wx_i32m4_m(mask, op1, op2, rm, vl)

#define __riscv_vnclipu_wv_u8m1(op1, op2, rm, vl) __riscv_th_vnclipu_wv_u8m1(op1, op2, rm, vl)
#define __riscv_vnclipu_wx_u8m1(op1, op2, rm, vl) __riscv_th_vnclipu_wx_u8m1(op1, op2, rm, vl)
#define __riscv_vnclipu_wv_u8m2(op1, op2, rm, vl) __riscv_th_vnclipu_wv_u8m2(op1, op2, rm, vl)
#define __riscv_vnclipu_wx_u8m2(op1, op2, rm, vl) __riscv_th_vnclipu_wx_u8m2(op1, op2, rm, vl)
#define __riscv_vnclipu_wv_u8m4(op1, op2, rm, vl) __riscv_th_vnclipu_wv_u8m4(op1, op2, rm, vl)
#define __riscv_vnclipu_wx_u8m4(op1, op2, rm, vl) __riscv_th_vnclipu_wx_u8m4(op1, op2, rm, vl)
#define __riscv_vnclipu_wv_u16m1(op1, op2, rm, vl) __riscv_th_vnclipu_wv_u16m1(op1, op2, rm, vl)
#define __riscv_vnclipu_wx_u16m1(op1, op2, rm, vl) __riscv_th_vnclipu_wx_u16m1(op1, op2, rm, vl)
#define __riscv_vnclipu_wv_u16m2(op1, op2, rm, vl) __riscv_th_vnclipu_wv_u16m2(op1, op2, rm, vl)
#define __riscv_vnclipu_wx_u16m2(op1, op2, rm, vl) __riscv_th_vnclipu_wx_u16m2(op1, op2, rm, vl)
#define __riscv_vnclipu_wv_u16m4(op1, op2, rm, vl) __riscv_th_vnclipu_wv_u16m4(op1, op2, rm, vl)
#define __riscv_vnclipu_wx_u16m4(op1, op2, rm, vl) __riscv_th_vnclipu_wx_u16m4(op1, op2, rm, vl)
#define __riscv_vnclipu_wv_u32m1(op1, op2, rm, vl) __riscv_th_vnclipu_wv_u32m1(op1, op2, rm, vl)
#define __riscv_vnclipu_wx_u32m1(op1, op2, rm, vl) __riscv_th_vnclipu_wx_u32m1(op1, op2, rm, vl)
#define __riscv_vnclipu_wv_u32m2(op1, op2, rm, vl) __riscv_th_vnclipu_wv_u32m2(op1, op2, rm, vl)
#define __riscv_vnclipu_wx_u32m2(op1, op2, rm, vl) __riscv_th_vnclipu_wx_u32m2(op1, op2, rm, vl)
#define __riscv_vnclipu_wv_u32m4(op1, op2, rm, vl) __riscv_th_vnclipu_wv_u32m4(op1, op2, rm, vl)
#define __riscv_vnclipu_wx_u32m4(op1, op2, rm, vl) __riscv_th_vnclipu_wx_u32m4(op1, op2, rm, vl)

#define __riscv_vnclipu_wv_u8m1_m(mask, op1, op2, rm, vl) __riscv_th_vnclipu_wv_u8m1_m(mask, op1, op2, rm, vl)
#define __riscv_vnclipu_wx_u8m1_m(mask, op1, op2, rm, vl) __riscv_th_vnclipu_wx_u8m1_m(mask, op1, op2, rm, vl)
#define __riscv_vnclipu_wv_u8m2_m(mask, op1, op2, rm, vl) __riscv_th_vnclipu_wv_u8m2_m(mask, op1, op2, rm, vl)
#define __riscv_vnclipu_wx_u8m2_m(mask, op1, op2, rm, vl) __riscv_th_vnclipu_wx_u8m2_m(mask, op1, op2, rm, vl)
#define __riscv_vnclipu_wv_u8m4_m(mask, op1, op2, rm, vl) __riscv_th_vnclipu_wv_u8m4_m(mask, op1, op2, rm, vl)
#define __riscv_vnclipu_wx_u8m4_m(mask, op1, op2, rm, vl) __riscv_th_vnclipu_wx_u8m4_m(mask, op1, op2, rm, vl)
#define __riscv_vnclipu_wv_u16m1_m(mask, op1, op2, rm, vl) __riscv_th_vnclipu_wv_u16m1_m(mask, op1, op2, rm, vl)
#define __riscv_vnclipu_wx_u16m1_m(mask, op1, op2, rm, vl) __riscv_th_vnclipu_wx_u16m1_m(mask, op1, op2, rm, vl)
#define __riscv_vnclipu_wv_u16m2_m(mask, op1, op2, rm, vl) __riscv_th_vnclipu_wv_u16m2_m(mask, op1, op2, rm, vl)
#define __riscv_vnclipu_wx_u16m2_m(mask, op1, op2, rm, vl) __riscv_th_vnclipu_wx_u16m2_m(mask, op1, op2, rm, vl)
#define __riscv_vnclipu_wv_u16m4_m(mask, op1, op2, rm, vl) __riscv_th_vnclipu_wv_u16m4_m(mask, op1, op2, rm, vl)
#define __riscv_vnclipu_wx_u16m4_m(mask, op1, op2, rm, vl) __riscv_th_vnclipu_wx_u16m4_m(mask, op1, op2, rm, vl)
#define __riscv_vnclipu_wv_u32m1_m(mask, op1, op2, rm, vl) __riscv_th_vnclipu_wv_u32m1_m(mask, op1, op2, rm, vl)
#define __riscv_vnclipu_wx_u32m1_m(mask, op1, op2, rm, vl) __riscv_th_vnclipu_wx_u32m1_m(mask, op1, op2, rm, vl)
#define __riscv_vnclipu_wv_u32m2_m(mask, op1, op2, rm, vl) __riscv_th_vnclipu_wv_u32m2_m(mask, op1, op2, rm, vl)
#define __riscv_vnclipu_wx_u32m2_m(mask, op1, op2, rm, vl) __riscv_th_vnclipu_wx_u32m2_m(mask, op1, op2, rm, vl)
#define __riscv_vnclipu_wv_u32m4_m(mask, op1, op2, rm, vl) __riscv_th_vnclipu_wv_u32m4_m(mask, op1, op2, rm, vl)
#define __riscv_vnclipu_wx_u32m4_m(mask, op1, op2, rm, vl) __riscv_th_vnclipu_wx_u32m4_m(mask, op1, op2, rm, vl)


// Vector Single-Width Averaging Add and Subtract
#define __riscv_vaadd_vv_i8m1(op1, op2, rm, vl) __riscv_th_vaadd_vv_i8m1(op1, op2, rm, vl)
#define __riscv_vaadd_vx_i8m1(op1, op2, rm, vl) __riscv_th_vaadd_vx_i8m1(op1, op2, rm, vl)
#define __riscv_vaadd_vv_i8m2(op1, op2, rm, vl) __riscv_th_vaadd_vv_i8m2(op1, op2, rm, vl)
#define __riscv_vaadd_vx_i8m2(op1, op2, rm, vl) __riscv_th_vaadd_vx_i8m2(op1, op2, rm, vl)
#define __riscv_vaadd_vv_i8m4(op1, op2, rm, vl) __riscv_th_vaadd_vv_i8m4(op1, op2, rm, vl)
#define __riscv_vaadd_vx_i8m4(op1, op2, rm, vl) __riscv_th_vaadd_vx_i8m4(op1, op2, rm, vl)
#define __riscv_vaadd_vv_i8m8(op1, op2, rm, vl) __riscv_th_vaadd_vv_i8m8(op1, op2, rm, vl)
#define __riscv_vaadd_vx_i8m8(op1, op2, rm, vl) __riscv_th_vaadd_vx_i8m8(op1, op2, rm, vl)
#define __riscv_vaadd_vv_i16m1(op1, op2, rm, vl) __riscv_th_vaadd_vv_i16m1(op1, op2, rm, vl)
#define __riscv_vaadd_vx_i16m1(op1, op2, rm, vl) __riscv_th_vaadd_vx_i16m1(op1, op2, rm, vl)
#define __riscv_vaadd_vv_i16m2(op1, op2, rm, vl) __riscv_th_vaadd_vv_i16m2(op1, op2, rm, vl)
#define __riscv_vaadd_vx_i16m2(op1, op2, rm, vl) __riscv_th_vaadd_vx_i16m2(op1, op2, rm, vl)
#define __riscv_vaadd_vv_i16m4(op1, op2, rm, vl) __riscv_th_vaadd_vv_i16m4(op1, op2, rm, vl)
#define __riscv_vaadd_vx_i16m4(op1, op2, rm, vl) __riscv_th_vaadd_vx_i16m4(op1, op2, rm, vl)
#define __riscv_vaadd_vv_i16m8(op1, op2, rm, vl) __riscv_th_vaadd_vv_i16m8(op1, op2, rm, vl)
#define __riscv_vaadd_vx_i16m8(op1, op2, rm, vl) __riscv_th_vaadd_vx_i16m8(op1, op2, rm, vl)
#define __riscv_vaadd_vv_i32m1(op1, op2, rm, vl) __riscv_th_vaadd_vv_i32m1(op1, op2, rm, vl)
#define __riscv_vaadd_vx_i32m1(op1, op2, rm, vl) __riscv_th_vaadd_vx_i32m1(op1, op2, rm, vl)
#define __riscv_vaadd_vv_i32m2(op1, op2, rm, vl) __riscv_th_vaadd_vv_i32m2(op1, op2, rm, vl)
#define __riscv_vaadd_vx_i32m2(op1, op2, rm, vl) __riscv_th_vaadd_vx_i32m2(op1, op2, rm, vl)
#define __riscv_vaadd_vv_i32m4(op1, op2, rm, vl) __riscv_th_vaadd_vv_i32m4(op1, op2, rm, vl)
#define __riscv_vaadd_vx_i32m4(op1, op2, rm, vl) __riscv_th_vaadd_vx_i32m4(op1, op2, rm, vl)
#define __riscv_vaadd_vv_i32m8(op1, op2, rm, vl) __riscv_th_vaadd_vv_i32m8(op1, op2, rm, vl)
#define __riscv_vaadd_vx_i32m8(op1, op2, rm, vl) __riscv_th_vaadd_vx_i32m8(op1, op2, rm, vl)
#define __riscv_vaadd_vv_i64m1(op1, op2, rm, vl) __riscv_th_vaadd_vv_i64m1(op1, op2, rm, vl)
#define __riscv_vaadd_vx_i64m1(op1, op2, rm, vl) __riscv_th_vaadd_vx_i64m1(op1, op2, rm, vl)
#define __riscv_vaadd_vv_i64m2(op1, op2, rm, vl) __riscv_th_vaadd_vv_i64m2(op1, op2, rm, vl)
#define __riscv_vaadd_vx_i64m2(op1, op2, rm, vl) __riscv_th_vaadd_vx_i64m2(op1, op2, rm, vl)
#define __riscv_vaadd_vv_i64m4(op1, op2, rm, vl) __riscv_th_vaadd_vv_i64m4(op1, op2, rm, vl)
#define __riscv_vaadd_vx_i64m4(op1, op2, rm, vl) __riscv_th_vaadd_vx_i64m4(op1, op2, rm, vl)
#define __riscv_vaadd_vv_i64m8(op1, op2, rm, vl) __riscv_th_vaadd_vv_i64m8(op1, op2, rm, vl)
#define __riscv_vaadd_vx_i64m8(op1, op2, rm, vl) __riscv_th_vaadd_vx_i64m8(op1, op2, rm, vl)

#define __riscv_vaadd_vv_i8m1_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vv_i8m1_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vx_i8m1_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vx_i8m1_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vv_i8m2_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vv_i8m2_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vx_i8m2_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vx_i8m2_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vv_i8m4_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vv_i8m4_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vx_i8m4_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vx_i8m4_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vv_i8m8_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vv_i8m8_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vx_i8m8_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vx_i8m8_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vv_i16m1_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vv_i16m1_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vx_i16m1_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vx_i16m1_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vv_i16m2_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vv_i16m2_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vx_i16m2_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vx_i16m2_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vv_i16m4_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vv_i16m4_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vx_i16m4_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vx_i16m4_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vv_i16m8_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vv_i16m8_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vx_i16m8_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vx_i16m8_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vv_i32m1_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vv_i32m1_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vx_i32m1_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vx_i32m1_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vv_i32m2_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vv_i32m2_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vx_i32m2_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vx_i32m2_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vv_i32m4_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vv_i32m4_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vx_i32m4_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vx_i32m4_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vv_i32m8_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vv_i32m8_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vx_i32m8_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vx_i32m8_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vv_i64m1_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vv_i64m1_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vx_i64m1_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vx_i64m1_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vv_i64m2_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vv_i64m2_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vx_i64m2_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vx_i64m2_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vv_i64m4_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vv_i64m4_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vx_i64m4_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vx_i64m4_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vv_i64m8_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vv_i64m8_m(mask, op1, op2, rm, vl)
#define __riscv_vaadd_vx_i64m8_m(mask, op1, op2, rm, vl) __riscv_th_vaadd_vx_i64m8_m(mask, op1, op2, rm, vl)

#define __riscv_vasub_vv_i8m1(op1, op2, rm, vl) __riscv_th_vasub_vv_i8m1(op1, op2, rm, vl)
#define __riscv_vasub_vx_i8m1(op1, op2, rm, vl) __riscv_th_vasub_vx_i8m1(op1, op2, rm, vl)
#define __riscv_vasub_vv_i8m2(op1, op2, rm, vl) __riscv_th_vasub_vv_i8m2(op1, op2, rm, vl)
#define __riscv_vasub_vx_i8m2(op1, op2, rm, vl) __riscv_th_vasub_vx_i8m2(op1, op2, rm, vl)
#define __riscv_vasub_vv_i8m4(op1, op2, rm, vl) __riscv_th_vasub_vv_i8m4(op1, op2, rm, vl)
#define __riscv_vasub_vx_i8m4(op1, op2, rm, vl) __riscv_th_vasub_vx_i8m4(op1, op2, rm, vl)
#define __riscv_vasub_vv_i8m8(op1, op2, rm, vl) __riscv_th_vasub_vv_i8m8(op1, op2, rm, vl)
#define __riscv_vasub_vx_i8m8(op1, op2, rm, vl) __riscv_th_vasub_vx_i8m8(op1, op2, rm, vl)
#define __riscv_vasub_vv_i16m1(op1, op2, rm, vl) __riscv_th_vasub_vv_i16m1(op1, op2, rm, vl)
#define __riscv_vasub_vx_i16m1(op1, op2, rm, vl) __riscv_th_vasub_vx_i16m1(op1, op2, rm, vl)
#define __riscv_vasub_vv_i16m2(op1, op2, rm, vl) __riscv_th_vasub_vv_i16m2(op1, op2, rm, vl)
#define __riscv_vasub_vx_i16m2(op1, op2, rm, vl) __riscv_th_vasub_vx_i16m2(op1, op2, rm, vl)
#define __riscv_vasub_vv_i16m4(op1, op2, rm, vl) __riscv_th_vasub_vv_i16m4(op1, op2, rm, vl)
#define __riscv_vasub_vx_i16m4(op1, op2, rm, vl) __riscv_th_vasub_vx_i16m4(op1, op2, rm, vl)
#define __riscv_vasub_vv_i16m8(op1, op2, rm, vl) __riscv_th_vasub_vv_i16m8(op1, op2, rm, vl)
#define __riscv_vasub_vx_i16m8(op1, op2, rm, vl) __riscv_th_vasub_vx_i16m8(op1, op2, rm, vl)
#define __riscv_vasub_vv_i32m1(op1, op2, rm, vl) __riscv_th_vasub_vv_i32m1(op1, op2, rm, vl)
#define __riscv_vasub_vx_i32m1(op1, op2, rm, vl) __riscv_th_vasub_vx_i32m1(op1, op2, rm, vl)
#define __riscv_vasub_vv_i32m2(op1, op2, rm, vl) __riscv_th_vasub_vv_i32m2(op1, op2, rm, vl)
#define __riscv_vasub_vx_i32m2(op1, op2, rm, vl) __riscv_th_vasub_vx_i32m2(op1, op2, rm, vl)
#define __riscv_vasub_vv_i32m4(op1, op2, rm, vl) __riscv_th_vasub_vv_i32m4(op1, op2, rm, vl)
#define __riscv_vasub_vx_i32m4(op1, op2, rm, vl) __riscv_th_vasub_vx_i32m4(op1, op2, rm, vl)
#define __riscv_vasub_vv_i32m8(op1, op2, rm, vl) __riscv_th_vasub_vv_i32m8(op1, op2, rm, vl)
#define __riscv_vasub_vx_i32m8(op1, op2, rm, vl) __riscv_th_vasub_vx_i32m8(op1, op2, rm, vl)
#define __riscv_vasub_vv_i64m1(op1, op2, rm, vl) __riscv_th_vasub_vv_i64m1(op1, op2, rm, vl)
#define __riscv_vasub_vx_i64m1(op1, op2, rm, vl) __riscv_th_vasub_vx_i64m1(op1, op2, rm, vl)
#define __riscv_vasub_vv_i64m2(op1, op2, rm, vl) __riscv_th_vasub_vv_i64m2(op1, op2, rm, vl)
#define __riscv_vasub_vx_i64m2(op1, op2, rm, vl) __riscv_th_vasub_vx_i64m2(op1, op2, rm, vl)
#define __riscv_vasub_vv_i64m4(op1, op2, rm, vl) __riscv_th_vasub_vv_i64m4(op1, op2, rm, vl)
#define __riscv_vasub_vx_i64m4(op1, op2, rm, vl) __riscv_th_vasub_vx_i64m4(op1, op2, rm, vl)
#define __riscv_vasub_vv_i64m8(op1, op2, rm, vl) __riscv_th_vasub_vv_i64m8(op1, op2, rm, vl)
#define __riscv_vasub_vx_i64m8(op1, op2, rm, vl) __riscv_th_vasub_vx_i64m8(op1, op2, rm, vl)

#define __riscv_vasub_vv_i8m1_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vv_i8m1_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vx_i8m1_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vx_i8m1_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vv_i8m2_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vv_i8m2_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vx_i8m2_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vx_i8m2_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vv_i8m4_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vv_i8m4_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vx_i8m4_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vx_i8m4_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vv_i8m8_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vv_i8m8_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vx_i8m8_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vx_i8m8_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vv_i16m1_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vv_i16m1_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vx_i16m1_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vx_i16m1_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vv_i16m2_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vv_i16m2_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vx_i16m2_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vx_i16m2_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vv_i16m4_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vv_i16m4_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vx_i16m4_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vx_i16m4_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vv_i16m8_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vv_i16m8_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vx_i16m8_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vx_i16m8_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vv_i32m1_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vv_i32m1_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vx_i32m1_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vx_i32m1_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vv_i32m2_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vv_i32m2_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vx_i32m2_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vx_i32m2_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vv_i32m4_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vv_i32m4_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vx_i32m4_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vx_i32m4_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vv_i32m8_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vv_i32m8_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vx_i32m8_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vx_i32m8_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vv_i64m1_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vv_i64m1_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vx_i64m1_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vx_i64m1_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vv_i64m2_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vv_i64m2_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vx_i64m2_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vx_i64m2_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vv_i64m4_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vv_i64m4_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vx_i64m4_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vx_i64m4_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vv_i64m8_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vv_i64m8_m(mask, op1, op2, rm, vl)
#define __riscv_vasub_vx_i64m8_m(mask, op1, op2, rm, vl) __riscv_th_vasub_vx_i64m8_m(mask, op1, op2, rm, vl)



#define __riscv_vsmul_vv_i8m1(op1, op2, rm, vl) __riscv_th_vsmul_vv_i8m1(op1, op2, rm, vl)
#define __riscv_vsmul_vx_i8m1(op1, op2, rm, vl) __riscv_th_vsmul_vx_i8m1(op1, op2, rm, vl)
#define __riscv_vsmul_vv_i8m2(op1, op2, rm, vl) __riscv_th_vsmul_vv_i8m2(op1, op2, rm, vl)
#define __riscv_vsmul_vx_i8m2(op1, op2, rm, vl) __riscv_th_vsmul_vx_i8m2(op1, op2, rm, vl)
#define __riscv_vsmul_vv_i8m4(op1, op2, rm, vl) __riscv_th_vsmul_vv_i8m4(op1, op2, rm, vl)
#define __riscv_vsmul_vx_i8m4(op1, op2, rm, vl) __riscv_th_vsmul_vx_i8m4(op1, op2, rm, vl)
#define __riscv_vsmul_vv_i8m8(op1, op2, rm, vl) __riscv_th_vsmul_vv_i8m8(op1, op2, rm, vl)
#define __riscv_vsmul_vx_i8m8(op1, op2, rm, vl) __riscv_th_vsmul_vx_i8m8(op1, op2, rm, vl)
#define __riscv_vsmul_vv_i16m1(op1, op2, rm, vl) __riscv_th_vsmul_vv_i16m1(op1, op2, rm, vl)
#define __riscv_vsmul_vx_i16m1(op1, op2, rm, vl) __riscv_th_vsmul_vx_i16m1(op1, op2, rm, vl)
#define __riscv_vsmul_vv_i16m2(op1, op2, rm, vl) __riscv_th_vsmul_vv_i16m2(op1, op2, rm, vl)
#define __riscv_vsmul_vx_i16m2(op1, op2, rm, vl) __riscv_th_vsmul_vx_i16m2(op1, op2, rm, vl)
#define __riscv_vsmul_vv_i16m4(op1, op2, rm, vl) __riscv_th_vsmul_vv_i16m4(op1, op2, rm, vl)
#define __riscv_vsmul_vx_i16m4(op1, op2, rm, vl) __riscv_th_vsmul_vx_i16m4(op1, op2, rm, vl)
#define __riscv_vsmul_vv_i16m8(op1, op2, rm, vl) __riscv_th_vsmul_vv_i16m8(op1, op2, rm, vl)
#define __riscv_vsmul_vx_i16m8(op1, op2, rm, vl) __riscv_th_vsmul_vx_i16m8(op1, op2, rm, vl)
#define __riscv_vsmul_vv_i32m1(op1, op2, rm, vl) __riscv_th_vsmul_vv_i32m1(op1, op2, rm, vl)
#define __riscv_vsmul_vx_i32m1(op1, op2, rm, vl) __riscv_th_vsmul_vx_i32m1(op1, op2, rm, vl)
#define __riscv_vsmul_vv_i32m2(op1, op2, rm, vl) __riscv_th_vsmul_vv_i32m2(op1, op2, rm, vl)
#define __riscv_vsmul_vx_i32m2(op1, op2, rm, vl) __riscv_th_vsmul_vx_i32m2(op1, op2, rm, vl)
#define __riscv_vsmul_vv_i32m4(op1, op2, rm, vl) __riscv_th_vsmul_vv_i32m4(op1, op2, rm, vl)
#define __riscv_vsmul_vx_i32m4(op1, op2, rm, vl) __riscv_th_vsmul_vx_i32m4(op1, op2, rm, vl)
#define __riscv_vsmul_vv_i32m8(op1, op2, rm, vl) __riscv_th_vsmul_vv_i32m8(op1, op2, rm, vl)
#define __riscv_vsmul_vx_i32m8(op1, op2, rm, vl) __riscv_th_vsmul_vx_i32m8(op1, op2, rm, vl)
#define __riscv_vsmul_vv_i64m1(op1, op2, rm, vl) __riscv_th_vsmul_vv_i64m1(op1, op2, rm, vl)
#define __riscv_vsmul_vx_i64m1(op1, op2, rm, vl) __riscv_th_vsmul_vx_i64m1(op1, op2, rm, vl)
#define __riscv_vsmul_vv_i64m2(op1, op2, rm, vl) __riscv_th_vsmul_vv_i64m2(op1, op2, rm, vl)
#define __riscv_vsmul_vx_i64m2(op1, op2, rm, vl) __riscv_th_vsmul_vx_i64m2(op1, op2, rm, vl)
#define __riscv_vsmul_vv_i64m4(op1, op2, rm, vl) __riscv_th_vsmul_vv_i64m4(op1, op2, rm, vl)
#define __riscv_vsmul_vx_i64m4(op1, op2, rm, vl) __riscv_th_vsmul_vx_i64m4(op1, op2, rm, vl)
#define __riscv_vsmul_vv_i64m8(op1, op2, rm, vl) __riscv_th_vsmul_vv_i64m8(op1, op2, rm, vl)
#define __riscv_vsmul_vx_i64m8(op1, op2, rm, vl) __riscv_th_vsmul_vx_i64m8(op1, op2, rm, vl)

#define __riscv_vsmul_vv_i8m1_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vv_i8m1_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vx_i8m1_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vx_i8m1_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vv_i8m2_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vv_i8m2_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vx_i8m2_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vx_i8m2_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vv_i8m4_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vv_i8m4_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vx_i8m4_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vx_i8m4_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vv_i8m8_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vv_i8m8_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vx_i8m8_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vx_i8m8_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vv_i16m1_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vv_i16m1_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vx_i16m1_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vx_i16m1_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vv_i16m2_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vv_i16m2_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vx_i16m2_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vx_i16m2_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vv_i16m4_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vv_i16m4_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vx_i16m4_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vx_i16m4_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vv_i16m8_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vv_i16m8_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vx_i16m8_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vx_i16m8_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vv_i32m1_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vv_i32m1_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vx_i32m1_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vx_i32m1_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vv_i32m2_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vv_i32m2_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vx_i32m2_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vx_i32m2_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vv_i32m4_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vv_i32m4_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vx_i32m4_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vx_i32m4_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vv_i32m8_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vv_i32m8_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vx_i32m8_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vx_i32m8_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vv_i64m1_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vv_i64m1_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vx_i64m1_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vx_i64m1_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vv_i64m2_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vv_i64m2_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vx_i64m2_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vx_i64m2_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vv_i64m4_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vv_i64m4_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vx_i64m4_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vx_i64m4_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vv_i64m8_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vv_i64m8_m(mask, op1, op2, rm, vl)
#define __riscv_vsmul_vx_i64m8_m(mask, op1, op2, rm, vl) __riscv_th_vsmul_vx_i64m8_m(mask, op1, op2, rm, vl)


// Vector Single-Width Integer Add and Subtract
#define __riscv_vadd_vv_i8m1(op1_v, op2_v, vl) __riscv_th_vadd_vv_i8m1(op1_v, op2_v, vl)
#define __riscv_vadd_vv_i8m2(op1_v, op2_v, vl) __riscv_th_vadd_vv_i8m2(op1_v, op2_v, vl)
#define __riscv_vadd_vv_i8m4(op1_v, op2_v, vl) __riscv_th_vadd_vv_i8m4(op1_v, op2_v, vl)
#define __riscv_vadd_vv_i8m8(op1_v, op2_v, vl) __riscv_th_vadd_vv_i8m8(op1_v, op2_v, vl)
#define __riscv_vadd_vv_i16m1(op1_v, op2_v, vl) __riscv_th_vadd_vv_i16m1(op1_v, op2_v, vl)
#define __riscv_vadd_vv_i16m2(op1_v, op2_v, vl) __riscv_th_vadd_vv_i16m2(op1_v, op2_v, vl)
#define __riscv_vadd_vv_i16m4(op1_v, op2_v, vl) __riscv_th_vadd_vv_i16m4(op1_v, op2_v, vl)
#define __riscv_vadd_vv_i16m8(op1_v, op2_v, vl) __riscv_th_vadd_vv_i16m8(op1_v, op2_v, vl)
#define __riscv_vadd_vv_i32m1(op1_v, op2_v, vl) __riscv_th_vadd_vv_i32m1(op1_v, op2_v, vl)
#define __riscv_vadd_vv_i32m2(op1_v, op2_v, vl) __riscv_th_vadd_vv_i32m2(op1_v, op2_v, vl)
#define __riscv_vadd_vv_i32m4(op1_v, op2_v, vl) __riscv_th_vadd_vv_i32m4(op1_v, op2_v, vl)
#define __riscv_vadd_vv_i32m8(op1_v, op2_v, vl) __riscv_th_vadd_vv_i32m8(op1_v, op2_v, vl)
#define __riscv_vadd_vv_i64m1(op1_v, op2_v, vl) __riscv_th_vadd_vv_i64m1(op1_v, op2_v, vl)
#define __riscv_vadd_vv_i64m2(op1_v, op2_v, vl) __riscv_th_vadd_vv_i64m2(op1_v, op2_v, vl)
#define __riscv_vadd_vv_i64m4(op1_v, op2_v, vl) __riscv_th_vadd_vv_i64m4(op1_v, op2_v, vl)
#define __riscv_vadd_vv_i64m8(op1_v, op2_v, vl) __riscv_th_vadd_vv_i64m8(op1_v, op2_v, vl)
#define __riscv_vadd_vv_u8m1(op1_v, op2_v, vl) __riscv_th_vadd_vv_u8m1(op1_v, op2_v, vl)
#define __riscv_vadd_vv_u8m2(op1_v, op2_v, vl) __riscv_th_vadd_vv_u8m2(op1_v, op2_v, vl)
#define __riscv_vadd_vv_u8m4(op1_v, op2_v, vl) __riscv_th_vadd_vv_u8m4(op1_v, op2_v, vl)
#define __riscv_vadd_vv_u8m8(op1_v, op2_v, vl) __riscv_th_vadd_vv_u8m8(op1_v, op2_v, vl)
#define __riscv_vadd_vv_u16m1(op1_v, op2_v, vl) __riscv_th_vadd_vv_u16m1(op1_v, op2_v, vl)
#define __riscv_vadd_vv_u16m2(op1_v, op2_v, vl) __riscv_th_vadd_vv_u16m2(op1_v, op2_v, vl)
#define __riscv_vadd_vv_u16m4(op1_v, op2_v, vl) __riscv_th_vadd_vv_u16m4(op1_v, op2_v, vl)
#define __riscv_vadd_vv_u16m8(op1_v, op2_v, vl) __riscv_th_vadd_vv_u16m8(op1_v, op2_v, vl)
#define __riscv_vadd_vv_u32m1(op1_v, op2_v, vl) __riscv_th_vadd_vv_u32m1(op1_v, op2_v, vl)
#define __riscv_vadd_vv_u32m2(op1_v, op2_v, vl) __riscv_th_vadd_vv_u32m2(op1_v, op2_v, vl)
#define __riscv_vadd_vv_u32m4(op1_v, op2_v, vl) __riscv_th_vadd_vv_u32m4(op1_v, op2_v, vl)
#define __riscv_vadd_vv_u32m8(op1_v, op2_v, vl) __riscv_th_vadd_vv_u32m8(op1_v, op2_v, vl)
#define __riscv_vadd_vv_u64m1(op1_v, op2_v, vl) __riscv_th_vadd_vv_u64m1(op1_v, op2_v, vl)
#define __riscv_vadd_vv_u64m2(op1_v, op2_v, vl) __riscv_th_vadd_vv_u64m2(op1_v, op2_v, vl)
#define __riscv_vadd_vv_u64m4(op1_v, op2_v, vl) __riscv_th_vadd_vv_u64m4(op1_v, op2_v, vl)
#define __riscv_vadd_vv_u64m8(op1_v, op2_v, vl) __riscv_th_vadd_vv_u64m8(op1_v, op2_v, vl)

#define __riscv_vadd_vx_i8m1(op1_v, op2_x, vl) __riscv_th_vadd_vx_i8m1(op1_v, op2_x, vl)
#define __riscv_vadd_vx_i8m2(op1_v, op2_x, vl) __riscv_th_vadd_vx_i8m2(op1_v, op2_x, vl)
#define __riscv_vadd_vx_i8m4(op1_v, op2_x, vl) __riscv_th_vadd_vx_i8m4(op1_v, op2_x, vl)
#define __riscv_vadd_vx_i8m8(op1_v, op2_x, vl) __riscv_th_vadd_vx_i8m8(op1_v, op2_x, vl)
#define __riscv_vadd_vx_i16m1(op1_v, op2_x, vl) __riscv_th_vadd_vx_i16m1(op1_v, op2_x, vl)
#define __riscv_vadd_vx_i16m2(op1_v, op2_x, vl) __riscv_th_vadd_vx_i16m2(op1_v, op2_x, vl)
#define __riscv_vadd_vx_i16m4(op1_v, op2_x, vl) __riscv_th_vadd_vx_i16m4(op1_v, op2_x, vl)
#define __riscv_vadd_vx_i16m8(op1_v, op2_x, vl) __riscv_th_vadd_vx_i16m8(op1_v, op2_x, vl)
#define __riscv_vadd_vx_i32m1(op1_v, op2_x, vl) __riscv_th_vadd_vx_i32m1(op1_v, op2_x, vl)
#define __riscv_vadd_vx_i32m2(op1_v, op2_x, vl) __riscv_th_vadd_vx_i32m2(op1_v, op2_x, vl)
#define __riscv_vadd_vx_i32m4(op1_v, op2_x, vl) __riscv_th_vadd_vx_i32m4(op1_v, op2_x, vl)
#define __riscv_vadd_vx_i32m8(op1_v, op2_x, vl) __riscv_th_vadd_vx_i32m8(op1_v, op2_x, vl)
#define __riscv_vadd_vx_i64m1(op1_v, op2_x, vl) __riscv_th_vadd_vx_i64m1(op1_v, op2_x, vl)
#define __riscv_vadd_vx_i64m2(op1_v, op2_x, vl) __riscv_th_vadd_vx_i64m2(op1_v, op2_x, vl)
#define __riscv_vadd_vx_i64m4(op1_v, op2_x, vl) __riscv_th_vadd_vx_i64m4(op1_v, op2_x, vl)
#define __riscv_vadd_vx_i64m8(op1_v, op2_x, vl) __riscv_th_vadd_vx_i64m8(op1_v, op2_x, vl)
#define __riscv_vadd_vx_u8m1(op1_v, op2_x, vl) __riscv_th_vadd_vx_u8m1(op1_v, op2_x, vl)
#define __riscv_vadd_vx_u8m2(op1_v, op2_x, vl) __riscv_th_vadd_vx_u8m2(op1_v, op2_x, vl)
#define __riscv_vadd_vx_u8m4(op1_v, op2_x, vl) __riscv_th_vadd_vx_u8m4(op1_v, op2_x, vl)
#define __riscv_vadd_vx_u8m8(op1_v, op2_x, vl) __riscv_th_vadd_vx_u8m8(op1_v, op2_x, vl)
#define __riscv_vadd_vx_u16m1(op1_v, op2_x, vl) __riscv_th_vadd_vx_u16m1(op1_v, op2_x, vl)
#define __riscv_vadd_vx_u16m2(op1_v, op2_x, vl) __riscv_th_vadd_vx_u16m2(op1_v, op2_x, vl)
#define __riscv_vadd_vx_u16m4(op1_v, op2_x, vl) __riscv_th_vadd_vx_u16m4(op1_v, op2_x, vl)
#define __riscv_vadd_vx_u16m8(op1_v, op2_x, vl) __riscv_th_vadd_vx_u16m8(op1_v, op2_x, vl)
#define __riscv_vadd_vx_u32m1(op1_v, op2_x, vl) __riscv_th_vadd_vx_u32m1(op1_v, op2_x, vl)
#define __riscv_vadd_vx_u32m2(op1_v, op2_x, vl) __riscv_th_vadd_vx_u32m2(op1_v, op2_x, vl)
#define __riscv_vadd_vx_u32m4(op1_v, op2_x, vl) __riscv_th_vadd_vx_u32m4(op1_v, op2_x, vl)
#define __riscv_vadd_vx_u32m8(op1_v, op2_x, vl) __riscv_th_vadd_vx_u32m8(op1_v, op2_x, vl)
#define __riscv_vadd_vx_u64m1(op1_v, op2_x, vl) __riscv_th_vadd_vx_u64m1(op1_v, op2_x, vl)
#define __riscv_vadd_vx_u64m2(op1_v, op2_x, vl) __riscv_th_vadd_vx_u64m2(op1_v, op2_x, vl)
#define __riscv_vadd_vx_u64m4(op1_v, op2_x, vl) __riscv_th_vadd_vx_u64m4(op1_v, op2_x, vl)
#define __riscv_vadd_vx_u64m8(op1_v, op2_x, vl) __riscv_th_vadd_vx_u64m8(op1_v, op2_x, vl)

#define __riscv_vsub_vv_i8m1(op1_v, op2_v, vl) __riscv_th_vsub_vv_i8m1(op1_v, op2_v, vl)
#define __riscv_vsub_vv_i8m2(op1_v, op2_v, vl) __riscv_th_vsub_vv_i8m2(op1_v, op2_v, vl)
#define __riscv_vsub_vv_i8m4(op1_v, op2_v, vl) __riscv_th_vsub_vv_i8m4(op1_v, op2_v, vl)
#define __riscv_vsub_vv_i8m8(op1_v, op2_v, vl) __riscv_th_vsub_vv_i8m8(op1_v, op2_v, vl)
#define __riscv_vsub_vv_i16m1(op1_v, op2_v, vl) __riscv_th_vsub_vv_i16m1(op1_v, op2_v, vl)
#define __riscv_vsub_vv_i16m2(op1_v, op2_v, vl) __riscv_th_vsub_vv_i16m2(op1_v, op2_v, vl)
#define __riscv_vsub_vv_i16m4(op1_v, op2_v, vl) __riscv_th_vsub_vv_i16m4(op1_v, op2_v, vl)
#define __riscv_vsub_vv_i16m8(op1_v, op2_v, vl) __riscv_th_vsub_vv_i16m8(op1_v, op2_v, vl)
#define __riscv_vsub_vv_i32m1(op1_v, op2_v, vl) __riscv_th_vsub_vv_i32m1(op1_v, op2_v, vl)
#define __riscv_vsub_vv_i32m2(op1_v, op2_v, vl) __riscv_th_vsub_vv_i32m2(op1_v, op2_v, vl)
#define __riscv_vsub_vv_i32m4(op1_v, op2_v, vl) __riscv_th_vsub_vv_i32m4(op1_v, op2_v, vl)
#define __riscv_vsub_vv_i32m8(op1_v, op2_v, vl) __riscv_th_vsub_vv_i32m8(op1_v, op2_v, vl)
#define __riscv_vsub_vv_i64m1(op1_v, op2_v, vl) __riscv_th_vsub_vv_i64m1(op1_v, op2_v, vl)
#define __riscv_vsub_vv_i64m2(op1_v, op2_v, vl) __riscv_th_vsub_vv_i64m2(op1_v, op2_v, vl)
#define __riscv_vsub_vv_i64m4(op1_v, op2_v, vl) __riscv_th_vsub_vv_i64m4(op1_v, op2_v, vl)
#define __riscv_vsub_vv_i64m8(op1_v, op2_v, vl) __riscv_th_vsub_vv_i64m8(op1_v, op2_v, vl)
#define __riscv_vsub_vv_u8m1(op1_v, op2_v, vl) __riscv_th_vsub_vv_u8m1(op1_v, op2_v, vl)
#define __riscv_vsub_vv_u8m2(op1_v, op2_v, vl) __riscv_th_vsub_vv_u8m2(op1_v, op2_v, vl)
#define __riscv_vsub_vv_u8m4(op1_v, op2_v, vl) __riscv_th_vsub_vv_u8m4(op1_v, op2_v, vl)
#define __riscv_vsub_vv_u8m8(op1_v, op2_v, vl) __riscv_th_vsub_vv_u8m8(op1_v, op2_v, vl)
#define __riscv_vsub_vv_u16m1(op1_v, op2_v, vl) __riscv_th_vsub_vv_u16m1(op1_v, op2_v, vl)
#define __riscv_vsub_vv_u16m2(op1_v, op2_v, vl) __riscv_th_vsub_vv_u16m2(op1_v, op2_v, vl)
#define __riscv_vsub_vv_u16m4(op1_v, op2_v, vl) __riscv_th_vsub_vv_u16m4(op1_v, op2_v, vl)
#define __riscv_vsub_vv_u16m8(op1_v, op2_v, vl) __riscv_th_vsub_vv_u16m8(op1_v, op2_v, vl)
#define __riscv_vsub_vv_u32m1(op1_v, op2_v, vl) __riscv_th_vsub_vv_u32m1(op1_v, op2_v, vl)
#define __riscv_vsub_vv_u32m2(op1_v, op2_v, vl) __riscv_th_vsub_vv_u32m2(op1_v, op2_v, vl)
#define __riscv_vsub_vv_u32m4(op1_v, op2_v, vl) __riscv_th_vsub_vv_u32m4(op1_v, op2_v, vl)
#define __riscv_vsub_vv_u32m8(op1_v, op2_v, vl) __riscv_th_vsub_vv_u32m8(op1_v, op2_v, vl)
#define __riscv_vsub_vv_u64m1(op1_v, op2_v, vl) __riscv_th_vsub_vv_u64m1(op1_v, op2_v, vl)
#define __riscv_vsub_vv_u64m2(op1_v, op2_v, vl) __riscv_th_vsub_vv_u64m2(op1_v, op2_v, vl)
#define __riscv_vsub_vv_u64m4(op1_v, op2_v, vl) __riscv_th_vsub_vv_u64m4(op1_v, op2_v, vl)
#define __riscv_vsub_vv_u64m8(op1_v, op2_v, vl) __riscv_th_vsub_vv_u64m8(op1_v, op2_v, vl)

#define __riscv_vsub_vx_i8m1(op1_v, op2_x, vl) __riscv_th_vsub_vx_i8m1(op1_v, op2_x, vl)
#define __riscv_vsub_vx_i8m2(op1_v, op2_x, vl) __riscv_th_vsub_vx_i8m2(op1_v, op2_x, vl)
#define __riscv_vsub_vx_i8m4(op1_v, op2_x, vl) __riscv_th_vsub_vx_i8m4(op1_v, op2_x, vl)
#define __riscv_vsub_vx_i8m8(op1_v, op2_x, vl) __riscv_th_vsub_vx_i8m8(op1_v, op2_x, vl)
#define __riscv_vsub_vx_i16m1(op1_v, op2_x, vl) __riscv_th_vsub_vx_i16m1(op1_v, op2_x, vl)
#define __riscv_vsub_vx_i16m2(op1_v, op2_x, vl) __riscv_th_vsub_vx_i16m2(op1_v, op2_x, vl)
#define __riscv_vsub_vx_i16m4(op1_v, op2_x, vl) __riscv_th_vsub_vx_i16m4(op1_v, op2_x, vl)
#define __riscv_vsub_vx_i16m8(op1_v, op2_x, vl) __riscv_th_vsub_vx_i16m8(op1_v, op2_x, vl)
#define __riscv_vsub_vx_i32m1(op1_v, op2_x, vl) __riscv_th_vsub_vx_i32m1(op1_v, op2_x, vl)
#define __riscv_vsub_vx_i32m2(op1_v, op2_x, vl) __riscv_th_vsub_vx_i32m2(op1_v, op2_x, vl)
#define __riscv_vsub_vx_i32m4(op1_v, op2_x, vl) __riscv_th_vsub_vx_i32m4(op1_v, op2_x, vl)
#define __riscv_vsub_vx_i32m8(op1_v, op2_x, vl) __riscv_th_vsub_vx_i32m8(op1_v, op2_x, vl)
#define __riscv_vsub_vx_i64m1(op1_v, op2_x, vl) __riscv_th_vsub_vx_i64m1(op1_v, op2_x, vl)
#define __riscv_vsub_vx_i64m2(op1_v, op2_x, vl) __riscv_th_vsub_vx_i64m2(op1_v, op2_x, vl)
#define __riscv_vsub_vx_i64m4(op1_v, op2_x, vl) __riscv_th_vsub_vx_i64m4(op1_v, op2_x, vl)
#define __riscv_vsub_vx_i64m8(op1_v, op2_x, vl) __riscv_th_vsub_vx_i64m8(op1_v, op2_x, vl)
#define __riscv_vsub_vx_u8m1(op1_v, op2_x, vl) __riscv_th_vsub_vx_u8m1(op1_v, op2_x, vl)
#define __riscv_vsub_vx_u8m2(op1_v, op2_x, vl) __riscv_th_vsub_vx_u8m2(op1_v, op2_x, vl)
#define __riscv_vsub_vx_u8m4(op1_v, op2_x, vl) __riscv_th_vsub_vx_u8m4(op1_v, op2_x, vl)
#define __riscv_vsub_vx_u8m8(op1_v, op2_x, vl) __riscv_th_vsub_vx_u8m8(op1_v, op2_x, vl)
#define __riscv_vsub_vx_u16m1(op1_v, op2_x, vl) __riscv_th_vsub_vx_u16m1(op1_v, op2_x, vl)
#define __riscv_vsub_vx_u16m2(op1_v, op2_x, vl) __riscv_th_vsub_vx_u16m2(op1_v, op2_x, vl)
#define __riscv_vsub_vx_u16m4(op1_v, op2_x, vl) __riscv_th_vsub_vx_u16m4(op1_v, op2_x, vl)
#define __riscv_vsub_vx_u16m8(op1_v, op2_x, vl) __riscv_th_vsub_vx_u16m8(op1_v, op2_x, vl)
#define __riscv_vsub_vx_u32m1(op1_v, op2_x, vl) __riscv_th_vsub_vx_u32m1(op1_v, op2_x, vl)
#define __riscv_vsub_vx_u32m2(op1_v, op2_x, vl) __riscv_th_vsub_vx_u32m2(op1_v, op2_x, vl)
#define __riscv_vsub_vx_u32m4(op1_v, op2_x, vl) __riscv_th_vsub_vx_u32m4(op1_v, op2_x, vl)
#define __riscv_vsub_vx_u32m8(op1_v, op2_x, vl) __riscv_th_vsub_vx_u32m8(op1_v, op2_x, vl)
#define __riscv_vsub_vx_u64m1(op1_v, op2_x, vl) __riscv_th_vsub_vx_u64m1(op1_v, op2_x, vl)
#define __riscv_vsub_vx_u64m2(op1_v, op2_x, vl) __riscv_th_vsub_vx_u64m2(op1_v, op2_x, vl)
#define __riscv_vsub_vx_u64m4(op1_v, op2_x, vl) __riscv_th_vsub_vx_u64m4(op1_v, op2_x, vl)
#define __riscv_vsub_vx_u64m8(op1_v, op2_x, vl) __riscv_th_vsub_vx_u64m8(op1_v, op2_x, vl)

#define __riscv_vrsub_vx_i8m1(op1_v, op2_x, vl) __riscv_th_vrsub_vx_i8m1(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_i8m2(op1_v, op2_x, vl) __riscv_th_vrsub_vx_i8m2(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_i8m4(op1_v, op2_x, vl) __riscv_th_vrsub_vx_i8m4(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_i8m8(op1_v, op2_x, vl) __riscv_th_vrsub_vx_i8m8(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_i16m1(op1_v, op2_x, vl) __riscv_th_vrsub_vx_i16m1(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_i16m2(op1_v, op2_x, vl) __riscv_th_vrsub_vx_i16m2(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_i16m4(op1_v, op2_x, vl) __riscv_th_vrsub_vx_i16m4(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_i16m8(op1_v, op2_x, vl) __riscv_th_vrsub_vx_i16m8(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_i32m1(op1_v, op2_x, vl) __riscv_th_vrsub_vx_i32m1(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_i32m2(op1_v, op2_x, vl) __riscv_th_vrsub_vx_i32m2(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_i32m4(op1_v, op2_x, vl) __riscv_th_vrsub_vx_i32m4(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_i32m8(op1_v, op2_x, vl) __riscv_th_vrsub_vx_i32m8(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_i64m1(op1_v, op2_x, vl) __riscv_th_vrsub_vx_i64m1(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_i64m2(op1_v, op2_x, vl) __riscv_th_vrsub_vx_i64m2(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_i64m4(op1_v, op2_x, vl) __riscv_th_vrsub_vx_i64m4(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_i64m8(op1_v, op2_x, vl) __riscv_th_vrsub_vx_i64m8(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_u8m1(op1_v, op2_x, vl) __riscv_th_vrsub_vx_u8m1(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_u8m2(op1_v, op2_x, vl) __riscv_th_vrsub_vx_u8m2(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_u8m4(op1_v, op2_x, vl) __riscv_th_vrsub_vx_u8m4(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_u8m8(op1_v, op2_x, vl) __riscv_th_vrsub_vx_u8m8(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_u16m1(op1_v, op2_x, vl) __riscv_th_vrsub_vx_u16m1(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_u16m2(op1_v, op2_x, vl) __riscv_th_vrsub_vx_u16m2(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_u16m4(op1_v, op2_x, vl) __riscv_th_vrsub_vx_u16m4(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_u16m8(op1_v, op2_x, vl) __riscv_th_vrsub_vx_u16m8(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_u32m1(op1_v, op2_x, vl) __riscv_th_vrsub_vx_u32m1(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_u32m2(op1_v, op2_x, vl) __riscv_th_vrsub_vx_u32m2(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_u32m4(op1_v, op2_x, vl) __riscv_th_vrsub_vx_u32m4(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_u32m8(op1_v, op2_x, vl) __riscv_th_vrsub_vx_u32m8(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_u64m1(op1_v, op2_x, vl) __riscv_th_vrsub_vx_u64m1(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_u64m2(op1_v, op2_x, vl) __riscv_th_vrsub_vx_u64m2(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_u64m4(op1_v, op2_x, vl) __riscv_th_vrsub_vx_u64m4(op1_v, op2_x, vl)
#define __riscv_vrsub_vx_u64m8(op1_v, op2_x, vl) __riscv_th_vrsub_vx_u64m8(op1_v, op2_x, vl)

#define __riscv_vneg_v_i8m1(op1_v, vl) __riscv_th_vneg_v_i8m1(op1_v, vl)
#define __riscv_vneg_v_i8m2(op1_v, vl) __riscv_th_vneg_v_i8m2(op1_v, vl)
#define __riscv_vneg_v_i8m4(op1_v, vl) __riscv_th_vneg_v_i8m4(op1_v, vl)
#define __riscv_vneg_v_i8m8(op1_v, vl) __riscv_th_vneg_v_i8m8(op1_v, vl)
#define __riscv_vneg_v_i16m1(op1_v, vl) __riscv_th_vneg_v_i16m1(op1_v, vl)
#define __riscv_vneg_v_i16m2(op1_v, vl) __riscv_th_vneg_v_i16m2(op1_v, vl)
#define __riscv_vneg_v_i16m4(op1_v, vl) __riscv_th_vneg_v_i16m4(op1_v, vl)
#define __riscv_vneg_v_i16m8(op1_v, vl) __riscv_th_vneg_v_i16m8(op1_v, vl)
#define __riscv_vneg_v_i32m1(op1_v, vl) __riscv_th_vneg_v_i32m1(op1_v, vl)
#define __riscv_vneg_v_i32m2(op1_v, vl) __riscv_th_vneg_v_i32m2(op1_v, vl)
#define __riscv_vneg_v_i32m4(op1_v, vl) __riscv_th_vneg_v_i32m4(op1_v, vl)
#define __riscv_vneg_v_i32m8(op1_v, vl) __riscv_th_vneg_v_i32m8(op1_v, vl)
#define __riscv_vneg_v_i64m1(op1_v, vl) __riscv_th_vneg_v_i64m1(op1_v, vl)
#define __riscv_vneg_v_i64m2(op1_v, vl) __riscv_th_vneg_v_i64m2(op1_v, vl)
#define __riscv_vneg_v_i64m4(op1_v, vl) __riscv_th_vneg_v_i64m4(op1_v, vl)
#define __riscv_vneg_v_i64m8(op1_v, vl) __riscv_th_vneg_v_i64m8(op1_v, vl)
#define __riscv_vneg_v_u8m1(op1_v, vl) __riscv_th_vneg_v_u8m1(op1_v, vl)
#define __riscv_vneg_v_u8m2(op1_v, vl) __riscv_th_vneg_v_u8m2(op1_v, vl)
#define __riscv_vneg_v_u8m4(op1_v, vl) __riscv_th_vneg_v_u8m4(op1_v, vl)
#define __riscv_vneg_v_u8m8(op1_v, vl) __riscv_th_vneg_v_u8m8(op1_v, vl)
#define __riscv_vneg_v_u16m1(op1_v, vl) __riscv_th_vneg_v_u16m1(op1_v, vl)
#define __riscv_vneg_v_u16m2(op1_v, vl) __riscv_th_vneg_v_u16m2(op1_v, vl)
#define __riscv_vneg_v_u16m4(op1_v, vl) __riscv_th_vneg_v_u16m4(op1_v, vl)
#define __riscv_vneg_v_u16m8(op1_v, vl) __riscv_th_vneg_v_u16m8(op1_v, vl)
#define __riscv_vneg_v_u32m1(op1_v, vl) __riscv_th_vneg_v_u32m1(op1_v, vl)
#define __riscv_vneg_v_u32m2(op1_v, vl) __riscv_th_vneg_v_u32m2(op1_v, vl)
#define __riscv_vneg_v_u32m4(op1_v, vl) __riscv_th_vneg_v_u32m4(op1_v, vl)
#define __riscv_vneg_v_u32m8(op1_v, vl) __riscv_th_vneg_v_u32m8(op1_v, vl)
#define __riscv_vneg_v_u64m1(op1_v, vl) __riscv_th_vneg_v_u64m1(op1_v, vl)
#define __riscv_vneg_v_u64m2(op1_v, vl) __riscv_th_vneg_v_u64m2(op1_v, vl)
#define __riscv_vneg_v_u64m4(op1_v, vl) __riscv_th_vneg_v_u64m4(op1_v, vl)
#define __riscv_vneg_v_u64m8(op1_v, vl) __riscv_th_vneg_v_u64m8(op1_v, vl)


// Vector Single Width Integer Bit Shift Operations
#define __riscv_vsll_vv_i8m1(op1_v, shift_v, vl) __riscv_th_vsll_vv_i8m1(op1_v, shift_v, vl)
#define __riscv_vsll_vv_i8m2(op1_v, shift_v, vl) __riscv_th_vsll_vv_i8m2(op1_v, shift_v, vl)
#define __riscv_vsll_vv_i8m4(op1_v, shift_v, vl) __riscv_th_vsll_vv_i8m4(op1_v, shift_v, vl)
#define __riscv_vsll_vv_i8m8(op1_v, shift_v, vl) __riscv_th_vsll_vv_i8m8(op1_v, shift_v, vl)
#define __riscv_vsll_vv_i16m1(op1_v, shift_v, vl) __riscv_th_vsll_vv_i16m1(op1_v, shift_v, vl)
#define __riscv_vsll_vv_i16m2(op1_v, shift_v, vl) __riscv_th_vsll_vv_i16m2(op1_v, shift_v, vl)
#define __riscv_vsll_vv_i16m4(op1_v, shift_v, vl) __riscv_th_vsll_vv_i16m4(op1_v, shift_v, vl)
#define __riscv_vsll_vv_i16m8(op1_v, shift_v, vl) __riscv_th_vsll_vv_i16m8(op1_v, shift_v, vl)
#define __riscv_vsll_vv_i32m1(op1_v, shift_v, vl) __riscv_th_vsll_vv_i32m1(op1_v, shift_v, vl)
#define __riscv_vsll_vv_i32m2(op1_v, shift_v, vl) __riscv_th_vsll_vv_i32m2(op1_v, shift_v, vl)
#define __riscv_vsll_vv_i32m4(op1_v, shift_v, vl) __riscv_th_vsll_vv_i32m4(op1_v, shift_v, vl)
#define __riscv_vsll_vv_i32m8(op1_v, shift_v, vl) __riscv_th_vsll_vv_i32m8(op1_v, shift_v, vl)
#define __riscv_vsll_vv_i64m1(op1_v, shift_v, vl) __riscv_th_vsll_vv_i64m1(op1_v, shift_v, vl)
#define __riscv_vsll_vv_i64m2(op1_v, shift_v, vl) __riscv_th_vsll_vv_i64m2(op1_v, shift_v, vl)
#define __riscv_vsll_vv_i64m4(op1_v, shift_v, vl) __riscv_th_vsll_vv_i64m4(op1_v, shift_v, vl)
#define __riscv_vsll_vv_i64m8(op1_v, shift_v, vl) __riscv_th_vsll_vv_i64m8(op1_v, shift_v, vl)

#define __riscv_vsll_vv_u8m1(op1_v, shift_v, vl) __riscv_th_vsll_vv_u8m1(op1_v, shift_v, vl)
#define __riscv_vsll_vv_u8m2(op1_v, shift_v, vl) __riscv_th_vsll_vv_u8m2(op1_v, shift_v, vl)
#define __riscv_vsll_vv_u8m4(op1_v, shift_v, vl) __riscv_th_vsll_vv_u8m4(op1_v, shift_v, vl)
#define __riscv_vsll_vv_u8m8(op1_v, shift_v, vl) __riscv_th_vsll_vv_u8m8(op1_v, shift_v, vl)
#define __riscv_vsll_vv_u16m1(op1_v, shift_v, vl) __riscv_th_vsll_vv_u16m1(op1_v, shift_v, vl)
#define __riscv_vsll_vv_u16m2(op1_v, shift_v, vl) __riscv_th_vsll_vv_u16m2(op1_v, shift_v, vl)
#define __riscv_vsll_vv_u16m4(op1_v, shift_v, vl) __riscv_th_vsll_vv_u16m4(op1_v, shift_v, vl)
#define __riscv_vsll_vv_u16m8(op1_v, shift_v, vl) __riscv_th_vsll_vv_u16m8(op1_v, shift_v, vl)
#define __riscv_vsll_vv_u32m1(op1_v, shift_v, vl) __riscv_th_vsll_vv_u32m1(op1_v, shift_v, vl)
#define __riscv_vsll_vv_u32m2(op1_v, shift_v, vl) __riscv_th_vsll_vv_u32m2(op1_v, shift_v, vl)
#define __riscv_vsll_vv_u32m4(op1_v, shift_v, vl) __riscv_th_vsll_vv_u32m4(op1_v, shift_v, vl)
#define __riscv_vsll_vv_u32m8(op1_v, shift_v, vl) __riscv_th_vsll_vv_u32m8(op1_v, shift_v, vl)
#define __riscv_vsll_vv_u64m1(op1_v, shift_v, vl) __riscv_th_vsll_vv_u64m1(op1_v, shift_v, vl)
#define __riscv_vsll_vv_u64m2(op1_v, shift_v, vl) __riscv_th_vsll_vv_u64m2(op1_v, shift_v, vl)
#define __riscv_vsll_vv_u64m4(op1_v, shift_v, vl) __riscv_th_vsll_vv_u64m4(op1_v, shift_v, vl)
#define __riscv_vsll_vv_u64m8(op1_v, shift_v, vl) __riscv_th_vsll_vv_u64m8(op1_v, shift_v, vl)

#define __riscv_vsll_vx_i8m1(op1_v, shift_x, vl) __riscv_th_vsll_vx_i8m1(op1_v, shift_x, vl)
#define __riscv_vsll_vx_i8m2(op1_v, shift_x, vl) __riscv_th_vsll_vx_i8m2(op1_v, shift_x, vl)
#define __riscv_vsll_vx_i8m4(op1_v, shift_x, vl) __riscv_th_vsll_vx_i8m4(op1_v, shift_x, vl)
#define __riscv_vsll_vx_i8m8(op1_v, shift_x, vl) __riscv_th_vsll_vx_i8m8(op1_v, shift_x, vl)
#define __riscv_vsll_vx_i16m1(op1_v, shift_x, vl) __riscv_th_vsll_vx_i16m1(op1_v, shift_x, vl)
#define __riscv_vsll_vx_i16m2(op1_v, shift_x, vl) __riscv_th_vsll_vx_i16m2(op1_v, shift_x, vl)
#define __riscv_vsll_vx_i16m4(op1_v, shift_x, vl) __riscv_th_vsll_vx_i16m4(op1_v, shift_x, vl)
#define __riscv_vsll_vx_i16m8(op1_v, shift_x, vl) __riscv_th_vsll_vx_i16m8(op1_v, shift_x, vl)
#define __riscv_vsll_vx_i32m1(op1_v, shift_x, vl) __riscv_th_vsll_vx_i32m1(op1_v, shift_x, vl)
#define __riscv_vsll_vx_i32m2(op1_v, shift_x, vl) __riscv_th_vsll_vx_i32m2(op1_v, shift_x, vl)
#define __riscv_vsll_vx_i32m4(op1_v, shift_x, vl) __riscv_th_vsll_vx_i32m4(op1_v, shift_x, vl)
#define __riscv_vsll_vx_i32m8(op1_v, shift_x, vl) __riscv_th_vsll_vx_i32m8(op1_v, shift_x, vl)
#define __riscv_vsll_vx_i64m1(op1_v, shift_x, vl) __riscv_th_vsll_vx_i64m1(op1_v, shift_x, vl)
#define __riscv_vsll_vx_i64m2(op1_v, shift_x, vl) __riscv_th_vsll_vx_i64m2(op1_v, shift_x, vl)
#define __riscv_vsll_vx_i64m4(op1_v, shift_x, vl) __riscv_th_vsll_vx_i64m4(op1_v, shift_x, vl)
#define __riscv_vsll_vx_i64m8(op1_v, shift_x, vl) __riscv_th_vsll_vx_i64m8(op1_v, shift_x, vl)

#define __riscv_vsll_vx_u8m1(op1_v, shift_x, vl) __riscv_th_vsll_vx_u8m1(op1_v, shift_x, vl)
#define __riscv_vsll_vx_u8m2(op1_v, shift_x, vl) __riscv_th_vsll_vx_u8m2(op1_v, shift_x, vl)
#define __riscv_vsll_vx_u8m4(op1_v, shift_x, vl) __riscv_th_vsll_vx_u8m4(op1_v, shift_x, vl)
#define __riscv_vsll_vx_u8m8(op1_v, shift_x, vl) __riscv_th_vsll_vx_u8m8(op1_v, shift_x, vl)
#define __riscv_vsll_vx_u16m1(op1_v, shift_x, vl) __riscv_th_vsll_vx_u16m1(op1_v, shift_x, vl)
#define __riscv_vsll_vx_u16m2(op1_v, shift_x, vl) __riscv_th_vsll_vx_u16m2(op1_v, shift_x, vl)
#define __riscv_vsll_vx_u16m4(op1_v, shift_x, vl) __riscv_th_vsll_vx_u16m4(op1_v, shift_x, vl)
#define __riscv_vsll_vx_u16m8(op1_v, shift_x, vl) __riscv_th_vsll_vx_u16m8(op1_v, shift_x, vl)
#define __riscv_vsll_vx_u32m1(op1_v, shift_x, vl) __riscv_th_vsll_vx_u32m1(op1_v, shift_x, vl)
#define __riscv_vsll_vx_u32m2(op1_v, shift_x, vl) __riscv_th_vsll_vx_u32m2(op1_v, shift_x, vl)
#define __riscv_vsll_vx_u32m4(op1_v, shift_x, vl) __riscv_th_vsll_vx_u32m4(op1_v, shift_x, vl)
#define __riscv_vsll_vx_u32m8(op1_v, shift_x, vl) __riscv_th_vsll_vx_u32m8(op1_v, shift_x, vl)
#define __riscv_vsll_vx_u64m1(op1_v, shift_x, vl) __riscv_th_vsll_vx_u64m1(op1_v, shift_x, vl)
#define __riscv_vsll_vx_u64m2(op1_v, shift_x, vl) __riscv_th_vsll_vx_u64m2(op1_v, shift_x, vl)
#define __riscv_vsll_vx_u64m4(op1_v, shift_x, vl) __riscv_th_vsll_vx_u64m4(op1_v, shift_x, vl)
#define __riscv_vsll_vx_u64m8(op1_v, shift_x, vl) __riscv_th_vsll_vx_u64m8(op1_v, shift_x, vl)

#define __riscv_vsrl_vv_u8m1(op1_v, shift_v, vl) __riscv_th_vsrl_vv_u8m1(op1_v, shift_v, vl)
#define __riscv_vsrl_vv_u8m2(op1_v, shift_v, vl) __riscv_th_vsrl_vv_u8m2(op1_v, shift_v, vl)
#define __riscv_vsrl_vv_u8m4(op1_v, shift_v, vl) __riscv_th_vsrl_vv_u8m4(op1_v, shift_v, vl)
#define __riscv_vsrl_vv_u8m8(op1_v, shift_v, vl) __riscv_th_vsrl_vv_u8m8(op1_v, shift_v, vl)
#define __riscv_vsrl_vv_u16m1(op1_v, shift_v, vl) __riscv_th_vsrl_vv_u16m1(op1_v, shift_v, vl)
#define __riscv_vsrl_vv_u16m2(op1_v, shift_v, vl) __riscv_th_vsrl_vv_u16m2(op1_v, shift_v, vl)
#define __riscv_vsrl_vv_u16m4(op1_v, shift_v, vl) __riscv_th_vsrl_vv_u16m4(op1_v, shift_v, vl)
#define __riscv_vsrl_vv_u16m8(op1_v, shift_v, vl) __riscv_th_vsrl_vv_u16m8(op1_v, shift_v, vl)
#define __riscv_vsrl_vv_u32m1(op1_v, shift_v, vl) __riscv_th_vsrl_vv_u32m1(op1_v, shift_v, vl)
#define __riscv_vsrl_vv_u32m2(op1_v, shift_v, vl) __riscv_th_vsrl_vv_u32m2(op1_v, shift_v, vl)
#define __riscv_vsrl_vv_u32m4(op1_v, shift_v, vl) __riscv_th_vsrl_vv_u32m4(op1_v, shift_v, vl)
#define __riscv_vsrl_vv_u32m8(op1_v, shift_v, vl) __riscv_th_vsrl_vv_u32m8(op1_v, shift_v, vl)
#define __riscv_vsrl_vv_u64m1(op1_v, shift_v, vl) __riscv_th_vsrl_vv_u64m1(op1_v, shift_v, vl)
#define __riscv_vsrl_vv_u64m2(op1_v, shift_v, vl) __riscv_th_vsrl_vv_u64m2(op1_v, shift_v, vl)
#define __riscv_vsrl_vv_u64m4(op1_v, shift_v, vl) __riscv_th_vsrl_vv_u64m4(op1_v, shift_v, vl)
#define __riscv_vsrl_vv_u64m8(op1_v, shift_v, vl) __riscv_th_vsrl_vv_u64m8(op1_v, shift_v, vl)

#define __riscv_vsrl_vx_u8m1(op1_v, shift_x, vl) __riscv_th_vsrl_vx_u8m1(op1_v, shift_x, vl)
#define __riscv_vsrl_vx_u8m2(op1_v, shift_x, vl) __riscv_th_vsrl_vx_u8m2(op1_v, shift_x, vl)
#define __riscv_vsrl_vx_u8m4(op1_v, shift_x, vl) __riscv_th_vsrl_vx_u8m4(op1_v, shift_x, vl)
#define __riscv_vsrl_vx_u8m8(op1_v, shift_x, vl) __riscv_th_vsrl_vx_u8m8(op1_v, shift_x, vl)
#define __riscv_vsrl_vx_u16m1(op1_v, shift_x, vl) __riscv_th_vsrl_vx_u16m1(op1_v, shift_x, vl)
#define __riscv_vsrl_vx_u16m2(op1_v, shift_x, vl) __riscv_th_vsrl_vx_u16m2(op1_v, shift_x, vl)
#define __riscv_vsrl_vx_u16m4(op1_v, shift_x, vl) __riscv_th_vsrl_vx_u16m4(op1_v, shift_x, vl)
#define __riscv_vsrl_vx_u16m8(op1_v, shift_x, vl) __riscv_th_vsrl_vx_u16m8(op1_v, shift_x, vl)
#define __riscv_vsrl_vx_u32m1(op1_v, shift_x, vl) __riscv_th_vsrl_vx_u32m1(op1_v, shift_x, vl)
#define __riscv_vsrl_vx_u32m2(op1_v, shift_x, vl) __riscv_th_vsrl_vx_u32m2(op1_v, shift_x, vl)
#define __riscv_vsrl_vx_u32m4(op1_v, shift_x, vl) __riscv_th_vsrl_vx_u32m4(op1_v, shift_x, vl)
#define __riscv_vsrl_vx_u32m8(op1_v, shift_x, vl) __riscv_th_vsrl_vx_u32m8(op1_v, shift_x, vl)
#define __riscv_vsrl_vx_u64m1(op1_v, shift_x, vl) __riscv_th_vsrl_vx_u64m1(op1_v, shift_x, vl)
#define __riscv_vsrl_vx_u64m2(op1_v, shift_x, vl) __riscv_th_vsrl_vx_u64m2(op1_v, shift_x, vl)
#define __riscv_vsrl_vx_u64m4(op1_v, shift_x, vl) __riscv_th_vsrl_vx_u64m4(op1_v, shift_x, vl)
#define __riscv_vsrl_vx_u64m8(op1_v, shift_x, vl) __riscv_th_vsrl_vx_u64m8(op1_v, shift_x, vl)

#define __riscv_vsra_vv_i8m1(op1_v, shift_v, vl) __riscv_th_vsra_vv_i8m1(op1_v, shift_v, vl)
#define __riscv_vsra_vv_i8m2(op1_v, shift_v, vl) __riscv_th_vsra_vv_i8m2(op1_v, shift_v, vl)
#define __riscv_vsra_vv_i8m4(op1_v, shift_v, vl) __riscv_th_vsra_vv_i8m4(op1_v, shift_v, vl)
#define __riscv_vsra_vv_i8m8(op1_v, shift_v, vl) __riscv_th_vsra_vv_i8m8(op1_v, shift_v, vl)
#define __riscv_vsra_vv_i16m1(op1_v, shift_v, vl) __riscv_th_vsra_vv_i16m1(op1_v, shift_v, vl)
#define __riscv_vsra_vv_i16m2(op1_v, shift_v, vl) __riscv_th_vsra_vv_i16m2(op1_v, shift_v, vl)
#define __riscv_vsra_vv_i16m4(op1_v, shift_v, vl) __riscv_th_vsra_vv_i16m4(op1_v, shift_v, vl)
#define __riscv_vsra_vv_i16m8(op1_v, shift_v, vl) __riscv_th_vsra_vv_i16m8(op1_v, shift_v, vl)
#define __riscv_vsra_vv_i32m1(op1_v, shift_v, vl) __riscv_th_vsra_vv_i32m1(op1_v, shift_v, vl)
#define __riscv_vsra_vv_i32m2(op1_v, shift_v, vl) __riscv_th_vsra_vv_i32m2(op1_v, shift_v, vl)
#define __riscv_vsra_vv_i32m4(op1_v, shift_v, vl) __riscv_th_vsra_vv_i32m4(op1_v, shift_v, vl)
#define __riscv_vsra_vv_i32m8(op1_v, shift_v, vl) __riscv_th_vsra_vv_i32m8(op1_v, shift_v, vl)
#define __riscv_vsra_vv_i64m1(op1_v, shift_v, vl) __riscv_th_vsra_vv_i64m1(op1_v, shift_v, vl)
#define __riscv_vsra_vv_i64m2(op1_v, shift_v, vl) __riscv_th_vsra_vv_i64m2(op1_v, shift_v, vl)
#define __riscv_vsra_vv_i64m4(op1_v, shift_v, vl) __riscv_th_vsra_vv_i64m4(op1_v, shift_v, vl)
#define __riscv_vsra_vv_i64m8(op1_v, shift_v, vl) __riscv_th_vsra_vv_i64m8(op1_v, shift_v, vl)

#define __riscv_vsra_vx_i8m1(op1_v, shift_x, vl) __riscv_th_vsra_vx_i8m1(op1_v, shift_x, vl)
#define __riscv_vsra_vx_i8m2(op1_v, shift_x, vl) __riscv_th_vsra_vx_i8m2(op1_v, shift_x, vl)
#define __riscv_vsra_vx_i8m4(op1_v, shift_x, vl) __riscv_th_vsra_vx_i8m4(op1_v, shift_x, vl)
#define __riscv_vsra_vx_i8m8(op1_v, shift_x, vl) __riscv_th_vsra_vx_i8m8(op1_v, shift_x, vl)
#define __riscv_vsra_vx_i16m1(op1_v, shift_x, vl) __riscv_th_vsra_vx_i16m1(op1_v, shift_x, vl)
#define __riscv_vsra_vx_i16m2(op1_v, shift_x, vl) __riscv_th_vsra_vx_i16m2(op1_v, shift_x, vl)
#define __riscv_vsra_vx_i16m4(op1_v, shift_x, vl) __riscv_th_vsra_vx_i16m4(op1_v, shift_x, vl)
#define __riscv_vsra_vx_i16m8(op1_v, shift_x, vl) __riscv_th_vsra_vx_i16m8(op1_v, shift_x, vl)
#define __riscv_vsra_vx_i32m1(op1_v, shift_x, vl) __riscv_th_vsra_vx_i32m1(op1_v, shift_x, vl)
#define __riscv_vsra_vx_i32m2(op1_v, shift_x, vl) __riscv_th_vsra_vx_i32m2(op1_v, shift_x, vl)
#define __riscv_vsra_vx_i32m4(op1_v, shift_x, vl) __riscv_th_vsra_vx_i32m4(op1_v, shift_x, vl)
#define __riscv_vsra_vx_i32m8(op1_v, shift_x, vl) __riscv_th_vsra_vx_i32m8(op1_v, shift_x, vl)
#define __riscv_vsra_vx_i64m1(op1_v, shift_x, vl) __riscv_th_vsra_vx_i64m1(op1_v, shift_x, vl)
#define __riscv_vsra_vx_i64m2(op1_v, shift_x, vl) __riscv_th_vsra_vx_i64m2(op1_v, shift_x, vl)
#define __riscv_vsra_vx_i64m4(op1_v, shift_x, vl) __riscv_th_vsra_vx_i64m4(op1_v, shift_x, vl)
#define __riscv_vsra_vx_i64m8(op1_v, shift_x, vl) __riscv_th_vsra_vx_i64m8(op1_v, shift_x, vl)


// Vector Single-Width Saturating Add and Subtract
#define __riscv_vsadd_vv_i8m1(op1, op2, vl) __riscv_th_vsadd_vv_i8m1(op1, op2, vl)
#define __riscv_vsadd_vx_i8m1(op1, op2, vl) __riscv_th_vsadd_vx_i8m1(op1, op2, vl)
#define __riscv_vsadd_vv_i8m2(op1, op2, vl) __riscv_th_vsadd_vv_i8m2(op1, op2, vl)
#define __riscv_vsadd_vx_i8m2(op1, op2, vl) __riscv_th_vsadd_vx_i8m2(op1, op2, vl)
#define __riscv_vsadd_vv_i8m4(op1, op2, vl) __riscv_th_vsadd_vv_i8m4(op1, op2, vl)
#define __riscv_vsadd_vx_i8m4(op1, op2, vl) __riscv_th_vsadd_vx_i8m4(op1, op2, vl)
#define __riscv_vsadd_vv_i8m8(op1, op2, vl) __riscv_th_vsadd_vv_i8m8(op1, op2, vl)
#define __riscv_vsadd_vx_i8m8(op1, op2, vl) __riscv_th_vsadd_vx_i8m8(op1, op2, vl)
#define __riscv_vsadd_vv_i16m1(op1, op2, vl) __riscv_th_vsadd_vv_i16m1(op1, op2, vl)
#define __riscv_vsadd_vx_i16m1(op1, op2, vl) __riscv_th_vsadd_vx_i16m1(op1, op2, vl)
#define __riscv_vsadd_vv_i16m2(op1, op2, vl) __riscv_th_vsadd_vv_i16m2(op1, op2, vl)
#define __riscv_vsadd_vx_i16m2(op1, op2, vl) __riscv_th_vsadd_vx_i16m2(op1, op2, vl)
#define __riscv_vsadd_vv_i16m4(op1, op2, vl) __riscv_th_vsadd_vv_i16m4(op1, op2, vl)
#define __riscv_vsadd_vx_i16m4(op1, op2, vl) __riscv_th_vsadd_vx_i16m4(op1, op2, vl)
#define __riscv_vsadd_vv_i16m8(op1, op2, vl) __riscv_th_vsadd_vv_i16m8(op1, op2, vl)
#define __riscv_vsadd_vx_i16m8(op1, op2, vl) __riscv_th_vsadd_vx_i16m8(op1, op2, vl)
#define __riscv_vsadd_vv_i32m1(op1, op2, vl) __riscv_th_vsadd_vv_i32m1(op1, op2, vl)
#define __riscv_vsadd_vx_i32m1(op1, op2, vl) __riscv_th_vsadd_vx_i32m1(op1, op2, vl)
#define __riscv_vsadd_vv_i32m2(op1, op2, vl) __riscv_th_vsadd_vv_i32m2(op1, op2, vl)
#define __riscv_vsadd_vx_i32m2(op1, op2, vl) __riscv_th_vsadd_vx_i32m2(op1, op2, vl)
#define __riscv_vsadd_vv_i32m4(op1, op2, vl) __riscv_th_vsadd_vv_i32m4(op1, op2, vl)
#define __riscv_vsadd_vx_i32m4(op1, op2, vl) __riscv_th_vsadd_vx_i32m4(op1, op2, vl)
#define __riscv_vsadd_vv_i32m8(op1, op2, vl) __riscv_th_vsadd_vv_i32m8(op1, op2, vl)
#define __riscv_vsadd_vx_i32m8(op1, op2, vl) __riscv_th_vsadd_vx_i32m8(op1, op2, vl)
#define __riscv_vsadd_vv_i64m1(op1, op2, vl) __riscv_th_vsadd_vv_i64m1(op1, op2, vl)
#define __riscv_vsadd_vx_i64m1(op1, op2, vl) __riscv_th_vsadd_vx_i64m1(op1, op2, vl)
#define __riscv_vsadd_vv_i64m2(op1, op2, vl) __riscv_th_vsadd_vv_i64m2(op1, op2, vl)
#define __riscv_vsadd_vx_i64m2(op1, op2, vl) __riscv_th_vsadd_vx_i64m2(op1, op2, vl)
#define __riscv_vsadd_vv_i64m4(op1, op2, vl) __riscv_th_vsadd_vv_i64m4(op1, op2, vl)
#define __riscv_vsadd_vx_i64m4(op1, op2, vl) __riscv_th_vsadd_vx_i64m4(op1, op2, vl)
#define __riscv_vsadd_vv_i64m8(op1, op2, vl) __riscv_th_vsadd_vv_i64m8(op1, op2, vl)
#define __riscv_vsadd_vx_i64m8(op1, op2, vl) __riscv_th_vsadd_vx_i64m8(op1, op2, vl)

#define __riscv_vsadd_vv_i8m1_m(mask, op1, op2, vl) __riscv_th_vsadd_vv_i8m1_m(mask, op1, op2, vl)
#define __riscv_vsadd_vx_i8m1_m(mask, op1, op2, vl) __riscv_th_vsadd_vx_i8m1_m(mask, op1, op2, vl)
#define __riscv_vsadd_vv_i8m2_m(mask, op1, op2, vl) __riscv_th_vsadd_vv_i8m2_m(mask, op1, op2, vl)
#define __riscv_vsadd_vx_i8m2_m(mask, op1, op2, vl) __riscv_th_vsadd_vx_i8m2_m(mask, op1, op2, vl)
#define __riscv_vsadd_vv_i8m4_m(mask, op1, op2, vl) __riscv_th_vsadd_vv_i8m4_m(mask, op1, op2, vl)
#define __riscv_vsadd_vx_i8m4_m(mask, op1, op2, vl) __riscv_th_vsadd_vx_i8m4_m(mask, op1, op2, vl)
#define __riscv_vsadd_vv_i8m8_m(mask, op1, op2, vl) __riscv_th_vsadd_vv_i8m8_m(mask, op1, op2, vl)
#define __riscv_vsadd_vx_i8m8_m(mask, op1, op2, vl) __riscv_th_vsadd_vx_i8m8_m(mask, op1, op2, vl)
#define __riscv_vsadd_vv_i16m1_m(mask, op1, op2, vl) __riscv_th_vsadd_vv_i16m1_m(mask, op1, op2, vl)
#define __riscv_vsadd_vx_i16m1_m(mask, op1, op2, vl) __riscv_th_vsadd_vx_i16m1_m(mask, op1, op2, vl)
#define __riscv_vsadd_vv_i16m2_m(mask, op1, op2, vl) __riscv_th_vsadd_vv_i16m2_m(mask, op1, op2, vl)
#define __riscv_vsadd_vx_i16m2_m(mask, op1, op2, vl) __riscv_th_vsadd_vx_i16m2_m(mask, op1, op2, vl)
#define __riscv_vsadd_vv_i16m4_m(mask, op1, op2, vl) __riscv_th_vsadd_vv_i16m4_m(mask, op1, op2, vl)
#define __riscv_vsadd_vx_i16m4_m(mask, op1, op2, vl) __riscv_th_vsadd_vx_i16m4_m(mask, op1, op2, vl)
#define __riscv_vsadd_vv_i16m8_m(mask, op1, op2, vl) __riscv_th_vsadd_vv_i16m8_m(mask, op1, op2, vl)
#define __riscv_vsadd_vx_i16m8_m(mask, op1, op2, vl) __riscv_th_vsadd_vx_i16m8_m(mask, op1, op2, vl)
#define __riscv_vsadd_vv_i32m1_m(mask, op1, op2, vl) __riscv_th_vsadd_vv_i32m1_m(mask, op1, op2, vl)
#define __riscv_vsadd_vx_i32m1_m(mask, op1, op2, vl) __riscv_th_vsadd_vx_i32m1_m(mask, op1, op2, vl)
#define __riscv_vsadd_vv_i32m2_m(mask, op1, op2, vl) __riscv_th_vsadd_vv_i32m2_m(mask, op1, op2, vl)
#define __riscv_vsadd_vx_i32m2_m(mask, op1, op2, vl) __riscv_th_vsadd_vx_i32m2_m(mask, op1, op2, vl)
#define __riscv_vsadd_vv_i32m4_m(mask, op1, op2, vl) __riscv_th_vsadd_vv_i32m4_m(mask, op1, op2, vl)
#define __riscv_vsadd_vx_i32m4_m(mask, op1, op2, vl) __riscv_th_vsadd_vx_i32m4_m(mask, op1, op2, vl)
#define __riscv_vsadd_vv_i32m8_m(mask, op1, op2, vl) __riscv_th_vsadd_vv_i32m8_m(mask, op1, op2, vl)
#define __riscv_vsadd_vx_i32m8_m(mask, op1, op2, vl) __riscv_th_vsadd_vx_i32m8_m(mask, op1, op2, vl)
#define __riscv_vsadd_vv_i64m1_m(mask, op1, op2, vl) __riscv_th_vsadd_vv_i64m1_m(mask, op1, op2, vl)
#define __riscv_vsadd_vx_i64m1_m(mask, op1, op2, vl) __riscv_th_vsadd_vx_i64m1_m(mask, op1, op2, vl)
#define __riscv_vsadd_vv_i64m2_m(mask, op1, op2, vl) __riscv_th_vsadd_vv_i64m2_m(mask, op1, op2, vl)
#define __riscv_vsadd_vx_i64m2_m(mask, op1, op2, vl) __riscv_th_vsadd_vx_i64m2_m(mask, op1, op2, vl)
#define __riscv_vsadd_vv_i64m4_m(mask, op1, op2, vl) __riscv_th_vsadd_vv_i64m4_m(mask, op1, op2, vl)
#define __riscv_vsadd_vx_i64m4_m(mask, op1, op2, vl) __riscv_th_vsadd_vx_i64m4_m(mask, op1, op2, vl)
#define __riscv_vsadd_vv_i64m8_m(mask, op1, op2, vl) __riscv_th_vsadd_vv_i64m8_m(mask, op1, op2, vl)
#define __riscv_vsadd_vx_i64m8_m(mask, op1, op2, vl) __riscv_th_vsadd_vx_i64m8_m(mask, op1, op2, vl)

#define __riscv_vssub_vv_i8m1(op1, op2, vl) __riscv_th_vssub_vv_i8m1(op1, op2, vl)
#define __riscv_vssub_vx_i8m1(op1, op2, vl) __riscv_th_vssub_vx_i8m1(op1, op2, vl)
#define __riscv_vssub_vv_i8m2(op1, op2, vl) __riscv_th_vssub_vv_i8m2(op1, op2, vl)
#define __riscv_vssub_vx_i8m2(op1, op2, vl) __riscv_th_vssub_vx_i8m2(op1, op2, vl)
#define __riscv_vssub_vv_i8m4(op1, op2, vl) __riscv_th_vssub_vv_i8m4(op1, op2, vl)
#define __riscv_vssub_vx_i8m4(op1, op2, vl) __riscv_th_vssub_vx_i8m4(op1, op2, vl)
#define __riscv_vssub_vv_i8m8(op1, op2, vl) __riscv_th_vssub_vv_i8m8(op1, op2, vl)
#define __riscv_vssub_vx_i8m8(op1, op2, vl) __riscv_th_vssub_vx_i8m8(op1, op2, vl)
#define __riscv_vssub_vv_i16m1(op1, op2, vl) __riscv_th_vssub_vv_i16m1(op1, op2, vl)
#define __riscv_vssub_vx_i16m1(op1, op2, vl) __riscv_th_vssub_vx_i16m1(op1, op2, vl)
#define __riscv_vssub_vv_i16m2(op1, op2, vl) __riscv_th_vssub_vv_i16m2(op1, op2, vl)
#define __riscv_vssub_vx_i16m2(op1, op2, vl) __riscv_th_vssub_vx_i16m2(op1, op2, vl)
#define __riscv_vssub_vv_i16m4(op1, op2, vl) __riscv_th_vssub_vv_i16m4(op1, op2, vl)
#define __riscv_vssub_vx_i16m4(op1, op2, vl) __riscv_th_vssub_vx_i16m4(op1, op2, vl)
#define __riscv_vssub_vv_i16m8(op1, op2, vl) __riscv_th_vssub_vv_i16m8(op1, op2, vl)
#define __riscv_vssub_vx_i16m8(op1, op2, vl) __riscv_th_vssub_vx_i16m8(op1, op2, vl)
#define __riscv_vssub_vv_i32m1(op1, op2, vl) __riscv_th_vssub_vv_i32m1(op1, op2, vl)
#define __riscv_vssub_vx_i32m1(op1, op2, vl) __riscv_th_vssub_vx_i32m1(op1, op2, vl)
#define __riscv_vssub_vv_i32m2(op1, op2, vl) __riscv_th_vssub_vv_i32m2(op1, op2, vl)
#define __riscv_vssub_vx_i32m2(op1, op2, vl) __riscv_th_vssub_vx_i32m2(op1, op2, vl)
#define __riscv_vssub_vv_i32m4(op1, op2, vl) __riscv_th_vssub_vv_i32m4(op1, op2, vl)
#define __riscv_vssub_vx_i32m4(op1, op2, vl) __riscv_th_vssub_vx_i32m4(op1, op2, vl)
#define __riscv_vssub_vv_i32m8(op1, op2, vl) __riscv_th_vssub_vv_i32m8(op1, op2, vl)
#define __riscv_vssub_vx_i32m8(op1, op2, vl) __riscv_th_vssub_vx_i32m8(op1, op2, vl)
#define __riscv_vssub_vv_i64m1(op1, op2, vl) __riscv_th_vssub_vv_i64m1(op1, op2, vl)
#define __riscv_vssub_vx_i64m1(op1, op2, vl) __riscv_th_vssub_vx_i64m1(op1, op2, vl)
#define __riscv_vssub_vv_i64m2(op1, op2, vl) __riscv_th_vssub_vv_i64m2(op1, op2, vl)
#define __riscv_vssub_vx_i64m2(op1, op2, vl) __riscv_th_vssub_vx_i64m2(op1, op2, vl)
#define __riscv_vssub_vv_i64m4(op1, op2, vl) __riscv_th_vssub_vv_i64m4(op1, op2, vl)
#define __riscv_vssub_vx_i64m4(op1, op2, vl) __riscv_th_vssub_vx_i64m4(op1, op2, vl)
#define __riscv_vssub_vv_i64m8(op1, op2, vl) __riscv_th_vssub_vv_i64m8(op1, op2, vl)
#define __riscv_vssub_vx_i64m8(op1, op2, vl) __riscv_th_vssub_vx_i64m8(op1, op2, vl)

#define __riscv_vssub_vv_i8m1_m(mask, op1, op2, vl) __riscv_th_vssub_vv_i8m1_m(mask, op1, op2, vl)
#define __riscv_vssub_vx_i8m1_m(mask, op1, op2, vl) __riscv_th_vssub_vx_i8m1_m(mask, op1, op2, vl)
#define __riscv_vssub_vv_i8m2_m(mask, op1, op2, vl) __riscv_th_vssub_vv_i8m2_m(mask, op1, op2, vl)
#define __riscv_vssub_vx_i8m2_m(mask, op1, op2, vl) __riscv_th_vssub_vx_i8m2_m(mask, op1, op2, vl)
#define __riscv_vssub_vv_i8m4_m(mask, op1, op2, vl) __riscv_th_vssub_vv_i8m4_m(mask, op1, op2, vl)
#define __riscv_vssub_vx_i8m4_m(mask, op1, op2, vl) __riscv_th_vssub_vx_i8m4_m(mask, op1, op2, vl)
#define __riscv_vssub_vv_i8m8_m(mask, op1, op2, vl) __riscv_th_vssub_vv_i8m8_m(mask, op1, op2, vl)
#define __riscv_vssub_vx_i8m8_m(mask, op1, op2, vl) __riscv_th_vssub_vx_i8m8_m(mask, op1, op2, vl)
#define __riscv_vssub_vv_i16m1_m(mask, op1, op2, vl) __riscv_th_vssub_vv_i16m1_m(mask, op1, op2, vl)
#define __riscv_vssub_vx_i16m1_m(mask, op1, op2, vl) __riscv_th_vssub_vx_i16m1_m(mask, op1, op2, vl)
#define __riscv_vssub_vv_i16m2_m(mask, op1, op2, vl) __riscv_th_vssub_vv_i16m2_m(mask, op1, op2, vl)
#define __riscv_vssub_vx_i16m2_m(mask, op1, op2, vl) __riscv_th_vssub_vx_i16m2_m(mask, op1, op2, vl)
#define __riscv_vssub_vv_i16m4_m(mask, op1, op2, vl) __riscv_th_vssub_vv_i16m4_m(mask, op1, op2, vl)
#define __riscv_vssub_vx_i16m4_m(mask, op1, op2, vl) __riscv_th_vssub_vx_i16m4_m(mask, op1, op2, vl)
#define __riscv_vssub_vv_i16m8_m(mask, op1, op2, vl) __riscv_th_vssub_vv_i16m8_m(mask, op1, op2, vl)
#define __riscv_vssub_vx_i16m8_m(mask, op1, op2, vl) __riscv_th_vssub_vx_i16m8_m(mask, op1, op2, vl)
#define __riscv_vssub_vv_i32m1_m(mask, op1, op2, vl) __riscv_th_vssub_vv_i32m1_m(mask, op1, op2, vl)
#define __riscv_vssub_vx_i32m1_m(mask, op1, op2, vl) __riscv_th_vssub_vx_i32m1_m(mask, op1, op2, vl)
#define __riscv_vssub_vv_i32m2_m(mask, op1, op2, vl) __riscv_th_vssub_vv_i32m2_m(mask, op1, op2, vl)
#define __riscv_vssub_vx_i32m2_m(mask, op1, op2, vl) __riscv_th_vssub_vx_i32m2_m(mask, op1, op2, vl)
#define __riscv_vssub_vv_i32m4_m(mask, op1, op2, vl) __riscv_th_vssub_vv_i32m4_m(mask, op1, op2, vl)
#define __riscv_vssub_vx_i32m4_m(mask, op1, op2, vl) __riscv_th_vssub_vx_i32m4_m(mask, op1, op2, vl)
#define __riscv_vssub_vv_i32m8_m(mask, op1, op2, vl) __riscv_th_vssub_vv_i32m8_m(mask, op1, op2, vl)
#define __riscv_vssub_vx_i32m8_m(mask, op1, op2, vl) __riscv_th_vssub_vx_i32m8_m(mask, op1, op2, vl)
#define __riscv_vssub_vv_i64m1_m(mask, op1, op2, vl) __riscv_th_vssub_vv_i64m1_m(mask, op1, op2, vl)
#define __riscv_vssub_vx_i64m1_m(mask, op1, op2, vl) __riscv_th_vssub_vx_i64m1_m(mask, op1, op2, vl)
#define __riscv_vssub_vv_i64m2_m(mask, op1, op2, vl) __riscv_th_vssub_vv_i64m2_m(mask, op1, op2, vl)
#define __riscv_vssub_vx_i64m2_m(mask, op1, op2, vl) __riscv_th_vssub_vx_i64m2_m(mask, op1, op2, vl)
#define __riscv_vssub_vv_i64m4_m(mask, op1, op2, vl) __riscv_th_vssub_vv_i64m4_m(mask, op1, op2, vl)
#define __riscv_vssub_vx_i64m4_m(mask, op1, op2, vl) __riscv_th_vssub_vx_i64m4_m(mask, op1, op2, vl)
#define __riscv_vssub_vv_i64m8_m(mask, op1, op2, vl) __riscv_th_vssub_vv_i64m8_m(mask, op1, op2, vl)
#define __riscv_vssub_vx_i64m8_m(mask, op1, op2, vl) __riscv_th_vssub_vx_i64m8_m(mask, op1, op2, vl)

#define __riscv_vsaddu_vv_u8m1(op1, op2, vl) __riscv_th_vsaddu_vv_u8m1(op1, op2, vl)
#define __riscv_vsaddu_vx_u8m1(op1, op2, vl) __riscv_th_vsaddu_vx_u8m1(op1, op2, vl)
#define __riscv_vsaddu_vv_u8m2(op1, op2, vl) __riscv_th_vsaddu_vv_u8m2(op1, op2, vl)
#define __riscv_vsaddu_vx_u8m2(op1, op2, vl) __riscv_th_vsaddu_vx_u8m2(op1, op2, vl)
#define __riscv_vsaddu_vv_u8m4(op1, op2, vl) __riscv_th_vsaddu_vv_u8m4(op1, op2, vl)
#define __riscv_vsaddu_vx_u8m4(op1, op2, vl) __riscv_th_vsaddu_vx_u8m4(op1, op2, vl)
#define __riscv_vsaddu_vv_u8m8(op1, op2, vl) __riscv_th_vsaddu_vv_u8m8(op1, op2, vl)
#define __riscv_vsaddu_vx_u8m8(op1, op2, vl) __riscv_th_vsaddu_vx_u8m8(op1, op2, vl)
#define __riscv_vsaddu_vv_u16m1(op1, op2, vl) __riscv_th_vsaddu_vv_u16m1(op1, op2, vl)
#define __riscv_vsaddu_vx_u16m1(op1, op2, vl) __riscv_th_vsaddu_vx_u16m1(op1, op2, vl)
#define __riscv_vsaddu_vv_u16m2(op1, op2, vl) __riscv_th_vsaddu_vv_u16m2(op1, op2, vl)
#define __riscv_vsaddu_vx_u16m2(op1, op2, vl) __riscv_th_vsaddu_vx_u16m2(op1, op2, vl)
#define __riscv_vsaddu_vv_u16m4(op1, op2, vl) __riscv_th_vsaddu_vv_u16m4(op1, op2, vl)
#define __riscv_vsaddu_vx_u16m4(op1, op2, vl) __riscv_th_vsaddu_vx_u16m4(op1, op2, vl)
#define __riscv_vsaddu_vv_u16m8(op1, op2, vl) __riscv_th_vsaddu_vv_u16m8(op1, op2, vl)
#define __riscv_vsaddu_vx_u16m8(op1, op2, vl) __riscv_th_vsaddu_vx_u16m8(op1, op2, vl)
#define __riscv_vsaddu_vv_u32m1(op1, op2, vl) __riscv_th_vsaddu_vv_u32m1(op1, op2, vl)
#define __riscv_vsaddu_vx_u32m1(op1, op2, vl) __riscv_th_vsaddu_vx_u32m1(op1, op2, vl)
#define __riscv_vsaddu_vv_u32m2(op1, op2, vl) __riscv_th_vsaddu_vv_u32m2(op1, op2, vl)
#define __riscv_vsaddu_vx_u32m2(op1, op2, vl) __riscv_th_vsaddu_vx_u32m2(op1, op2, vl)
#define __riscv_vsaddu_vv_u32m4(op1, op2, vl) __riscv_th_vsaddu_vv_u32m4(op1, op2, vl)
#define __riscv_vsaddu_vx_u32m4(op1, op2, vl) __riscv_th_vsaddu_vx_u32m4(op1, op2, vl)
#define __riscv_vsaddu_vv_u32m8(op1, op2, vl) __riscv_th_vsaddu_vv_u32m8(op1, op2, vl)
#define __riscv_vsaddu_vx_u32m8(op1, op2, vl) __riscv_th_vsaddu_vx_u32m8(op1, op2, vl)
#define __riscv_vsaddu_vv_u64m1(op1, op2, vl) __riscv_th_vsaddu_vv_u64m1(op1, op2, vl)
#define __riscv_vsaddu_vx_u64m1(op1, op2, vl) __riscv_th_vsaddu_vx_u64m1(op1, op2, vl)
#define __riscv_vsaddu_vv_u64m2(op1, op2, vl) __riscv_th_vsaddu_vv_u64m2(op1, op2, vl)
#define __riscv_vsaddu_vx_u64m2(op1, op2, vl) __riscv_th_vsaddu_vx_u64m2(op1, op2, vl)
#define __riscv_vsaddu_vv_u64m4(op1, op2, vl) __riscv_th_vsaddu_vv_u64m4(op1, op2, vl)
#define __riscv_vsaddu_vx_u64m4(op1, op2, vl) __riscv_th_vsaddu_vx_u64m4(op1, op2, vl)
#define __riscv_vsaddu_vv_u64m8(op1, op2, vl) __riscv_th_vsaddu_vv_u64m8(op1, op2, vl)
#define __riscv_vsaddu_vx_u64m8(op1, op2, vl) __riscv_th_vsaddu_vx_u64m8(op1, op2, vl)

#define __riscv_vsaddu_vv_u8m1_m(mask, op1, op2, vl) __riscv_th_vsaddu_vv_u8m1_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vx_u8m1_m(mask, op1, op2, vl) __riscv_th_vsaddu_vx_u8m1_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vv_u8m2_m(mask, op1, op2, vl) __riscv_th_vsaddu_vv_u8m2_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vx_u8m2_m(mask, op1, op2, vl) __riscv_th_vsaddu_vx_u8m2_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vv_u8m4_m(mask, op1, op2, vl) __riscv_th_vsaddu_vv_u8m4_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vx_u8m4_m(mask, op1, op2, vl) __riscv_th_vsaddu_vx_u8m4_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vv_u8m8_m(mask, op1, op2, vl) __riscv_th_vsaddu_vv_u8m8_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vx_u8m8_m(mask, op1, op2, vl) __riscv_th_vsaddu_vx_u8m8_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vv_u16m1_m(mask, op1, op2, vl) __riscv_th_vsaddu_vv_u16m1_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vx_u16m1_m(mask, op1, op2, vl) __riscv_th_vsaddu_vx_u16m1_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vv_u16m2_m(mask, op1, op2, vl) __riscv_th_vsaddu_vv_u16m2_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vx_u16m2_m(mask, op1, op2, vl) __riscv_th_vsaddu_vx_u16m2_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vv_u16m4_m(mask, op1, op2, vl) __riscv_th_vsaddu_vv_u16m4_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vx_u16m4_m(mask, op1, op2, vl) __riscv_th_vsaddu_vx_u16m4_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vv_u16m8_m(mask, op1, op2, vl) __riscv_th_vsaddu_vv_u16m8_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vx_u16m8_m(mask, op1, op2, vl) __riscv_th_vsaddu_vx_u16m8_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vv_u32m1_m(mask, op1, op2, vl) __riscv_th_vsaddu_vv_u32m1_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vx_u32m1_m(mask, op1, op2, vl) __riscv_th_vsaddu_vx_u32m1_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vv_u32m2_m(mask, op1, op2, vl) __riscv_th_vsaddu_vv_u32m2_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vx_u32m2_m(mask, op1, op2, vl) __riscv_th_vsaddu_vx_u32m2_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vv_u32m4_m(mask, op1, op2, vl) __riscv_th_vsaddu_vv_u32m4_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vx_u32m4_m(mask, op1, op2, vl) __riscv_th_vsaddu_vx_u32m4_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vv_u32m8_m(mask, op1, op2, vl) __riscv_th_vsaddu_vv_u32m8_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vx_u32m8_m(mask, op1, op2, vl) __riscv_th_vsaddu_vx_u32m8_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vv_u64m1_m(mask, op1, op2, vl) __riscv_th_vsaddu_vv_u64m1_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vx_u64m1_m(mask, op1, op2, vl) __riscv_th_vsaddu_vx_u64m1_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vv_u64m2_m(mask, op1, op2, vl) __riscv_th_vsaddu_vv_u64m2_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vx_u64m2_m(mask, op1, op2, vl) __riscv_th_vsaddu_vx_u64m2_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vv_u64m4_m(mask, op1, op2, vl) __riscv_th_vsaddu_vv_u64m4_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vx_u64m4_m(mask, op1, op2, vl) __riscv_th_vsaddu_vx_u64m4_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vv_u64m8_m(mask, op1, op2, vl) __riscv_th_vsaddu_vv_u64m8_m(mask, op1, op2, vl)
#define __riscv_vsaddu_vx_u64m8_m(mask, op1, op2, vl) __riscv_th_vsaddu_vx_u64m8_m(mask, op1, op2, vl)

#define __riscv_vssubu_vv_u8m1(op1, op2, vl) __riscv_th_vssubu_vv_u8m1(op1, op2, vl)
#define __riscv_vssubu_vx_u8m1(op1, op2, vl) __riscv_th_vssubu_vx_u8m1(op1, op2, vl)
#define __riscv_vssubu_vv_u8m2(op1, op2, vl) __riscv_th_vssubu_vv_u8m2(op1, op2, vl)
#define __riscv_vssubu_vx_u8m2(op1, op2, vl) __riscv_th_vssubu_vx_u8m2(op1, op2, vl)
#define __riscv_vssubu_vv_u8m4(op1, op2, vl) __riscv_th_vssubu_vv_u8m4(op1, op2, vl)
#define __riscv_vssubu_vx_u8m4(op1, op2, vl) __riscv_th_vssubu_vx_u8m4(op1, op2, vl)
#define __riscv_vssubu_vv_u8m8(op1, op2, vl) __riscv_th_vssubu_vv_u8m8(op1, op2, vl)
#define __riscv_vssubu_vx_u8m8(op1, op2, vl) __riscv_th_vssubu_vx_u8m8(op1, op2, vl)
#define __riscv_vssubu_vv_u16m1(op1, op2, vl) __riscv_th_vssubu_vv_u16m1(op1, op2, vl)
#define __riscv_vssubu_vx_u16m1(op1, op2, vl) __riscv_th_vssubu_vx_u16m1(op1, op2, vl)
#define __riscv_vssubu_vv_u16m2(op1, op2, vl) __riscv_th_vssubu_vv_u16m2(op1, op2, vl)
#define __riscv_vssubu_vx_u16m2(op1, op2, vl) __riscv_th_vssubu_vx_u16m2(op1, op2, vl)
#define __riscv_vssubu_vv_u16m4(op1, op2, vl) __riscv_th_vssubu_vv_u16m4(op1, op2, vl)
#define __riscv_vssubu_vx_u16m4(op1, op2, vl) __riscv_th_vssubu_vx_u16m4(op1, op2, vl)
#define __riscv_vssubu_vv_u16m8(op1, op2, vl) __riscv_th_vssubu_vv_u16m8(op1, op2, vl)
#define __riscv_vssubu_vx_u16m8(op1, op2, vl) __riscv_th_vssubu_vx_u16m8(op1, op2, vl)
#define __riscv_vssubu_vv_u32m1(op1, op2, vl) __riscv_th_vssubu_vv_u32m1(op1, op2, vl)
#define __riscv_vssubu_vx_u32m1(op1, op2, vl) __riscv_th_vssubu_vx_u32m1(op1, op2, vl)
#define __riscv_vssubu_vv_u32m2(op1, op2, vl) __riscv_th_vssubu_vv_u32m2(op1, op2, vl)
#define __riscv_vssubu_vx_u32m2(op1, op2, vl) __riscv_th_vssubu_vx_u32m2(op1, op2, vl)
#define __riscv_vssubu_vv_u32m4(op1, op2, vl) __riscv_th_vssubu_vv_u32m4(op1, op2, vl)
#define __riscv_vssubu_vx_u32m4(op1, op2, vl) __riscv_th_vssubu_vx_u32m4(op1, op2, vl)
#define __riscv_vssubu_vv_u32m8(op1, op2, vl) __riscv_th_vssubu_vv_u32m8(op1, op2, vl)
#define __riscv_vssubu_vx_u32m8(op1, op2, vl) __riscv_th_vssubu_vx_u32m8(op1, op2, vl)
#define __riscv_vssubu_vv_u64m1(op1, op2, vl) __riscv_th_vssubu_vv_u64m1(op1, op2, vl)
#define __riscv_vssubu_vx_u64m1(op1, op2, vl) __riscv_th_vssubu_vx_u64m1(op1, op2, vl)
#define __riscv_vssubu_vv_u64m2(op1, op2, vl) __riscv_th_vssubu_vv_u64m2(op1, op2, vl)
#define __riscv_vssubu_vx_u64m2(op1, op2, vl) __riscv_th_vssubu_vx_u64m2(op1, op2, vl)
#define __riscv_vssubu_vv_u64m4(op1, op2, vl) __riscv_th_vssubu_vv_u64m4(op1, op2, vl)
#define __riscv_vssubu_vx_u64m4(op1, op2, vl) __riscv_th_vssubu_vx_u64m4(op1, op2, vl)
#define __riscv_vssubu_vv_u64m8(op1, op2, vl) __riscv_th_vssubu_vv_u64m8(op1, op2, vl)
#define __riscv_vssubu_vx_u64m8(op1, op2, vl) __riscv_th_vssubu_vx_u64m8(op1, op2, vl)

#define __riscv_vssubu_vv_u8m1_m(mask, op1, op2, vl) __riscv_th_vssubu_vv_u8m1_m(mask, op1, op2, vl)
#define __riscv_vssubu_vx_u8m1_m(mask, op1, op2, vl) __riscv_th_vssubu_vx_u8m1_m(mask, op1, op2, vl)
#define __riscv_vssubu_vv_u8m2_m(mask, op1, op2, vl) __riscv_th_vssubu_vv_u8m2_m(mask, op1, op2, vl)
#define __riscv_vssubu_vx_u8m2_m(mask, op1, op2, vl) __riscv_th_vssubu_vx_u8m2_m(mask, op1, op2, vl)
#define __riscv_vssubu_vv_u8m4_m(mask, op1, op2, vl) __riscv_th_vssubu_vv_u8m4_m(mask, op1, op2, vl)
#define __riscv_vssubu_vx_u8m4_m(mask, op1, op2, vl) __riscv_th_vssubu_vx_u8m4_m(mask, op1, op2, vl)
#define __riscv_vssubu_vv_u8m8_m(mask, op1, op2, vl) __riscv_th_vssubu_vv_u8m8_m(mask, op1, op2, vl)
#define __riscv_vssubu_vx_u8m8_m(mask, op1, op2, vl) __riscv_th_vssubu_vx_u8m8_m(mask, op1, op2, vl)
#define __riscv_vssubu_vv_u16m1_m(mask, op1, op2, vl) __riscv_th_vssubu_vv_u16m1_m(mask, op1, op2, vl)
#define __riscv_vssubu_vx_u16m1_m(mask, op1, op2, vl) __riscv_th_vssubu_vx_u16m1_m(mask, op1, op2, vl)
#define __riscv_vssubu_vv_u16m2_m(mask, op1, op2, vl) __riscv_th_vssubu_vv_u16m2_m(mask, op1, op2, vl)
#define __riscv_vssubu_vx_u16m2_m(mask, op1, op2, vl) __riscv_th_vssubu_vx_u16m2_m(mask, op1, op2, vl)
#define __riscv_vssubu_vv_u16m4_m(mask, op1, op2, vl) __riscv_th_vssubu_vv_u16m4_m(mask, op1, op2, vl)
#define __riscv_vssubu_vx_u16m4_m(mask, op1, op2, vl) __riscv_th_vssubu_vx_u16m4_m(mask, op1, op2, vl)
#define __riscv_vssubu_vv_u16m8_m(mask, op1, op2, vl) __riscv_th_vssubu_vv_u16m8_m(mask, op1, op2, vl)
#define __riscv_vssubu_vx_u16m8_m(mask, op1, op2, vl) __riscv_th_vssubu_vx_u16m8_m(mask, op1, op2, vl)
#define __riscv_vssubu_vv_u32m1_m(mask, op1, op2, vl) __riscv_th_vssubu_vv_u32m1_m(mask, op1, op2, vl)
#define __riscv_vssubu_vx_u32m1_m(mask, op1, op2, vl) __riscv_th_vssubu_vx_u32m1_m(mask, op1, op2, vl)
#define __riscv_vssubu_vv_u32m2_m(mask, op1, op2, vl) __riscv_th_vssubu_vv_u32m2_m(mask, op1, op2, vl)
#define __riscv_vssubu_vx_u32m2_m(mask, op1, op2, vl) __riscv_th_vssubu_vx_u32m2_m(mask, op1, op2, vl)
#define __riscv_vssubu_vv_u32m4_m(mask, op1, op2, vl) __riscv_th_vssubu_vv_u32m4_m(mask, op1, op2, vl)
#define __riscv_vssubu_vx_u32m4_m(mask, op1, op2, vl) __riscv_th_vssubu_vx_u32m4_m(mask, op1, op2, vl)
#define __riscv_vssubu_vv_u32m8_m(mask, op1, op2, vl) __riscv_th_vssubu_vv_u32m8_m(mask, op1, op2, vl)
#define __riscv_vssubu_vx_u32m8_m(mask, op1, op2, vl) __riscv_th_vssubu_vx_u32m8_m(mask, op1, op2, vl)
#define __riscv_vssubu_vv_u64m1_m(mask, op1, op2, vl) __riscv_th_vssubu_vv_u64m1_m(mask, op1, op2, vl)
#define __riscv_vssubu_vx_u64m1_m(mask, op1, op2, vl) __riscv_th_vssubu_vx_u64m1_m(mask, op1, op2, vl)
#define __riscv_vssubu_vv_u64m2_m(mask, op1, op2, vl) __riscv_th_vssubu_vv_u64m2_m(mask, op1, op2, vl)
#define __riscv_vssubu_vx_u64m2_m(mask, op1, op2, vl) __riscv_th_vssubu_vx_u64m2_m(mask, op1, op2, vl)
#define __riscv_vssubu_vv_u64m4_m(mask, op1, op2, vl) __riscv_th_vssubu_vv_u64m4_m(mask, op1, op2, vl)
#define __riscv_vssubu_vx_u64m4_m(mask, op1, op2, vl) __riscv_th_vssubu_vx_u64m4_m(mask, op1, op2, vl)
#define __riscv_vssubu_vv_u64m8_m(mask, op1, op2, vl) __riscv_th_vssubu_vv_u64m8_m(mask, op1, op2, vl)
#define __riscv_vssubu_vx_u64m8_m(mask, op1, op2, vl) __riscv_th_vssubu_vx_u64m8_m(mask, op1, op2, vl)


// Vector Strided loads
#define __riscv_vlsb_v_i8m1(src_ptr, stride, vl) __riscv_th_vlsb_v_i8m1(src_ptr, stride, vl)
#define __riscv_vlsb_v_i8m2(src_ptr, stride, vl) __riscv_th_vlsb_v_i8m2(src_ptr, stride, vl)
#define __riscv_vlsb_v_i8m4(src_ptr, stride, vl) __riscv_th_vlsb_v_i8m4(src_ptr, stride, vl)
#define __riscv_vlsb_v_i8m8(src_ptr, stride, vl) __riscv_th_vlsb_v_i8m8(src_ptr, stride, vl)
#define __riscv_vlsb_v_i16m1(src_ptr, stride, vl) __riscv_th_vlsb_v_i16m1(src_ptr, stride, vl)
#define __riscv_vlsb_v_i16m2(src_ptr, stride, vl) __riscv_th_vlsb_v_i16m2(src_ptr, stride, vl)
#define __riscv_vlsb_v_i16m4(src_ptr, stride, vl) __riscv_th_vlsb_v_i16m4(src_ptr, stride, vl)
#define __riscv_vlsb_v_i16m8(src_ptr, stride, vl) __riscv_th_vlsb_v_i16m8(src_ptr, stride, vl)
#define __riscv_vlsb_v_i32m1(src_ptr, stride, vl) __riscv_th_vlsb_v_i32m1(src_ptr, stride, vl)
#define __riscv_vlsb_v_i32m2(src_ptr, stride, vl) __riscv_th_vlsb_v_i32m2(src_ptr, stride, vl)
#define __riscv_vlsb_v_i32m4(src_ptr, stride, vl) __riscv_th_vlsb_v_i32m4(src_ptr, stride, vl)
#define __riscv_vlsb_v_i32m8(src_ptr, stride, vl) __riscv_th_vlsb_v_i32m8(src_ptr, stride, vl)
#define __riscv_vlsb_v_i64m1(src_ptr, stride, vl) __riscv_th_vlsb_v_i64m1(src_ptr, stride, vl)
#define __riscv_vlsb_v_i64m2(src_ptr, stride, vl) __riscv_th_vlsb_v_i64m2(src_ptr, stride, vl)
#define __riscv_vlsb_v_i64m4(src_ptr, stride, vl) __riscv_th_vlsb_v_i64m4(src_ptr, stride, vl)
#define __riscv_vlsb_v_i64m8(src_ptr, stride, vl) __riscv_th_vlsb_v_i64m8(src_ptr, stride, vl)
#define __riscv_vlsh_v_i8m1(src_ptr, stride, vl) __riscv_th_vlsh_v_i8m1(src_ptr, stride, vl)
#define __riscv_vlsh_v_i8m2(src_ptr, stride, vl) __riscv_th_vlsh_v_i8m2(src_ptr, stride, vl)
#define __riscv_vlsh_v_i8m4(src_ptr, stride, vl) __riscv_th_vlsh_v_i8m4(src_ptr, stride, vl)
#define __riscv_vlsh_v_i8m8(src_ptr, stride, vl) __riscv_th_vlsh_v_i8m8(src_ptr, stride, vl)
#define __riscv_vlsh_v_i16m1(src_ptr, stride, vl) __riscv_th_vlsh_v_i16m1(src_ptr, stride, vl)
#define __riscv_vlsh_v_i16m2(src_ptr, stride, vl) __riscv_th_vlsh_v_i16m2(src_ptr, stride, vl)
#define __riscv_vlsh_v_i16m4(src_ptr, stride, vl) __riscv_th_vlsh_v_i16m4(src_ptr, stride, vl)
#define __riscv_vlsh_v_i16m8(src_ptr, stride, vl) __riscv_th_vlsh_v_i16m8(src_ptr, stride, vl)
#define __riscv_vlsh_v_i32m1(src_ptr, stride, vl) __riscv_th_vlsh_v_i32m1(src_ptr, stride, vl)
#define __riscv_vlsh_v_i32m2(src_ptr, stride, vl) __riscv_th_vlsh_v_i32m2(src_ptr, stride, vl)
#define __riscv_vlsh_v_i32m4(src_ptr, stride, vl) __riscv_th_vlsh_v_i32m4(src_ptr, stride, vl)
#define __riscv_vlsh_v_i32m8(src_ptr, stride, vl) __riscv_th_vlsh_v_i32m8(src_ptr, stride, vl)
#define __riscv_vlsh_v_i64m1(src_ptr, stride, vl) __riscv_th_vlsh_v_i64m1(src_ptr, stride, vl)
#define __riscv_vlsh_v_i64m2(src_ptr, stride, vl) __riscv_th_vlsh_v_i64m2(src_ptr, stride, vl)
#define __riscv_vlsh_v_i64m4(src_ptr, stride, vl) __riscv_th_vlsh_v_i64m4(src_ptr, stride, vl)
#define __riscv_vlsh_v_i64m8(src_ptr, stride, vl) __riscv_th_vlsh_v_i64m8(src_ptr, stride, vl)
#define __riscv_vlsw_v_i8m1(src_ptr, stride, vl) __riscv_th_vlsw_v_i8m1(src_ptr, stride, vl)
#define __riscv_vlsw_v_i8m2(src_ptr, stride, vl) __riscv_th_vlsw_v_i8m2(src_ptr, stride, vl)
#define __riscv_vlsw_v_i8m4(src_ptr, stride, vl) __riscv_th_vlsw_v_i8m4(src_ptr, stride, vl)
#define __riscv_vlsw_v_i8m8(src_ptr, stride, vl) __riscv_th_vlsw_v_i8m8(src_ptr, stride, vl)
#define __riscv_vlsw_v_i16m1(src_ptr, stride, vl) __riscv_th_vlsw_v_i16m1(src_ptr, stride, vl)
#define __riscv_vlsw_v_i16m2(src_ptr, stride, vl) __riscv_th_vlsw_v_i16m2(src_ptr, stride, vl)
#define __riscv_vlsw_v_i16m4(src_ptr, stride, vl) __riscv_th_vlsw_v_i16m4(src_ptr, stride, vl)
#define __riscv_vlsw_v_i16m8(src_ptr, stride, vl) __riscv_th_vlsw_v_i16m8(src_ptr, stride, vl)
#define __riscv_vlsw_v_i32m1(src_ptr, stride, vl) __riscv_th_vlsw_v_i32m1(src_ptr, stride, vl)
#define __riscv_vlsw_v_i32m2(src_ptr, stride, vl) __riscv_th_vlsw_v_i32m2(src_ptr, stride, vl)
#define __riscv_vlsw_v_i32m4(src_ptr, stride, vl) __riscv_th_vlsw_v_i32m4(src_ptr, stride, vl)
#define __riscv_vlsw_v_i32m8(src_ptr, stride, vl) __riscv_th_vlsw_v_i32m8(src_ptr, stride, vl)
#define __riscv_vlsw_v_i64m1(src_ptr, stride, vl) __riscv_th_vlsw_v_i64m1(src_ptr, stride, vl)
#define __riscv_vlsw_v_i64m2(src_ptr, stride, vl) __riscv_th_vlsw_v_i64m2(src_ptr, stride, vl)
#define __riscv_vlsw_v_i64m4(src_ptr, stride, vl) __riscv_th_vlsw_v_i64m4(src_ptr, stride, vl)
#define __riscv_vlsw_v_i64m8(src_ptr, stride, vl) __riscv_th_vlsw_v_i64m8(src_ptr, stride, vl)
#define __riscv_vlsbu_v_u8m1(src_ptr, stride, vl) __riscv_th_vlsbu_v_u8m1(src_ptr, stride, vl)
#define __riscv_vlsbu_v_u8m2(src_ptr, stride, vl) __riscv_th_vlsbu_v_u8m2(src_ptr, stride, vl)
#define __riscv_vlsbu_v_u8m4(src_ptr, stride, vl) __riscv_th_vlsbu_v_u8m4(src_ptr, stride, vl)
#define __riscv_vlsbu_v_u8m8(src_ptr, stride, vl) __riscv_th_vlsbu_v_u8m8(src_ptr, stride, vl)
#define __riscv_vlsbu_v_u16m1(src_ptr, stride, vl) __riscv_th_vlsbu_v_u16m1(src_ptr, stride, vl)
#define __riscv_vlsbu_v_u16m2(src_ptr, stride, vl) __riscv_th_vlsbu_v_u16m2(src_ptr, stride, vl)
#define __riscv_vlsbu_v_u16m4(src_ptr, stride, vl) __riscv_th_vlsbu_v_u16m4(src_ptr, stride, vl)
#define __riscv_vlsbu_v_u16m8(src_ptr, stride, vl) __riscv_th_vlsbu_v_u16m8(src_ptr, stride, vl)
#define __riscv_vlsbu_v_u32m1(src_ptr, stride, vl) __riscv_th_vlsbu_v_u32m1(src_ptr, stride, vl)
#define __riscv_vlsbu_v_u32m2(src_ptr, stride, vl) __riscv_th_vlsbu_v_u32m2(src_ptr, stride, vl)
#define __riscv_vlsbu_v_u32m4(src_ptr, stride, vl) __riscv_th_vlsbu_v_u32m4(src_ptr, stride, vl)
#define __riscv_vlsbu_v_u32m8(src_ptr, stride, vl) __riscv_th_vlsbu_v_u32m8(src_ptr, stride, vl)
#define __riscv_vlsbu_v_u64m1(src_ptr, stride, vl) __riscv_th_vlsbu_v_u64m1(src_ptr, stride, vl)
#define __riscv_vlsbu_v_u64m2(src_ptr, stride, vl) __riscv_th_vlsbu_v_u64m2(src_ptr, stride, vl)
#define __riscv_vlsbu_v_u64m4(src_ptr, stride, vl) __riscv_th_vlsbu_v_u64m4(src_ptr, stride, vl)
#define __riscv_vlsbu_v_u64m8(src_ptr, stride, vl) __riscv_th_vlsbu_v_u64m8(src_ptr, stride, vl)
#define __riscv_vlshu_v_u8m1(src_ptr, stride, vl) __riscv_th_vlshu_v_u8m1(src_ptr, stride, vl)
#define __riscv_vlshu_v_u8m2(src_ptr, stride, vl) __riscv_th_vlshu_v_u8m2(src_ptr, stride, vl)
#define __riscv_vlshu_v_u8m4(src_ptr, stride, vl) __riscv_th_vlshu_v_u8m4(src_ptr, stride, vl)
#define __riscv_vlshu_v_u8m8(src_ptr, stride, vl) __riscv_th_vlshu_v_u8m8(src_ptr, stride, vl)
#define __riscv_vlshu_v_u16m1(src_ptr, stride, vl) __riscv_th_vlshu_v_u16m1(src_ptr, stride, vl)
#define __riscv_vlshu_v_u16m2(src_ptr, stride, vl) __riscv_th_vlshu_v_u16m2(src_ptr, stride, vl)
#define __riscv_vlshu_v_u16m4(src_ptr, stride, vl) __riscv_th_vlshu_v_u16m4(src_ptr, stride, vl)
#define __riscv_vlshu_v_u16m8(src_ptr, stride, vl) __riscv_th_vlshu_v_u16m8(src_ptr, stride, vl)
#define __riscv_vlshu_v_u32m1(src_ptr, stride, vl) __riscv_th_vlshu_v_u32m1(src_ptr, stride, vl)
#define __riscv_vlshu_v_u32m2(src_ptr, stride, vl) __riscv_th_vlshu_v_u32m2(src_ptr, stride, vl)
#define __riscv_vlshu_v_u32m4(src_ptr, stride, vl) __riscv_th_vlshu_v_u32m4(src_ptr, stride, vl)
#define __riscv_vlshu_v_u32m8(src_ptr, stride, vl) __riscv_th_vlshu_v_u32m8(src_ptr, stride, vl)
#define __riscv_vlshu_v_u64m1(src_ptr, stride, vl) __riscv_th_vlshu_v_u64m1(src_ptr, stride, vl)
#define __riscv_vlshu_v_u64m2(src_ptr, stride, vl) __riscv_th_vlshu_v_u64m2(src_ptr, stride, vl)
#define __riscv_vlshu_v_u64m4(src_ptr, stride, vl) __riscv_th_vlshu_v_u64m4(src_ptr, stride, vl)
#define __riscv_vlshu_v_u64m8(src_ptr, stride, vl) __riscv_th_vlshu_v_u64m8(src_ptr, stride, vl)
#define __riscv_vlswu_v_u8m1(src_ptr, stride, vl) __riscv_th_vlswu_v_u8m1(src_ptr, stride, vl)
#define __riscv_vlswu_v_u8m2(src_ptr, stride, vl) __riscv_th_vlswu_v_u8m2(src_ptr, stride, vl)
#define __riscv_vlswu_v_u8m4(src_ptr, stride, vl) __riscv_th_vlswu_v_u8m4(src_ptr, stride, vl)
#define __riscv_vlswu_v_u8m8(src_ptr, stride, vl) __riscv_th_vlswu_v_u8m8(src_ptr, stride, vl)
#define __riscv_vlswu_v_u16m1(src_ptr, stride, vl) __riscv_th_vlswu_v_u16m1(src_ptr, stride, vl)
#define __riscv_vlswu_v_u16m2(src_ptr, stride, vl) __riscv_th_vlswu_v_u16m2(src_ptr, stride, vl)
#define __riscv_vlswu_v_u16m4(src_ptr, stride, vl) __riscv_th_vlswu_v_u16m4(src_ptr, stride, vl)
#define __riscv_vlswu_v_u16m8(src_ptr, stride, vl) __riscv_th_vlswu_v_u16m8(src_ptr, stride, vl)
#define __riscv_vlswu_v_u32m1(src_ptr, stride, vl) __riscv_th_vlswu_v_u32m1(src_ptr, stride, vl)
#define __riscv_vlswu_v_u32m2(src_ptr, stride, vl) __riscv_th_vlswu_v_u32m2(src_ptr, stride, vl)
#define __riscv_vlswu_v_u32m4(src_ptr, stride, vl) __riscv_th_vlswu_v_u32m4(src_ptr, stride, vl)
#define __riscv_vlswu_v_u32m8(src_ptr, stride, vl) __riscv_th_vlswu_v_u32m8(src_ptr, stride, vl)
#define __riscv_vlswu_v_u64m1(src_ptr, stride, vl) __riscv_th_vlswu_v_u64m1(src_ptr, stride, vl)
#define __riscv_vlswu_v_u64m2(src_ptr, stride, vl) __riscv_th_vlswu_v_u64m2(src_ptr, stride, vl)
#define __riscv_vlswu_v_u64m4(src_ptr, stride, vl) __riscv_th_vlswu_v_u64m4(src_ptr, stride, vl)
#define __riscv_vlswu_v_u64m8(src_ptr, stride, vl) __riscv_th_vlswu_v_u64m8(src_ptr, stride, vl)
#define __riscv_vlse8_v_i8m1(src_ptr, stride, vl) __riscv_th_vlse8_v_i8m1(src_ptr, stride, vl)
#define __riscv_vlse8_v_i8m2(src_ptr, stride, vl) __riscv_th_vlse8_v_i8m2(src_ptr, stride, vl)
#define __riscv_vlse8_v_i8m4(src_ptr, stride, vl) __riscv_th_vlse8_v_i8m4(src_ptr, stride, vl)
#define __riscv_vlse8_v_i8m8(src_ptr, stride, vl) __riscv_th_vlse8_v_i8m8(src_ptr, stride, vl)
#define __riscv_vlse16_v_i16m1(src_ptr, stride, vl) __riscv_th_vlse16_v_i16m1(src_ptr, stride, vl)
#define __riscv_vlse16_v_i16m2(src_ptr, stride, vl) __riscv_th_vlse16_v_i16m2(src_ptr, stride, vl)
#define __riscv_vlse16_v_i16m4(src_ptr, stride, vl) __riscv_th_vlse16_v_i16m4(src_ptr, stride, vl)
#define __riscv_vlse16_v_i16m8(src_ptr, stride, vl) __riscv_th_vlse16_v_i16m8(src_ptr, stride, vl)
#define __riscv_vlse32_v_i32m1(src_ptr, stride, vl) __riscv_th_vlse32_v_i32m1(src_ptr, stride, vl)
#define __riscv_vlse32_v_i32m2(src_ptr, stride, vl) __riscv_th_vlse32_v_i32m2(src_ptr, stride, vl)
#define __riscv_vlse32_v_i32m4(src_ptr, stride, vl) __riscv_th_vlse32_v_i32m4(src_ptr, stride, vl)
#define __riscv_vlse32_v_i32m8(src_ptr, stride, vl) __riscv_th_vlse32_v_i32m8(src_ptr, stride, vl)
#define __riscv_vlse64_v_i64m1(src_ptr, stride, vl) __riscv_th_vlse64_v_i64m1(src_ptr, stride, vl)
#define __riscv_vlse64_v_i64m2(src_ptr, stride, vl) __riscv_th_vlse64_v_i64m2(src_ptr, stride, vl)
#define __riscv_vlse64_v_i64m4(src_ptr, stride, vl) __riscv_th_vlse64_v_i64m4(src_ptr, stride, vl)
#define __riscv_vlse64_v_i64m8(src_ptr, stride, vl) __riscv_th_vlse64_v_i64m8(src_ptr, stride, vl)
#define __riscv_vlse8_v_u8m1(src_ptr, stride, vl) __riscv_th_vlse8_v_u8m1(src_ptr, stride, vl)
#define __riscv_vlse8_v_u8m2(src_ptr, stride, vl) __riscv_th_vlse8_v_u8m2(src_ptr, stride, vl)
#define __riscv_vlse8_v_u8m4(src_ptr, stride, vl) __riscv_th_vlse8_v_u8m4(src_ptr, stride, vl)
#define __riscv_vlse8_v_u8m8(src_ptr, stride, vl) __riscv_th_vlse8_v_u8m8(src_ptr, stride, vl)
#define __riscv_vlse16_v_u16m1(src_ptr, stride, vl) __riscv_th_vlse16_v_u16m1(src_ptr, stride, vl)
#define __riscv_vlse16_v_u16m2(src_ptr, stride, vl) __riscv_th_vlse16_v_u16m2(src_ptr, stride, vl)
#define __riscv_vlse16_v_u16m4(src_ptr, stride, vl) __riscv_th_vlse16_v_u16m4(src_ptr, stride, vl)
#define __riscv_vlse16_v_u16m8(src_ptr, stride, vl) __riscv_th_vlse16_v_u16m8(src_ptr, stride, vl)
#define __riscv_vlse32_v_u32m1(src_ptr, stride, vl) __riscv_th_vlse32_v_u32m1(src_ptr, stride, vl)
#define __riscv_vlse32_v_u32m2(src_ptr, stride, vl) __riscv_th_vlse32_v_u32m2(src_ptr, stride, vl)
#define __riscv_vlse32_v_u32m4(src_ptr, stride, vl) __riscv_th_vlse32_v_u32m4(src_ptr, stride, vl)
#define __riscv_vlse32_v_u32m8(src_ptr, stride, vl) __riscv_th_vlse32_v_u32m8(src_ptr, stride, vl)
#define __riscv_vlse64_v_u64m1(src_ptr, stride, vl) __riscv_th_vlse64_v_u64m1(src_ptr, stride, vl)
#define __riscv_vlse64_v_u64m2(src_ptr, stride, vl) __riscv_th_vlse64_v_u64m2(src_ptr, stride, vl)
#define __riscv_vlse64_v_u64m4(src_ptr, stride, vl) __riscv_th_vlse64_v_u64m4(src_ptr, stride, vl)
#define __riscv_vlse64_v_u64m8(src_ptr, stride, vl) __riscv_th_vlse64_v_u64m8(src_ptr, stride, vl)
#define __riscv_vlse16_v_f16m1(src_ptr, stride, vl) __riscv_th_vlse16_v_f16m1(src_ptr, stride, vl)
#define __riscv_vlse16_v_f16m2(src_ptr, stride, vl) __riscv_th_vlse16_v_f16m2(src_ptr, stride, vl)
#define __riscv_vlse16_v_f16m4(src_ptr, stride, vl) __riscv_th_vlse16_v_f16m4(src_ptr, stride, vl)
#define __riscv_vlse16_v_f16m8(src_ptr, stride, vl) __riscv_th_vlse16_v_f16m8(src_ptr, stride, vl)
#define __riscv_vlse32_v_f32m1(src_ptr, stride, vl) __riscv_th_vlse32_v_f32m1(src_ptr, stride, vl)
#define __riscv_vlse32_v_f32m2(src_ptr, stride, vl) __riscv_th_vlse32_v_f32m2(src_ptr, stride, vl)
#define __riscv_vlse32_v_f32m4(src_ptr, stride, vl) __riscv_th_vlse32_v_f32m4(src_ptr, stride, vl)
#define __riscv_vlse32_v_f32m8(src_ptr, stride, vl) __riscv_th_vlse32_v_f32m8(src_ptr, stride, vl)
#define __riscv_vlse64_v_f64m1(src_ptr, stride, vl) __riscv_th_vlse64_v_f64m1(src_ptr, stride, vl)
#define __riscv_vlse64_v_f64m2(src_ptr, stride, vl) __riscv_th_vlse64_v_f64m2(src_ptr, stride, vl)
#define __riscv_vlse64_v_f64m4(src_ptr, stride, vl) __riscv_th_vlse64_v_f64m4(src_ptr, stride, vl)
#define __riscv_vlse64_v_f64m8(src_ptr, stride, vl) __riscv_th_vlse64_v_f64m8(src_ptr, stride, vl)

// Vector Strided stores
#define __riscv_vssb_v_i8m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_i8m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_i8m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_i8m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_i8m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_i8m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_i8m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_i8m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_i16m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_i16m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_i16m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_i16m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_i16m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_i16m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_i16m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_i16m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_i32m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_i32m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_i32m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_i32m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_i32m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_i32m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_i32m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_i32m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_i64m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_i64m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_i64m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_i64m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_i64m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_i64m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_i64m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_i64m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_i8m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_i8m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_i8m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_i8m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_i8m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_i8m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_i8m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_i8m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_i16m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_i16m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_i16m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_i16m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_i16m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_i16m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_i16m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_i16m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_i32m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_i32m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_i32m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_i32m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_i32m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_i32m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_i32m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_i32m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_i64m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_i64m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_i64m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_i64m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_i64m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_i64m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_i64m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_i64m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_i8m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_i8m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_i8m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_i8m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_i8m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_i8m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_i8m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_i8m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_i16m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_i16m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_i16m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_i16m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_i16m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_i16m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_i16m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_i16m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_i32m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_i32m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_i32m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_i32m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_i32m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_i32m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_i32m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_i32m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_i64m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_i64m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_i64m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_i64m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_i64m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_i64m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_i64m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_i64m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_u8m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_u8m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_u8m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_u8m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_u8m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_u8m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_u8m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_u8m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_u16m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_u16m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_u16m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_u16m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_u16m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_u16m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_u16m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_u16m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_u32m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_u32m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_u32m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_u32m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_u32m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_u32m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_u32m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_u32m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_u64m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_u64m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_u64m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_u64m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_u64m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_u64m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssb_v_u64m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssb_v_u64m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_u8m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_u8m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_u8m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_u8m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_u8m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_u8m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_u8m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_u8m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_u16m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_u16m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_u16m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_u16m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_u16m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_u16m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_u16m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_u16m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_u32m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_u32m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_u32m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_u32m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_u32m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_u32m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_u32m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_u32m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_u64m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_u64m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_u64m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_u64m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_u64m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_u64m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssh_v_u64m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssh_v_u64m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_u8m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_u8m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_u8m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_u8m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_u8m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_u8m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_u8m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_u8m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_u16m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_u16m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_u16m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_u16m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_u16m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_u16m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_u16m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_u16m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_u32m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_u32m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_u32m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_u32m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_u32m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_u32m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_u32m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_u32m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_u64m1(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_u64m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_u64m2(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_u64m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_u64m4(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_u64m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vssw_v_u64m8(dst_ptr, stride, vector_value, vl) __riscv_th_vssw_v_u64m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse8_v_i8m1(dst_ptr, stride, vector_value, vl) __riscv_th_vsse8_v_i8m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse8_v_i8m2(dst_ptr, stride, vector_value, vl) __riscv_th_vsse8_v_i8m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse8_v_i8m4(dst_ptr, stride, vector_value, vl) __riscv_th_vsse8_v_i8m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse8_v_i8m8(dst_ptr, stride, vector_value, vl) __riscv_th_vsse8_v_i8m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse16_v_i16m1(dst_ptr, stride, vector_value, vl) __riscv_th_vsse16_v_i16m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse16_v_i16m2(dst_ptr, stride, vector_value, vl) __riscv_th_vsse16_v_i16m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse16_v_i16m4(dst_ptr, stride, vector_value, vl) __riscv_th_vsse16_v_i16m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse16_v_i16m8(dst_ptr, stride, vector_value, vl) __riscv_th_vsse16_v_i16m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse32_v_i32m1(dst_ptr, stride, vector_value, vl) __riscv_th_vsse32_v_i32m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse32_v_i32m2(dst_ptr, stride, vector_value, vl) __riscv_th_vsse32_v_i32m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse32_v_i32m4(dst_ptr, stride, vector_value, vl) __riscv_th_vsse32_v_i32m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse32_v_i32m8(dst_ptr, stride, vector_value, vl) __riscv_th_vsse32_v_i32m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse64_v_i64m1(dst_ptr, stride, vector_value, vl) __riscv_th_vsse64_v_i64m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse64_v_i64m2(dst_ptr, stride, vector_value, vl) __riscv_th_vsse64_v_i64m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse64_v_i64m4(dst_ptr, stride, vector_value, vl) __riscv_th_vsse64_v_i64m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse64_v_i64m8(dst_ptr, stride, vector_value, vl) __riscv_th_vsse64_v_i64m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse8_v_u8m1(dst_ptr, stride, vector_value, vl) __riscv_th_vsse8_v_u8m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse8_v_u8m2(dst_ptr, stride, vector_value, vl) __riscv_th_vsse8_v_u8m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse8_v_u8m4(dst_ptr, stride, vector_value, vl) __riscv_th_vsse8_v_u8m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse8_v_u8m8(dst_ptr, stride, vector_value, vl) __riscv_th_vsse8_v_u8m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse16_v_u16m1(dst_ptr, stride, vector_value, vl) __riscv_th_vsse16_v_u16m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse16_v_u16m2(dst_ptr, stride, vector_value, vl) __riscv_th_vsse16_v_u16m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse16_v_u16m4(dst_ptr, stride, vector_value, vl) __riscv_th_vsse16_v_u16m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse16_v_u16m8(dst_ptr, stride, vector_value, vl) __riscv_th_vsse16_v_u16m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse32_v_u32m1(dst_ptr, stride, vector_value, vl) __riscv_th_vsse32_v_u32m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse32_v_u32m2(dst_ptr, stride, vector_value, vl) __riscv_th_vsse32_v_u32m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse32_v_u32m4(dst_ptr, stride, vector_value, vl) __riscv_th_vsse32_v_u32m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse32_v_u32m8(dst_ptr, stride, vector_value, vl) __riscv_th_vsse32_v_u32m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse64_v_u64m1(dst_ptr, stride, vector_value, vl) __riscv_th_vsse64_v_u64m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse64_v_u64m2(dst_ptr, stride, vector_value, vl) __riscv_th_vsse64_v_u64m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse64_v_u64m4(dst_ptr, stride, vector_value, vl) __riscv_th_vsse64_v_u64m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse64_v_u64m8(dst_ptr, stride, vector_value, vl) __riscv_th_vsse64_v_u64m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse16_v_f16m1(dst_ptr, stride, vector_value, vl) __riscv_th_vsse16_v_f16m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse16_v_f16m2(dst_ptr, stride, vector_value, vl) __riscv_th_vsse16_v_f16m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse16_v_f16m4(dst_ptr, stride, vector_value, vl) __riscv_th_vsse16_v_f16m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse16_v_f16m8(dst_ptr, stride, vector_value, vl) __riscv_th_vsse16_v_f16m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse32_v_f32m1(dst_ptr, stride, vector_value, vl) __riscv_th_vsse32_v_f32m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse32_v_f32m2(dst_ptr, stride, vector_value, vl) __riscv_th_vsse32_v_f32m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse32_v_f32m4(dst_ptr, stride, vector_value, vl) __riscv_th_vsse32_v_f32m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse32_v_f32m8(dst_ptr, stride, vector_value, vl) __riscv_th_vsse32_v_f32m8(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse64_v_f64m1(dst_ptr, stride, vector_value, vl) __riscv_th_vsse64_v_f64m1(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse64_v_f64m2(dst_ptr, stride, vector_value, vl) __riscv_th_vsse64_v_f64m2(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse64_v_f64m4(dst_ptr, stride, vector_value, vl) __riscv_th_vsse64_v_f64m4(dst_ptr, stride, vector_value, vl)
#define __riscv_vsse64_v_f64m8(dst_ptr, stride, vector_value, vl) __riscv_th_vsse64_v_f64m8(dst_ptr, stride, vector_value, vl)


// Vector Unit-stride Fault-Only-First loads
#define __riscv_vle8ff_v_i8m1(src_ptr, new_vl_ptr, vl) __riscv_th_vle8ff_v_i8m1(src_ptr, new_vl_ptr, vl)
#define __riscv_vle8ff_v_i8m2(src_ptr, new_vl_ptr, vl) __riscv_th_vle8ff_v_i8m2(src_ptr, new_vl_ptr, vl)
#define __riscv_vle8ff_v_i8m4(src_ptr, new_vl_ptr, vl) __riscv_th_vle8ff_v_i8m4(src_ptr, new_vl_ptr, vl)
#define __riscv_vle8ff_v_i8m8(src_ptr, new_vl_ptr, vl) __riscv_th_vle8ff_v_i8m8(src_ptr, new_vl_ptr, vl)
#define __riscv_vle16ff_v_i16m1(src_ptr, new_vl_ptr, vl) __riscv_th_vle16ff_v_i16m1(src_ptr, new_vl_ptr, vl)
#define __riscv_vle16ff_v_i16m2(src_ptr, new_vl_ptr, vl) __riscv_th_vle16ff_v_i16m2(src_ptr, new_vl_ptr, vl)
#define __riscv_vle16ff_v_i16m4(src_ptr, new_vl_ptr, vl) __riscv_th_vle16ff_v_i16m4(src_ptr, new_vl_ptr, vl)
#define __riscv_vle16ff_v_i16m8(src_ptr, new_vl_ptr, vl) __riscv_th_vle16ff_v_i16m8(src_ptr, new_vl_ptr, vl)
#define __riscv_vle32ff_v_i32m1(src_ptr, new_vl_ptr, vl) __riscv_th_vle32ff_v_i32m1(src_ptr, new_vl_ptr, vl)
#define __riscv_vle32ff_v_i32m2(src_ptr, new_vl_ptr, vl) __riscv_th_vle32ff_v_i32m2(src_ptr, new_vl_ptr, vl)
#define __riscv_vle32ff_v_i32m4(src_ptr, new_vl_ptr, vl) __riscv_th_vle32ff_v_i32m4(src_ptr, new_vl_ptr, vl)
#define __riscv_vle32ff_v_i32m8(src_ptr, new_vl_ptr, vl) __riscv_th_vle32ff_v_i32m8(src_ptr, new_vl_ptr, vl)
#define __riscv_vle64ff_v_i64m1(src_ptr, new_vl_ptr, vl) __riscv_th_vle64ff_v_i64m1(src_ptr, new_vl_ptr, vl)
#define __riscv_vle64ff_v_i64m2(src_ptr, new_vl_ptr, vl) __riscv_th_vle64ff_v_i64m2(src_ptr, new_vl_ptr, vl)
#define __riscv_vle64ff_v_i64m4(src_ptr, new_vl_ptr, vl) __riscv_th_vle64ff_v_i64m4(src_ptr, new_vl_ptr, vl)
#define __riscv_vle64ff_v_i64m8(src_ptr, new_vl_ptr, vl) __riscv_th_vle64ff_v_i64m8(src_ptr, new_vl_ptr, vl)

#define __riscv_vle8ff_v_u8m1(src_ptr, new_vl_ptr, vl) __riscv_th_vle8ff_v_u8m1(src_ptr, new_vl_ptr, vl)
#define __riscv_vle8ff_v_u8m2(src_ptr, new_vl_ptr, vl) __riscv_th_vle8ff_v_u8m2(src_ptr, new_vl_ptr, vl)
#define __riscv_vle8ff_v_u8m4(src_ptr, new_vl_ptr, vl) __riscv_th_vle8ff_v_u8m4(src_ptr, new_vl_ptr, vl)
#define __riscv_vle8ff_v_u8m8(src_ptr, new_vl_ptr, vl) __riscv_th_vle8ff_v_u8m8(src_ptr, new_vl_ptr, vl)
#define __riscv_vle16ff_v_u16m1(src_ptr, new_vl_ptr, vl) __riscv_th_vle16ff_v_u16m1(src_ptr, new_vl_ptr, vl)
#define __riscv_vle16ff_v_u16m2(src_ptr, new_vl_ptr, vl) __riscv_th_vle16ff_v_u16m2(src_ptr, new_vl_ptr, vl)
#define __riscv_vle16ff_v_u16m4(src_ptr, new_vl_ptr, vl) __riscv_th_vle16ff_v_u16m4(src_ptr, new_vl_ptr, vl)
#define __riscv_vle16ff_v_u16m8(src_ptr, new_vl_ptr, vl) __riscv_th_vle16ff_v_u16m8(src_ptr, new_vl_ptr, vl)
#define __riscv_vle32ff_v_u32m1(src_ptr, new_vl_ptr, vl) __riscv_th_vle32ff_v_u32m1(src_ptr, new_vl_ptr, vl)
#define __riscv_vle32ff_v_u32m2(src_ptr, new_vl_ptr, vl) __riscv_th_vle32ff_v_u32m2(src_ptr, new_vl_ptr, vl)
#define __riscv_vle32ff_v_u32m4(src_ptr, new_vl_ptr, vl) __riscv_th_vle32ff_v_u32m4(src_ptr, new_vl_ptr, vl)
#define __riscv_vle32ff_v_u32m8(src_ptr, new_vl_ptr, vl) __riscv_th_vle32ff_v_u32m8(src_ptr, new_vl_ptr, vl)
#define __riscv_vle64ff_v_u64m1(src_ptr, new_vl_ptr, vl) __riscv_th_vle64ff_v_u64m1(src_ptr, new_vl_ptr, vl)
#define __riscv_vle64ff_v_u64m2(src_ptr, new_vl_ptr, vl) __riscv_th_vle64ff_v_u64m2(src_ptr, new_vl_ptr, vl)
#define __riscv_vle64ff_v_u64m4(src_ptr, new_vl_ptr, vl) __riscv_th_vle64ff_v_u64m4(src_ptr, new_vl_ptr, vl)
#define __riscv_vle64ff_v_u64m8(src_ptr, new_vl_ptr, vl) __riscv_th_vle64ff_v_u64m8(src_ptr, new_vl_ptr, vl)

#define __riscv_vle16ff_v_f16m1(src_ptr, new_vl_ptr, vl) __riscv_th_vle16ff_v_f16m1(src_ptr, new_vl_ptr, vl)
#define __riscv_vle16ff_v_f16m2(src_ptr, new_vl_ptr, vl) __riscv_th_vle16ff_v_f16m2(src_ptr, new_vl_ptr, vl)
#define __riscv_vle16ff_v_f16m4(src_ptr, new_vl_ptr, vl) __riscv_th_vle16ff_v_f16m4(src_ptr, new_vl_ptr, vl)
#define __riscv_vle16ff_v_f16m8(src_ptr, new_vl_ptr, vl) __riscv_th_vle16ff_v_f16m8(src_ptr, new_vl_ptr, vl)
#define __riscv_vle32ff_v_f32m1(src_ptr, new_vl_ptr, vl) __riscv_th_vle32ff_v_f32m1(src_ptr, new_vl_ptr, vl)
#define __riscv_vle32ff_v_f32m2(src_ptr, new_vl_ptr, vl) __riscv_th_vle32ff_v_f32m2(src_ptr, new_vl_ptr, vl)
#define __riscv_vle32ff_v_f32m4(src_ptr, new_vl_ptr, vl) __riscv_th_vle32ff_v_f32m4(src_ptr, new_vl_ptr, vl)
#define __riscv_vle32ff_v_f32m8(src_ptr, new_vl_ptr, vl) __riscv_th_vle32ff_v_f32m8(src_ptr, new_vl_ptr, vl)
#define __riscv_vle64ff_v_f64m1(src_ptr, new_vl_ptr, vl) __riscv_th_vle64ff_v_f64m1(src_ptr, new_vl_ptr, vl)
#define __riscv_vle64ff_v_f64m2(src_ptr, new_vl_ptr, vl) __riscv_th_vle64ff_v_f64m2(src_ptr, new_vl_ptr, vl)
#define __riscv_vle64ff_v_f64m4(src_ptr, new_vl_ptr, vl) __riscv_th_vle64ff_v_f64m4(src_ptr, new_vl_ptr, vl)
#define __riscv_vle64ff_v_f64m8(src_ptr, new_vl_ptr, vl) __riscv_th_vle64ff_v_f64m8(src_ptr, new_vl_ptr, vl)

// Vector Unit-stride loads
#define __riscv_vlb_v_i8m1(src_ptr, vl) __riscv_th_vlb_v_i8m1(src_ptr, vl)
#define __riscv_vlb_v_i8m2(src_ptr, vl) __riscv_th_vlb_v_i8m2(src_ptr, vl)
#define __riscv_vlb_v_i8m4(src_ptr, vl) __riscv_th_vlb_v_i8m4(src_ptr, vl)
#define __riscv_vlb_v_i8m8(src_ptr, vl) __riscv_th_vlb_v_i8m8(src_ptr, vl)
#define __riscv_vlb_v_i16m1(src_ptr, vl) __riscv_th_vlb_v_i16m1(src_ptr, vl)
#define __riscv_vlb_v_i16m2(src_ptr, vl) __riscv_th_vlb_v_i16m2(src_ptr, vl)
#define __riscv_vlb_v_i16m4(src_ptr, vl) __riscv_th_vlb_v_i16m4(src_ptr, vl)
#define __riscv_vlb_v_i16m8(src_ptr, vl) __riscv_th_vlb_v_i16m8(src_ptr, vl)
#define __riscv_vlb_v_i32m1(src_ptr, vl) __riscv_th_vlb_v_i32m1(src_ptr, vl)
#define __riscv_vlb_v_i32m2(src_ptr, vl) __riscv_th_vlb_v_i32m2(src_ptr, vl)
#define __riscv_vlb_v_i32m4(src_ptr, vl) __riscv_th_vlb_v_i32m4(src_ptr, vl)
#define __riscv_vlb_v_i32m8(src_ptr, vl) __riscv_th_vlb_v_i32m8(src_ptr, vl)
#define __riscv_vlb_v_i64m1(src_ptr, vl) __riscv_th_vlb_v_i64m1(src_ptr, vl)
#define __riscv_vlb_v_i64m2(src_ptr, vl) __riscv_th_vlb_v_i64m2(src_ptr, vl)
#define __riscv_vlb_v_i64m4(src_ptr, vl) __riscv_th_vlb_v_i64m4(src_ptr, vl)
#define __riscv_vlb_v_i64m8(src_ptr, vl) __riscv_th_vlb_v_i64m8(src_ptr, vl)
#define __riscv_vlh_v_i8m1(src_ptr, vl) __riscv_th_vlh_v_i8m1(src_ptr, vl)
#define __riscv_vlh_v_i8m2(src_ptr, vl) __riscv_th_vlh_v_i8m2(src_ptr, vl)
#define __riscv_vlh_v_i8m4(src_ptr, vl) __riscv_th_vlh_v_i8m4(src_ptr, vl)
#define __riscv_vlh_v_i8m8(src_ptr, vl) __riscv_th_vlh_v_i8m8(src_ptr, vl)
#define __riscv_vlh_v_i16m1(src_ptr, vl) __riscv_th_vlh_v_i16m1(src_ptr, vl)
#define __riscv_vlh_v_i16m2(src_ptr, vl) __riscv_th_vlh_v_i16m2(src_ptr, vl)
#define __riscv_vlh_v_i16m4(src_ptr, vl) __riscv_th_vlh_v_i16m4(src_ptr, vl)
#define __riscv_vlh_v_i16m8(src_ptr, vl) __riscv_th_vlh_v_i16m8(src_ptr, vl)
#define __riscv_vlh_v_i32m1(src_ptr, vl) __riscv_th_vlh_v_i32m1(src_ptr, vl)
#define __riscv_vlh_v_i32m2(src_ptr, vl) __riscv_th_vlh_v_i32m2(src_ptr, vl)
#define __riscv_vlh_v_i32m4(src_ptr, vl) __riscv_th_vlh_v_i32m4(src_ptr, vl)
#define __riscv_vlh_v_i32m8(src_ptr, vl) __riscv_th_vlh_v_i32m8(src_ptr, vl)
#define __riscv_vlh_v_i64m1(src_ptr, vl) __riscv_th_vlh_v_i64m1(src_ptr, vl)
#define __riscv_vlh_v_i64m2(src_ptr, vl) __riscv_th_vlh_v_i64m2(src_ptr, vl)
#define __riscv_vlh_v_i64m4(src_ptr, vl) __riscv_th_vlh_v_i64m4(src_ptr, vl)
#define __riscv_vlh_v_i64m8(src_ptr, vl) __riscv_th_vlh_v_i64m8(src_ptr, vl)
#define __riscv_vlw_v_i8m1(src_ptr, vl) __riscv_th_vlw_v_i8m1(src_ptr, vl)
#define __riscv_vlw_v_i8m2(src_ptr, vl) __riscv_th_vlw_v_i8m2(src_ptr, vl)
#define __riscv_vlw_v_i8m4(src_ptr, vl) __riscv_th_vlw_v_i8m4(src_ptr, vl)
#define __riscv_vlw_v_i8m8(src_ptr, vl) __riscv_th_vlw_v_i8m8(src_ptr, vl)
#define __riscv_vlw_v_i16m1(src_ptr, vl) __riscv_th_vlw_v_i16m1(src_ptr, vl)
#define __riscv_vlw_v_i16m2(src_ptr, vl) __riscv_th_vlw_v_i16m2(src_ptr, vl)
#define __riscv_vlw_v_i16m4(src_ptr, vl) __riscv_th_vlw_v_i16m4(src_ptr, vl)
#define __riscv_vlw_v_i16m8(src_ptr, vl) __riscv_th_vlw_v_i16m8(src_ptr, vl)
#define __riscv_vlw_v_i32m1(src_ptr, vl) __riscv_th_vlw_v_i32m1(src_ptr, vl)
#define __riscv_vlw_v_i32m2(src_ptr, vl) __riscv_th_vlw_v_i32m2(src_ptr, vl)
#define __riscv_vlw_v_i32m4(src_ptr, vl) __riscv_th_vlw_v_i32m4(src_ptr, vl)
#define __riscv_vlw_v_i32m8(src_ptr, vl) __riscv_th_vlw_v_i32m8(src_ptr, vl)
#define __riscv_vlw_v_i64m1(src_ptr, vl) __riscv_th_vlw_v_i64m1(src_ptr, vl)
#define __riscv_vlw_v_i64m2(src_ptr, vl) __riscv_th_vlw_v_i64m2(src_ptr, vl)
#define __riscv_vlw_v_i64m4(src_ptr, vl) __riscv_th_vlw_v_i64m4(src_ptr, vl)
#define __riscv_vlw_v_i64m8(src_ptr, vl) __riscv_th_vlw_v_i64m8(src_ptr, vl)
#define __riscv_vlbu_v_u8m1(src_ptr, vl) __riscv_th_vlbu_v_u8m1(src_ptr, vl)
#define __riscv_vlbu_v_u8m2(src_ptr, vl) __riscv_th_vlbu_v_u8m2(src_ptr, vl)
#define __riscv_vlbu_v_u8m4(src_ptr, vl) __riscv_th_vlbu_v_u8m4(src_ptr, vl)
#define __riscv_vlbu_v_u8m8(src_ptr, vl) __riscv_th_vlbu_v_u8m8(src_ptr, vl)
#define __riscv_vlbu_v_u16m1(src_ptr, vl) __riscv_th_vlbu_v_u16m1(src_ptr, vl)
#define __riscv_vlbu_v_u16m2(src_ptr, vl) __riscv_th_vlbu_v_u16m2(src_ptr, vl)
#define __riscv_vlbu_v_u16m4(src_ptr, vl) __riscv_th_vlbu_v_u16m4(src_ptr, vl)
#define __riscv_vlbu_v_u16m8(src_ptr, vl) __riscv_th_vlbu_v_u16m8(src_ptr, vl)
#define __riscv_vlbu_v_u32m1(src_ptr, vl) __riscv_th_vlbu_v_u32m1(src_ptr, vl)
#define __riscv_vlbu_v_u32m2(src_ptr, vl) __riscv_th_vlbu_v_u32m2(src_ptr, vl)
#define __riscv_vlbu_v_u32m4(src_ptr, vl) __riscv_th_vlbu_v_u32m4(src_ptr, vl)
#define __riscv_vlbu_v_u32m8(src_ptr, vl) __riscv_th_vlbu_v_u32m8(src_ptr, vl)
#define __riscv_vlbu_v_u64m1(src_ptr, vl) __riscv_th_vlbu_v_u64m1(src_ptr, vl)
#define __riscv_vlbu_v_u64m2(src_ptr, vl) __riscv_th_vlbu_v_u64m2(src_ptr, vl)
#define __riscv_vlbu_v_u64m4(src_ptr, vl) __riscv_th_vlbu_v_u64m4(src_ptr, vl)
#define __riscv_vlbu_v_u64m8(src_ptr, vl) __riscv_th_vlbu_v_u64m8(src_ptr, vl)
#define __riscv_vlhu_v_u8m1(src_ptr, vl) __riscv_th_vlhu_v_u8m1(src_ptr, vl)
#define __riscv_vlhu_v_u8m2(src_ptr, vl) __riscv_th_vlhu_v_u8m2(src_ptr, vl)
#define __riscv_vlhu_v_u8m4(src_ptr, vl) __riscv_th_vlhu_v_u8m4(src_ptr, vl)
#define __riscv_vlhu_v_u8m8(src_ptr, vl) __riscv_th_vlhu_v_u8m8(src_ptr, vl)
#define __riscv_vlhu_v_u16m1(src_ptr, vl) __riscv_th_vlhu_v_u16m1(src_ptr, vl)
#define __riscv_vlhu_v_u16m2(src_ptr, vl) __riscv_th_vlhu_v_u16m2(src_ptr, vl)
#define __riscv_vlhu_v_u16m4(src_ptr, vl) __riscv_th_vlhu_v_u16m4(src_ptr, vl)
#define __riscv_vlhu_v_u16m8(src_ptr, vl) __riscv_th_vlhu_v_u16m8(src_ptr, vl)
#define __riscv_vlhu_v_u32m1(src_ptr, vl) __riscv_th_vlhu_v_u32m1(src_ptr, vl)
#define __riscv_vlhu_v_u32m2(src_ptr, vl) __riscv_th_vlhu_v_u32m2(src_ptr, vl)
#define __riscv_vlhu_v_u32m4(src_ptr, vl) __riscv_th_vlhu_v_u32m4(src_ptr, vl)
#define __riscv_vlhu_v_u32m8(src_ptr, vl) __riscv_th_vlhu_v_u32m8(src_ptr, vl)
#define __riscv_vlhu_v_u64m1(src_ptr, vl) __riscv_th_vlhu_v_u64m1(src_ptr, vl)
#define __riscv_vlhu_v_u64m2(src_ptr, vl) __riscv_th_vlhu_v_u64m2(src_ptr, vl)
#define __riscv_vlhu_v_u64m4(src_ptr, vl) __riscv_th_vlhu_v_u64m4(src_ptr, vl)
#define __riscv_vlhu_v_u64m8(src_ptr, vl) __riscv_th_vlhu_v_u64m8(src_ptr, vl)
#define __riscv_vlwu_v_u8m1(src_ptr, vl) __riscv_th_vlwu_v_u8m1(src_ptr, vl)
#define __riscv_vlwu_v_u8m2(src_ptr, vl) __riscv_th_vlwu_v_u8m2(src_ptr, vl)
#define __riscv_vlwu_v_u8m4(src_ptr, vl) __riscv_th_vlwu_v_u8m4(src_ptr, vl)
#define __riscv_vlwu_v_u8m8(src_ptr, vl) __riscv_th_vlwu_v_u8m8(src_ptr, vl)
#define __riscv_vlwu_v_u16m1(src_ptr, vl) __riscv_th_vlwu_v_u16m1(src_ptr, vl)
#define __riscv_vlwu_v_u16m2(src_ptr, vl) __riscv_th_vlwu_v_u16m2(src_ptr, vl)
#define __riscv_vlwu_v_u16m4(src_ptr, vl) __riscv_th_vlwu_v_u16m4(src_ptr, vl)
#define __riscv_vlwu_v_u16m8(src_ptr, vl) __riscv_th_vlwu_v_u16m8(src_ptr, vl)
#define __riscv_vlwu_v_u32m1(src_ptr, vl) __riscv_th_vlwu_v_u32m1(src_ptr, vl)
#define __riscv_vlwu_v_u32m2(src_ptr, vl) __riscv_th_vlwu_v_u32m2(src_ptr, vl)
#define __riscv_vlwu_v_u32m4(src_ptr, vl) __riscv_th_vlwu_v_u32m4(src_ptr, vl)
#define __riscv_vlwu_v_u32m8(src_ptr, vl) __riscv_th_vlwu_v_u32m8(src_ptr, vl)
#define __riscv_vlwu_v_u64m1(src_ptr, vl) __riscv_th_vlwu_v_u64m1(src_ptr, vl)
#define __riscv_vlwu_v_u64m2(src_ptr, vl) __riscv_th_vlwu_v_u64m2(src_ptr, vl)
#define __riscv_vlwu_v_u64m4(src_ptr, vl) __riscv_th_vlwu_v_u64m4(src_ptr, vl)
#define __riscv_vlwu_v_u64m8(src_ptr, vl) __riscv_th_vlwu_v_u64m8(src_ptr, vl)
#define __riscv_vle8_v_i8m1(src_ptr, vl) __riscv_th_vle8_v_i8m1(src_ptr, vl)
#define __riscv_vle8_v_i8m2(src_ptr, vl) __riscv_th_vle8_v_i8m2(src_ptr, vl)
#define __riscv_vle8_v_i8m4(src_ptr, vl) __riscv_th_vle8_v_i8m4(src_ptr, vl)
#define __riscv_vle8_v_i8m8(src_ptr, vl) __riscv_th_vle8_v_i8m8(src_ptr, vl)
#define __riscv_vle16_v_i16m1(src_ptr, vl) __riscv_th_vle16_v_i16m1(src_ptr, vl)
#define __riscv_vle16_v_i16m2(src_ptr, vl) __riscv_th_vle16_v_i16m2(src_ptr, vl)
#define __riscv_vle16_v_i16m4(src_ptr, vl) __riscv_th_vle16_v_i16m4(src_ptr, vl)
#define __riscv_vle16_v_i16m8(src_ptr, vl) __riscv_th_vle16_v_i16m8(src_ptr, vl)
#define __riscv_vle32_v_i32m1(src_ptr, vl) __riscv_th_vle32_v_i32m1(src_ptr, vl)
#define __riscv_vle32_v_i32m2(src_ptr, vl) __riscv_th_vle32_v_i32m2(src_ptr, vl)
#define __riscv_vle32_v_i32m4(src_ptr, vl) __riscv_th_vle32_v_i32m4(src_ptr, vl)
#define __riscv_vle32_v_i32m8(src_ptr, vl) __riscv_th_vle32_v_i32m8(src_ptr, vl)
#define __riscv_vle64_v_i64m1(src_ptr, vl) __riscv_th_vle64_v_i64m1(src_ptr, vl)
#define __riscv_vle64_v_i64m2(src_ptr, vl) __riscv_th_vle64_v_i64m2(src_ptr, vl)
#define __riscv_vle64_v_i64m4(src_ptr, vl) __riscv_th_vle64_v_i64m4(src_ptr, vl)
#define __riscv_vle64_v_i64m8(src_ptr, vl) __riscv_th_vle64_v_i64m8(src_ptr, vl)
#define __riscv_vle8_v_u8m1(src_ptr, vl) __riscv_th_vle8_v_u8m1(src_ptr, vl)
#define __riscv_vle8_v_u8m2(src_ptr, vl) __riscv_th_vle8_v_u8m2(src_ptr, vl)
#define __riscv_vle8_v_u8m4(src_ptr, vl) __riscv_th_vle8_v_u8m4(src_ptr, vl)
#define __riscv_vle8_v_u8m8(src_ptr, vl) __riscv_th_vle8_v_u8m8(src_ptr, vl)
#define __riscv_vle16_v_u16m1(src_ptr, vl) __riscv_th_vle16_v_u16m1(src_ptr, vl)
#define __riscv_vle16_v_u16m2(src_ptr, vl) __riscv_th_vle16_v_u16m2(src_ptr, vl)
#define __riscv_vle16_v_u16m4(src_ptr, vl) __riscv_th_vle16_v_u16m4(src_ptr, vl)
#define __riscv_vle16_v_u16m8(src_ptr, vl) __riscv_th_vle16_v_u16m8(src_ptr, vl)
#define __riscv_vle32_v_u32m1(src_ptr, vl) __riscv_th_vle32_v_u32m1(src_ptr, vl)
#define __riscv_vle32_v_u32m2(src_ptr, vl) __riscv_th_vle32_v_u32m2(src_ptr, vl)
#define __riscv_vle32_v_u32m4(src_ptr, vl) __riscv_th_vle32_v_u32m4(src_ptr, vl)
#define __riscv_vle32_v_u32m8(src_ptr, vl) __riscv_th_vle32_v_u32m8(src_ptr, vl)
#define __riscv_vle64_v_u64m1(src_ptr, vl) __riscv_th_vle64_v_u64m1(src_ptr, vl)
#define __riscv_vle64_v_u64m2(src_ptr, vl) __riscv_th_vle64_v_u64m2(src_ptr, vl)
#define __riscv_vle64_v_u64m4(src_ptr, vl) __riscv_th_vle64_v_u64m4(src_ptr, vl)
#define __riscv_vle64_v_u64m8(src_ptr, vl) __riscv_th_vle64_v_u64m8(src_ptr, vl)
#define __riscv_vle16_v_f16m1(src_ptr, vl) __riscv_th_vle16_v_f16m1(src_ptr, vl)
#define __riscv_vle16_v_f16m2(src_ptr, vl) __riscv_th_vle16_v_f16m2(src_ptr, vl)
#define __riscv_vle16_v_f16m4(src_ptr, vl) __riscv_th_vle16_v_f16m4(src_ptr, vl)
#define __riscv_vle16_v_f16m8(src_ptr, vl) __riscv_th_vle16_v_f16m8(src_ptr, vl)
#define __riscv_vle32_v_f32m1(src_ptr, vl) __riscv_th_vle32_v_f32m1(src_ptr, vl)
#define __riscv_vle32_v_f32m2(src_ptr, vl) __riscv_th_vle32_v_f32m2(src_ptr, vl)
#define __riscv_vle32_v_f32m4(src_ptr, vl) __riscv_th_vle32_v_f32m4(src_ptr, vl)
#define __riscv_vle32_v_f32m8(src_ptr, vl) __riscv_th_vle32_v_f32m8(src_ptr, vl)
#define __riscv_vle64_v_f64m1(src_ptr, vl) __riscv_th_vle64_v_f64m1(src_ptr, vl)
#define __riscv_vle64_v_f64m2(src_ptr, vl) __riscv_th_vle64_v_f64m2(src_ptr, vl)
#define __riscv_vle64_v_f64m4(src_ptr, vl) __riscv_th_vle64_v_f64m4(src_ptr, vl)
#define __riscv_vle64_v_f64m8(src_ptr, vl) __riscv_th_vle64_v_f64m8(src_ptr, vl)

// Vector Unit-stride stores
#define __riscv_vsb_v_i8m1(dst_ptr, vector_value, vl) __riscv_th_vsb_v_i8m1(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_i8m2(dst_ptr, vector_value, vl) __riscv_th_vsb_v_i8m2(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_i8m4(dst_ptr, vector_value, vl) __riscv_th_vsb_v_i8m4(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_i8m8(dst_ptr, vector_value, vl) __riscv_th_vsb_v_i8m8(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_i16m1(dst_ptr, vector_value, vl) __riscv_th_vsb_v_i16m1(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_i16m2(dst_ptr, vector_value, vl) __riscv_th_vsb_v_i16m2(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_i16m4(dst_ptr, vector_value, vl) __riscv_th_vsb_v_i16m4(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_i16m8(dst_ptr, vector_value, vl) __riscv_th_vsb_v_i16m8(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_i32m1(dst_ptr, vector_value, vl) __riscv_th_vsb_v_i32m1(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_i32m2(dst_ptr, vector_value, vl) __riscv_th_vsb_v_i32m2(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_i32m4(dst_ptr, vector_value, vl) __riscv_th_vsb_v_i32m4(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_i32m8(dst_ptr, vector_value, vl) __riscv_th_vsb_v_i32m8(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_i64m1(dst_ptr, vector_value, vl) __riscv_th_vsb_v_i64m1(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_i64m2(dst_ptr, vector_value, vl) __riscv_th_vsb_v_i64m2(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_i64m4(dst_ptr, vector_value, vl) __riscv_th_vsb_v_i64m4(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_i64m8(dst_ptr, vector_value, vl) __riscv_th_vsb_v_i64m8(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_i8m1(dst_ptr, vector_value, vl) __riscv_th_vsh_v_i8m1(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_i8m2(dst_ptr, vector_value, vl) __riscv_th_vsh_v_i8m2(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_i8m4(dst_ptr, vector_value, vl) __riscv_th_vsh_v_i8m4(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_i8m8(dst_ptr, vector_value, vl) __riscv_th_vsh_v_i8m8(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_i16m1(dst_ptr, vector_value, vl) __riscv_th_vsh_v_i16m1(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_i16m2(dst_ptr, vector_value, vl) __riscv_th_vsh_v_i16m2(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_i16m4(dst_ptr, vector_value, vl) __riscv_th_vsh_v_i16m4(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_i16m8(dst_ptr, vector_value, vl) __riscv_th_vsh_v_i16m8(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_i32m1(dst_ptr, vector_value, vl) __riscv_th_vsh_v_i32m1(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_i32m2(dst_ptr, vector_value, vl) __riscv_th_vsh_v_i32m2(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_i32m4(dst_ptr, vector_value, vl) __riscv_th_vsh_v_i32m4(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_i32m8(dst_ptr, vector_value, vl) __riscv_th_vsh_v_i32m8(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_i64m1(dst_ptr, vector_value, vl) __riscv_th_vsh_v_i64m1(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_i64m2(dst_ptr, vector_value, vl) __riscv_th_vsh_v_i64m2(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_i64m4(dst_ptr, vector_value, vl) __riscv_th_vsh_v_i64m4(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_i64m8(dst_ptr, vector_value, vl) __riscv_th_vsh_v_i64m8(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_i8m1(dst_ptr, vector_value, vl) __riscv_th_vsw_v_i8m1(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_i8m2(dst_ptr, vector_value, vl) __riscv_th_vsw_v_i8m2(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_i8m4(dst_ptr, vector_value, vl) __riscv_th_vsw_v_i8m4(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_i8m8(dst_ptr, vector_value, vl) __riscv_th_vsw_v_i8m8(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_i16m1(dst_ptr, vector_value, vl) __riscv_th_vsw_v_i16m1(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_i16m2(dst_ptr, vector_value, vl) __riscv_th_vsw_v_i16m2(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_i16m4(dst_ptr, vector_value, vl) __riscv_th_vsw_v_i16m4(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_i16m8(dst_ptr, vector_value, vl) __riscv_th_vsw_v_i16m8(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_i32m1(dst_ptr, vector_value, vl) __riscv_th_vsw_v_i32m1(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_i32m2(dst_ptr, vector_value, vl) __riscv_th_vsw_v_i32m2(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_i32m4(dst_ptr, vector_value, vl) __riscv_th_vsw_v_i32m4(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_i32m8(dst_ptr, vector_value, vl) __riscv_th_vsw_v_i32m8(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_i64m1(dst_ptr, vector_value, vl) __riscv_th_vsw_v_i64m1(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_i64m2(dst_ptr, vector_value, vl) __riscv_th_vsw_v_i64m2(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_i64m4(dst_ptr, vector_value, vl) __riscv_th_vsw_v_i64m4(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_i64m8(dst_ptr, vector_value, vl) __riscv_th_vsw_v_i64m8(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_u8m1(dst_ptr, vector_value, vl) __riscv_th_vsb_v_u8m1(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_u8m2(dst_ptr, vector_value, vl) __riscv_th_vsb_v_u8m2(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_u8m4(dst_ptr, vector_value, vl) __riscv_th_vsb_v_u8m4(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_u8m8(dst_ptr, vector_value, vl) __riscv_th_vsb_v_u8m8(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_u16m1(dst_ptr, vector_value, vl) __riscv_th_vsb_v_u16m1(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_u16m2(dst_ptr, vector_value, vl) __riscv_th_vsb_v_u16m2(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_u16m4(dst_ptr, vector_value, vl) __riscv_th_vsb_v_u16m4(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_u16m8(dst_ptr, vector_value, vl) __riscv_th_vsb_v_u16m8(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_u32m1(dst_ptr, vector_value, vl) __riscv_th_vsb_v_u32m1(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_u32m2(dst_ptr, vector_value, vl) __riscv_th_vsb_v_u32m2(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_u32m4(dst_ptr, vector_value, vl) __riscv_th_vsb_v_u32m4(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_u32m8(dst_ptr, vector_value, vl) __riscv_th_vsb_v_u32m8(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_u64m1(dst_ptr, vector_value, vl) __riscv_th_vsb_v_u64m1(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_u64m2(dst_ptr, vector_value, vl) __riscv_th_vsb_v_u64m2(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_u64m4(dst_ptr, vector_value, vl) __riscv_th_vsb_v_u64m4(dst_ptr, vector_value, vl)
#define __riscv_vsb_v_u64m8(dst_ptr, vector_value, vl) __riscv_th_vsb_v_u64m8(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_u8m1(dst_ptr, vector_value, vl) __riscv_th_vsh_v_u8m1(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_u8m2(dst_ptr, vector_value, vl) __riscv_th_vsh_v_u8m2(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_u8m4(dst_ptr, vector_value, vl) __riscv_th_vsh_v_u8m4(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_u8m8(dst_ptr, vector_value, vl) __riscv_th_vsh_v_u8m8(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_u16m1(dst_ptr, vector_value, vl) __riscv_th_vsh_v_u16m1(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_u16m2(dst_ptr, vector_value, vl) __riscv_th_vsh_v_u16m2(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_u16m4(dst_ptr, vector_value, vl) __riscv_th_vsh_v_u16m4(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_u16m8(dst_ptr, vector_value, vl) __riscv_th_vsh_v_u16m8(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_u32m1(dst_ptr, vector_value, vl) __riscv_th_vsh_v_u32m1(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_u32m2(dst_ptr, vector_value, vl) __riscv_th_vsh_v_u32m2(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_u32m4(dst_ptr, vector_value, vl) __riscv_th_vsh_v_u32m4(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_u32m8(dst_ptr, vector_value, vl) __riscv_th_vsh_v_u32m8(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_u64m1(dst_ptr, vector_value, vl) __riscv_th_vsh_v_u64m1(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_u64m2(dst_ptr, vector_value, vl) __riscv_th_vsh_v_u64m2(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_u64m4(dst_ptr, vector_value, vl) __riscv_th_vsh_v_u64m4(dst_ptr, vector_value, vl)
#define __riscv_vsh_v_u64m8(dst_ptr, vector_value, vl) __riscv_th_vsh_v_u64m8(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_u8m1(dst_ptr, vector_value, vl) __riscv_th_vsw_v_u8m1(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_u8m2(dst_ptr, vector_value, vl) __riscv_th_vsw_v_u8m2(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_u8m4(dst_ptr, vector_value, vl) __riscv_th_vsw_v_u8m4(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_u8m8(dst_ptr, vector_value, vl) __riscv_th_vsw_v_u8m8(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_u16m1(dst_ptr, vector_value, vl) __riscv_th_vsw_v_u16m1(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_u16m2(dst_ptr, vector_value, vl) __riscv_th_vsw_v_u16m2(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_u16m4(dst_ptr, vector_value, vl) __riscv_th_vsw_v_u16m4(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_u16m8(dst_ptr, vector_value, vl) __riscv_th_vsw_v_u16m8(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_u32m1(dst_ptr, vector_value, vl) __riscv_th_vsw_v_u32m1(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_u32m2(dst_ptr, vector_value, vl) __riscv_th_vsw_v_u32m2(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_u32m4(dst_ptr, vector_value, vl) __riscv_th_vsw_v_u32m4(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_u32m8(dst_ptr, vector_value, vl) __riscv_th_vsw_v_u32m8(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_u64m1(dst_ptr, vector_value, vl) __riscv_th_vsw_v_u64m1(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_u64m2(dst_ptr, vector_value, vl) __riscv_th_vsw_v_u64m2(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_u64m4(dst_ptr, vector_value, vl) __riscv_th_vsw_v_u64m4(dst_ptr, vector_value, vl)
#define __riscv_vsw_v_u64m8(dst_ptr, vector_value, vl) __riscv_th_vsw_v_u64m8(dst_ptr, vector_value, vl)
#define __riscv_vse8_v_i8m1(dst_ptr, vector_value, vl) __riscv_th_vse8_v_i8m1(dst_ptr, vector_value, vl)
#define __riscv_vse8_v_i8m2(dst_ptr, vector_value, vl) __riscv_th_vse8_v_i8m2(dst_ptr, vector_value, vl)
#define __riscv_vse8_v_i8m4(dst_ptr, vector_value, vl) __riscv_th_vse8_v_i8m4(dst_ptr, vector_value, vl)
#define __riscv_vse8_v_i8m8(dst_ptr, vector_value, vl) __riscv_th_vse8_v_i8m8(dst_ptr, vector_value, vl)
#define __riscv_vse16_v_i16m1(dst_ptr, vector_value, vl) __riscv_th_vse16_v_i16m1(dst_ptr, vector_value, vl)
#define __riscv_vse16_v_i16m2(dst_ptr, vector_value, vl) __riscv_th_vse16_v_i16m2(dst_ptr, vector_value, vl)
#define __riscv_vse16_v_i16m4(dst_ptr, vector_value, vl) __riscv_th_vse16_v_i16m4(dst_ptr, vector_value, vl)
#define __riscv_vse16_v_i16m8(dst_ptr, vector_value, vl) __riscv_th_vse16_v_i16m8(dst_ptr, vector_value, vl)
#define __riscv_vse32_v_i32m1(dst_ptr, vector_value, vl) __riscv_th_vse32_v_i32m1(dst_ptr, vector_value, vl)
#define __riscv_vse32_v_i32m2(dst_ptr, vector_value, vl) __riscv_th_vse32_v_i32m2(dst_ptr, vector_value, vl)
#define __riscv_vse32_v_i32m4(dst_ptr, vector_value, vl) __riscv_th_vse32_v_i32m4(dst_ptr, vector_value, vl)
#define __riscv_vse32_v_i32m8(dst_ptr, vector_value, vl) __riscv_th_vse32_v_i32m8(dst_ptr, vector_value, vl)
#define __riscv_vse64_v_i64m1(dst_ptr, vector_value, vl) __riscv_th_vse64_v_i64m1(dst_ptr, vector_value, vl)
#define __riscv_vse64_v_i64m2(dst_ptr, vector_value, vl) __riscv_th_vse64_v_i64m2(dst_ptr, vector_value, vl)
#define __riscv_vse64_v_i64m4(dst_ptr, vector_value, vl) __riscv_th_vse64_v_i64m4(dst_ptr, vector_value, vl)
#define __riscv_vse64_v_i64m8(dst_ptr, vector_value, vl) __riscv_th_vse64_v_i64m8(dst_ptr, vector_value, vl)
#define __riscv_vse8_v_u8m1(dst_ptr, vector_value, vl) __riscv_th_vse8_v_u8m1(dst_ptr, vector_value, vl)
#define __riscv_vse8_v_u8m2(dst_ptr, vector_value, vl) __riscv_th_vse8_v_u8m2(dst_ptr, vector_value, vl)
#define __riscv_vse8_v_u8m4(dst_ptr, vector_value, vl) __riscv_th_vse8_v_u8m4(dst_ptr, vector_value, vl)
#define __riscv_vse8_v_u8m8(dst_ptr, vector_value, vl) __riscv_th_vse8_v_u8m8(dst_ptr, vector_value, vl)
#define __riscv_vse16_v_u16m1(dst_ptr, vector_value, vl) __riscv_th_vse16_v_u16m1(dst_ptr, vector_value, vl)
#define __riscv_vse16_v_u16m2(dst_ptr, vector_value, vl) __riscv_th_vse16_v_u16m2(dst_ptr, vector_value, vl)
#define __riscv_vse16_v_u16m4(dst_ptr, vector_value, vl) __riscv_th_vse16_v_u16m4(dst_ptr, vector_value, vl)
#define __riscv_vse16_v_u16m8(dst_ptr, vector_value, vl) __riscv_th_vse16_v_u16m8(dst_ptr, vector_value, vl)
#define __riscv_vse32_v_u32m1(dst_ptr, vector_value, vl) __riscv_th_vse32_v_u32m1(dst_ptr, vector_value, vl)
#define __riscv_vse32_v_u32m2(dst_ptr, vector_value, vl) __riscv_th_vse32_v_u32m2(dst_ptr, vector_value, vl)
#define __riscv_vse32_v_u32m4(dst_ptr, vector_value, vl) __riscv_th_vse32_v_u32m4(dst_ptr, vector_value, vl)
#define __riscv_vse32_v_u32m8(dst_ptr, vector_value, vl) __riscv_th_vse32_v_u32m8(dst_ptr, vector_value, vl)
#define __riscv_vse64_v_u64m1(dst_ptr, vector_value, vl) __riscv_th_vse64_v_u64m1(dst_ptr, vector_value, vl)
#define __riscv_vse64_v_u64m2(dst_ptr, vector_value, vl) __riscv_th_vse64_v_u64m2(dst_ptr, vector_value, vl)
#define __riscv_vse64_v_u64m4(dst_ptr, vector_value, vl) __riscv_th_vse64_v_u64m4(dst_ptr, vector_value, vl)
#define __riscv_vse64_v_u64m8(dst_ptr, vector_value, vl) __riscv_th_vse64_v_u64m8(dst_ptr, vector_value, vl)
#define __riscv_vse16_v_f16m1(dst_ptr, vector_value, vl) __riscv_th_vse16_v_f16m1(dst_ptr, vector_value, vl)
#define __riscv_vse16_v_f16m2(dst_ptr, vector_value, vl) __riscv_th_vse16_v_f16m2(dst_ptr, vector_value, vl)
#define __riscv_vse16_v_f16m4(dst_ptr, vector_value, vl) __riscv_th_vse16_v_f16m4(dst_ptr, vector_value, vl)
#define __riscv_vse16_v_f16m8(dst_ptr, vector_value, vl) __riscv_th_vse16_v_f16m8(dst_ptr, vector_value, vl)
#define __riscv_vse32_v_f32m1(dst_ptr, vector_value, vl) __riscv_th_vse32_v_f32m1(dst_ptr, vector_value, vl)
#define __riscv_vse32_v_f32m2(dst_ptr, vector_value, vl) __riscv_th_vse32_v_f32m2(dst_ptr, vector_value, vl)
#define __riscv_vse32_v_f32m4(dst_ptr, vector_value, vl) __riscv_th_vse32_v_f32m4(dst_ptr, vector_value, vl)
#define __riscv_vse32_v_f32m8(dst_ptr, vector_value, vl) __riscv_th_vse32_v_f32m8(dst_ptr, vector_value, vl)
#define __riscv_vse64_v_f64m1(dst_ptr, vector_value, vl) __riscv_th_vse64_v_f64m1(dst_ptr, vector_value, vl)
#define __riscv_vse64_v_f64m2(dst_ptr, vector_value, vl) __riscv_th_vse64_v_f64m2(dst_ptr, vector_value, vl)
#define __riscv_vse64_v_f64m4(dst_ptr, vector_value, vl) __riscv_th_vse64_v_f64m4(dst_ptr, vector_value, vl)
#define __riscv_vse64_v_f64m8(dst_ptr, vector_value, vl) __riscv_th_vse64_v_f64m8(dst_ptr, vector_value, vl)


enum RVV_CSR {
  RVV_VSTART = 0,
  RVV_VXSAT,
  RVV_VXRM,
};

static __inline__ __attribute__((__always_inline__, __nodebug__))
unsigned long __riscv_vread_csr(enum RVV_CSR __csr) {
  unsigned long __rv = 0;
  switch (__csr) {
    case RVV_VSTART:
      __asm__ __volatile__ ("csrr\t%0, vstart" : "=r"(__rv) : : "memory");
      break;
    case RVV_VXSAT:
      __asm__ __volatile__ ("csrr\t%0, vxsat" : "=r"(__rv) : : "memory");
      break;
    case RVV_VXRM:
      __asm__ __volatile__ ("csrr\t%0, vxrm" : "=r"(__rv) : : "memory");
      break;
  }
  return __rv;
}

static __inline__ __attribute__((__always_inline__, __nodebug__))
void __riscv_vwrite_csr(enum RVV_CSR __csr, unsigned long __value) {
  switch (__csr) {
    case RVV_VSTART:
      __asm__ __volatile__ ("csrw\tvstart, %z0" : : "rJ"(__value) : "memory");
      break;
    case RVV_VXSAT:
      __asm__ __volatile__ ("csrw\tvxsat, %z0" : : "rJ"(__value) : "memory");
      break;
    case RVV_VXRM:
      __asm__ __volatile__ ("csrw\tvxrm, %z0" : : "rJ"(__value) : "memory");
      break;
  }
}


/* These two builtins comes from the 1.0 implementation, */
/* for compatibility, we forward these calls to the corresponding 0.7 builtins. */
#define __builtin_rvv_vsetvli(avl, sew, lmul) __builtin_rvv_th_vsetvl((size_t)(avl), sew, lmul)
#define __builtin_rvv_vsetvlimax(sew, lmul)   __builtin_rvv_th_vsetvlmax(sew, lmul)

#define __riscv_vsetvl_e8m1(avl) __builtin_rvv_th_vsetvl((size_t)(avl), 0, 0)
#define __riscv_vsetvl_e8m2(avl) __builtin_rvv_th_vsetvl((size_t)(avl), 0, 1)
#define __riscv_vsetvl_e8m4(avl) __builtin_rvv_th_vsetvl((size_t)(avl), 0, 2)
#define __riscv_vsetvl_e8m8(avl) __builtin_rvv_th_vsetvl((size_t)(avl), 0, 3)

#define __riscv_vsetvl_e16m1(avl) __builtin_rvv_th_vsetvl((size_t)(avl), 1, 0)
#define __riscv_vsetvl_e16m2(avl) __builtin_rvv_th_vsetvl((size_t)(avl), 1, 1)
#define __riscv_vsetvl_e16m4(avl) __builtin_rvv_th_vsetvl((size_t)(avl), 1, 2)
#define __riscv_vsetvl_e16m8(avl) __builtin_rvv_th_vsetvl((size_t)(avl), 1, 3)

#define __riscv_vsetvl_e32m1(avl) __builtin_rvv_th_vsetvl((size_t)(avl), 2, 0)
#define __riscv_vsetvl_e32m2(avl) __builtin_rvv_th_vsetvl((size_t)(avl), 2, 1)
#define __riscv_vsetvl_e32m4(avl) __builtin_rvv_th_vsetvl((size_t)(avl), 2, 2)
#define __riscv_vsetvl_e32m8(avl) __builtin_rvv_th_vsetvl((size_t)(avl), 2, 3)

#if __riscv_v_elen >= 64
#define __riscv_vsetvl_e64m1(avl) __builtin_rvv_th_vsetvl((size_t)(avl), 3, 0)
#define __riscv_vsetvl_e64m2(avl) __builtin_rvv_th_vsetvl((size_t)(avl), 3, 1)
#define __riscv_vsetvl_e64m4(avl) __builtin_rvv_th_vsetvl((size_t)(avl), 3, 2)
#define __riscv_vsetvl_e64m8(avl) __builtin_rvv_th_vsetvl((size_t)(avl), 3, 3)
#endif

#define __riscv_vsetvlmax_e8m1() __builtin_rvv_th_vsetvlmax(0, 0)
#define __riscv_vsetvlmax_e8m2() __builtin_rvv_th_vsetvlmax(0, 1)
#define __riscv_vsetvlmax_e8m4() __builtin_rvv_th_vsetvlmax(0, 2)
#define __riscv_vsetvlmax_e8m8() __builtin_rvv_th_vsetvlmax(0, 3)

#define __riscv_vsetvlmax_e16m1() __builtin_rvv_th_vsetvlmax(1, 0)
#define __riscv_vsetvlmax_e16m2() __builtin_rvv_th_vsetvlmax(1, 1)
#define __riscv_vsetvlmax_e16m4() __builtin_rvv_th_vsetvlmax(1, 2)
#define __riscv_vsetvlmax_e16m8() __builtin_rvv_th_vsetvlmax(1, 3)

#define __riscv_vsetvlmax_e32m1() __builtin_rvv_th_vsetvlmax(2, 0)
#define __riscv_vsetvlmax_e32m2() __builtin_rvv_th_vsetvlmax(2, 1)
#define __riscv_vsetvlmax_e32m4() __builtin_rvv_th_vsetvlmax(2, 2)
#define __riscv_vsetvlmax_e32m8() __builtin_rvv_th_vsetvlmax(2, 3)

#if __riscv_v_elen >= 64
#define __riscv_vsetvlmax_e64m1() __builtin_rvv_th_vsetvlmax(3, 0)
#define __riscv_vsetvlmax_e64m2() __builtin_rvv_th_vsetvlmax(3, 1)
#define __riscv_vsetvlmax_e64m4() __builtin_rvv_th_vsetvlmax(3, 2)
#define __riscv_vsetvlmax_e64m8() __builtin_rvv_th_vsetvlmax(3, 3)
#endif


// Vector Widening Integer Add and Subtract
#define __riscv_vwadd_vv_i16m2(op1_v, op2_v, vl) __riscv_th_vwadd_vv_i16m2(op1_v, op2_v, vl)
#define __riscv_vwadd_vv_i16m4(op1_v, op2_v, vl) __riscv_th_vwadd_vv_i16m4(op1_v, op2_v, vl)
#define __riscv_vwadd_vv_i16m8(op1_v, op2_v, vl) __riscv_th_vwadd_vv_i16m8(op1_v, op2_v, vl)
#define __riscv_vwadd_vv_i32m1(op1_v, op2_v, vl) __riscv_th_vwadd_vv_i32m1(op1_v, op2_v, vl)
#define __riscv_vwadd_vv_i32m2(op1_v, op2_v, vl) __riscv_th_vwadd_vv_i32m2(op1_v, op2_v, vl)
#define __riscv_vwadd_vv_i32m4(op1_v, op2_v, vl) __riscv_th_vwadd_vv_i32m4(op1_v, op2_v, vl)
#define __riscv_vwadd_vv_i32m8(op1_v, op2_v, vl) __riscv_th_vwadd_vv_i32m8(op1_v, op2_v, vl)
#define __riscv_vwadd_vv_i64m1(op1_v, op2_v, vl) __riscv_th_vwadd_vv_i64m1(op1_v, op2_v, vl)
#define __riscv_vwadd_vv_i64m2(op1_v, op2_v, vl) __riscv_th_vwadd_vv_i64m2(op1_v, op2_v, vl)
#define __riscv_vwadd_vv_i64m4(op1_v, op2_v, vl) __riscv_th_vwadd_vv_i64m4(op1_v, op2_v, vl)
#define __riscv_vwadd_vv_i64m8(op1_v, op2_v, vl) __riscv_th_vwadd_vv_i64m8(op1_v, op2_v, vl)

#define __riscv_vwaddu_vv_u16m2(op1_v, op2_v, vl) __riscv_th_vwaddu_vv_u16m2(op1_v, op2_v, vl)
#define __riscv_vwaddu_vv_u16m4(op1_v, op2_v, vl) __riscv_th_vwaddu_vv_u16m4(op1_v, op2_v, vl)
#define __riscv_vwaddu_vv_u16m8(op1_v, op2_v, vl) __riscv_th_vwaddu_vv_u16m8(op1_v, op2_v, vl)
#define __riscv_vwaddu_vv_u32m1(op1_v, op2_v, vl) __riscv_th_vwaddu_vv_u32m1(op1_v, op2_v, vl)
#define __riscv_vwaddu_vv_u32m2(op1_v, op2_v, vl) __riscv_th_vwaddu_vv_u32m2(op1_v, op2_v, vl)
#define __riscv_vwaddu_vv_u32m4(op1_v, op2_v, vl) __riscv_th_vwaddu_vv_u32m4(op1_v, op2_v, vl)
#define __riscv_vwaddu_vv_u32m8(op1_v, op2_v, vl) __riscv_th_vwaddu_vv_u32m8(op1_v, op2_v, vl)
#define __riscv_vwaddu_vv_u64m1(op1_v, op2_v, vl) __riscv_th_vwaddu_vv_u64m1(op1_v, op2_v, vl)
#define __riscv_vwaddu_vv_u64m2(op1_v, op2_v, vl) __riscv_th_vwaddu_vv_u64m2(op1_v, op2_v, vl)
#define __riscv_vwaddu_vv_u64m4(op1_v, op2_v, vl) __riscv_th_vwaddu_vv_u64m4(op1_v, op2_v, vl)
#define __riscv_vwaddu_vv_u64m8(op1_v, op2_v, vl) __riscv_th_vwaddu_vv_u64m8(op1_v, op2_v, vl)

#define __riscv_vwadd_vx_i16m2(op1_v, op2_x, vl) __riscv_th_vwadd_vx_i16m2(op1_v, op2_x, vl)
#define __riscv_vwadd_vx_i16m4(op1_v, op2_x, vl) __riscv_th_vwadd_vx_i16m4(op1_v, op2_x, vl)
#define __riscv_vwadd_vx_i16m8(op1_v, op2_x, vl) __riscv_th_vwadd_vx_i16m8(op1_v, op2_x, vl)
#define __riscv_vwadd_vx_i32m1(op1_v, op2_x, vl) __riscv_th_vwadd_vx_i32m1(op1_v, op2_x, vl)
#define __riscv_vwadd_vx_i32m2(op1_v, op2_x, vl) __riscv_th_vwadd_vx_i32m2(op1_v, op2_x, vl)
#define __riscv_vwadd_vx_i32m4(op1_v, op2_x, vl) __riscv_th_vwadd_vx_i32m4(op1_v, op2_x, vl)
#define __riscv_vwadd_vx_i32m8(op1_v, op2_x, vl) __riscv_th_vwadd_vx_i32m8(op1_v, op2_x, vl)
#define __riscv_vwadd_vx_i64m1(op1_v, op2_x, vl) __riscv_th_vwadd_vx_i64m1(op1_v, op2_x, vl)
#define __riscv_vwadd_vx_i64m2(op1_v, op2_x, vl) __riscv_th_vwadd_vx_i64m2(op1_v, op2_x, vl)
#define __riscv_vwadd_vx_i64m4(op1_v, op2_x, vl) __riscv_th_vwadd_vx_i64m4(op1_v, op2_x, vl)
#define __riscv_vwadd_vx_i64m8(op1_v, op2_x, vl) __riscv_th_vwadd_vx_i64m8(op1_v, op2_x, vl)

#define __riscv_vwaddu_vx_u16m2(op1_v, op2_x, vl) __riscv_th_vwaddu_vx_u16m2(op1_v, op2_x, vl)
#define __riscv_vwaddu_vx_u16m4(op1_v, op2_x, vl) __riscv_th_vwaddu_vx_u16m4(op1_v, op2_x, vl)
#define __riscv_vwaddu_vx_u16m8(op1_v, op2_x, vl) __riscv_th_vwaddu_vx_u16m8(op1_v, op2_x, vl)
#define __riscv_vwaddu_vx_u32m1(op1_v, op2_x, vl) __riscv_th_vwaddu_vx_u32m1(op1_v, op2_x, vl)
#define __riscv_vwaddu_vx_u32m2(op1_v, op2_x, vl) __riscv_th_vwaddu_vx_u32m2(op1_v, op2_x, vl)
#define __riscv_vwaddu_vx_u32m4(op1_v, op2_x, vl) __riscv_th_vwaddu_vx_u32m4(op1_v, op2_x, vl)
#define __riscv_vwaddu_vx_u32m8(op1_v, op2_x, vl) __riscv_th_vwaddu_vx_u32m8(op1_v, op2_x, vl)
#define __riscv_vwaddu_vx_u64m1(op1_v, op2_x, vl) __riscv_th_vwaddu_vx_u64m1(op1_v, op2_x, vl)
#define __riscv_vwaddu_vx_u64m2(op1_v, op2_x, vl) __riscv_th_vwaddu_vx_u64m2(op1_v, op2_x, vl)
#define __riscv_vwaddu_vx_u64m4(op1_v, op2_x, vl) __riscv_th_vwaddu_vx_u64m4(op1_v, op2_x, vl)
#define __riscv_vwaddu_vx_u64m8(op1_v, op2_x, vl) __riscv_th_vwaddu_vx_u64m8(op1_v, op2_x, vl)

#define __riscv_vwadd_wv_i16m2(op1_wv, op2_v, vl) __riscv_th_vwadd_wv_i16m2(op1_wv, op2_v, vl)
#define __riscv_vwadd_wv_i16m4(op1_wv, op2_v, vl) __riscv_th_vwadd_wv_i16m4(op1_wv, op2_v, vl)
#define __riscv_vwadd_wv_i16m8(op1_wv, op2_v, vl) __riscv_th_vwadd_wv_i16m8(op1_wv, op2_v, vl)
#define __riscv_vwadd_wv_i32m1(op1_wv, op2_v, vl) __riscv_th_vwadd_wv_i32m1(op1_wv, op2_v, vl)
#define __riscv_vwadd_wv_i32m2(op1_wv, op2_v, vl) __riscv_th_vwadd_wv_i32m2(op1_wv, op2_v, vl)
#define __riscv_vwadd_wv_i32m4(op1_wv, op2_v, vl) __riscv_th_vwadd_wv_i32m4(op1_wv, op2_v, vl)
#define __riscv_vwadd_wv_i32m8(op1_wv, op2_v, vl) __riscv_th_vwadd_wv_i32m8(op1_wv, op2_v, vl)
#define __riscv_vwadd_wv_i64m1(op1_wv, op2_v, vl) __riscv_th_vwadd_wv_i64m1(op1_wv, op2_v, vl)
#define __riscv_vwadd_wv_i64m2(op1_wv, op2_v, vl) __riscv_th_vwadd_wv_i64m2(op1_wv, op2_v, vl)
#define __riscv_vwadd_wv_i64m4(op1_wv, op2_v, vl) __riscv_th_vwadd_wv_i64m4(op1_wv, op2_v, vl)
#define __riscv_vwadd_wv_i64m8(op1_wv, op2_v, vl) __riscv_th_vwadd_wv_i64m8(op1_wv, op2_v, vl)

#define __riscv_vwaddu_wv_u16m2(op1_wv, op2_v, vl) __riscv_th_vwaddu_wv_u16m2(op1_wv, op2_v, vl)
#define __riscv_vwaddu_wv_u16m4(op1_wv, op2_v, vl) __riscv_th_vwaddu_wv_u16m4(op1_wv, op2_v, vl)
#define __riscv_vwaddu_wv_u16m8(op1_wv, op2_v, vl) __riscv_th_vwaddu_wv_u16m8(op1_wv, op2_v, vl)
#define __riscv_vwaddu_wv_u32m1(op1_wv, op2_v, vl) __riscv_th_vwaddu_wv_u32m1(op1_wv, op2_v, vl)
#define __riscv_vwaddu_wv_u32m2(op1_wv, op2_v, vl) __riscv_th_vwaddu_wv_u32m2(op1_wv, op2_v, vl)
#define __riscv_vwaddu_wv_u32m4(op1_wv, op2_v, vl) __riscv_th_vwaddu_wv_u32m4(op1_wv, op2_v, vl)
#define __riscv_vwaddu_wv_u32m8(op1_wv, op2_v, vl) __riscv_th_vwaddu_wv_u32m8(op1_wv, op2_v, vl)
#define __riscv_vwaddu_wv_u64m1(op1_wv, op2_v, vl) __riscv_th_vwaddu_wv_u64m1(op1_wv, op2_v, vl)
#define __riscv_vwaddu_wv_u64m2(op1_wv, op2_v, vl) __riscv_th_vwaddu_wv_u64m2(op1_wv, op2_v, vl)
#define __riscv_vwaddu_wv_u64m4(op1_wv, op2_v, vl) __riscv_th_vwaddu_wv_u64m4(op1_wv, op2_v, vl)
#define __riscv_vwaddu_wv_u64m8(op1_wv, op2_v, vl) __riscv_th_vwaddu_wv_u64m8(op1_wv, op2_v, vl)

#define __riscv_vwadd_wx_i16m1(op1_wx, op2_x, vl) __riscv_th_vwadd_wx_i16m1(op1_wx, op2_x, vl)
#define __riscv_vwadd_wx_i16m2(op1_wx, op2_x, vl) __riscv_th_vwadd_wx_i16m2(op1_wx, op2_x, vl)
#define __riscv_vwadd_wx_i16m4(op1_wx, op2_x, vl) __riscv_th_vwadd_wx_i16m4(op1_wx, op2_x, vl)
#define __riscv_vwadd_wx_i16m8(op1_wx, op2_x, vl) __riscv_th_vwadd_wx_i16m8(op1_wx, op2_x, vl)
#define __riscv_vwadd_wx_i32m1(op1_wx, op2_x, vl) __riscv_th_vwadd_wx_i32m1(op1_wx, op2_x, vl)
#define __riscv_vwadd_wx_i32m2(op1_wx, op2_x, vl) __riscv_th_vwadd_wx_i32m2(op1_wx, op2_x, vl)
#define __riscv_vwadd_wx_i32m4(op1_wx, op2_x, vl) __riscv_th_vwadd_wx_i32m4(op1_wx, op2_x, vl)
#define __riscv_vwadd_wx_i32m8(op1_wx, op2_x, vl) __riscv_th_vwadd_wx_i32m8(op1_wx, op2_x, vl)
#define __riscv_vwadd_wx_i64m1(op1_wx, op2_x, vl) __riscv_th_vwadd_wx_i64m1(op1_wx, op2_x, vl)
#define __riscv_vwadd_wx_i64m2(op1_wx, op2_x, vl) __riscv_th_vwadd_wx_i64m2(op1_wx, op2_x, vl)
#define __riscv_vwadd_wx_i64m4(op1_wx, op2_x, vl) __riscv_th_vwadd_wx_i64m4(op1_wx, op2_x, vl)
#define __riscv_vwadd_wx_i64m8(op1_wx, op2_x, vl) __riscv_th_vwadd_wx_i64m8(op1_wx, op2_x, vl)

#define __riscv_vwaddu_wx_u16m1(op1_wx, op2_x, vl) __riscv_th_vwaddu_wx_u16m1(op1_wx, op2_x, vl)
#define __riscv_vwaddu_wx_u16m2(op1_wx, op2_x, vl) __riscv_th_vwaddu_wx_u16m2(op1_wx, op2_x, vl)
#define __riscv_vwaddu_wx_u16m4(op1_wx, op2_x, vl) __riscv_th_vwaddu_wx_u16m4(op1_wx, op2_x, vl)
#define __riscv_vwaddu_wx_u16m8(op1_wx, op2_x, vl) __riscv_th_vwaddu_wx_u16m8(op1_wx, op2_x, vl)
#define __riscv_vwaddu_wx_u32m1(op1_wx, op2_x, vl) __riscv_th_vwaddu_wx_u32m1(op1_wx, op2_x, vl)
#define __riscv_vwaddu_wx_u32m2(op1_wx, op2_x, vl) __riscv_th_vwaddu_wx_u32m2(op1_wx, op2_x, vl)
#define __riscv_vwaddu_wx_u32m4(op1_wx, op2_x, vl) __riscv_th_vwaddu_wx_u32m4(op1_wx, op2_x, vl)
#define __riscv_vwaddu_wx_u32m8(op1_wx, op2_x, vl) __riscv_th_vwaddu_wx_u32m8(op1_wx, op2_x, vl)
#define __riscv_vwaddu_wx_u64m1(op1_wx, op2_x, vl) __riscv_th_vwaddu_wx_u64m1(op1_wx, op2_x, vl)
#define __riscv_vwaddu_wx_u64m2(op1_wx, op2_x, vl) __riscv_th_vwaddu_wx_u64m2(op1_wx, op2_x, vl)
#define __riscv_vwaddu_wx_u64m4(op1_wx, op2_x, vl) __riscv_th_vwaddu_wx_u64m4(op1_wx, op2_x, vl)
#define __riscv_vwaddu_wx_u64m8(op1_wx, op2_x, vl) __riscv_th_vwaddu_wx_u64m8(op1_wx, op2_x, vl)

#define __riscv_vwsub_vv_i16m2(op1_v, op2_v, vl) __riscv_th_vwsub_vv_i16m2(op1_v, op2_v, vl)
#define __riscv_vwsub_vv_i16m4(op1_v, op2_v, vl) __riscv_th_vwsub_vv_i16m4(op1_v, op2_v, vl)
#define __riscv_vwsub_vv_i16m8(op1_v, op2_v, vl) __riscv_th_vwsub_vv_i16m8(op1_v, op2_v, vl)
#define __riscv_vwsub_vv_i32m1(op1_v, op2_v, vl) __riscv_th_vwsub_vv_i32m1(op1_v, op2_v, vl)
#define __riscv_vwsub_vv_i32m2(op1_v, op2_v, vl) __riscv_th_vwsub_vv_i32m2(op1_v, op2_v, vl)
#define __riscv_vwsub_vv_i32m4(op1_v, op2_v, vl) __riscv_th_vwsub_vv_i32m4(op1_v, op2_v, vl)
#define __riscv_vwsub_vv_i32m8(op1_v, op2_v, vl) __riscv_th_vwsub_vv_i32m8(op1_v, op2_v, vl)
#define __riscv_vwsub_vv_i64m1(op1_v, op2_v, vl) __riscv_th_vwsub_vv_i64m1(op1_v, op2_v, vl)
#define __riscv_vwsub_vv_i64m2(op1_v, op2_v, vl) __riscv_th_vwsub_vv_i64m2(op1_v, op2_v, vl)
#define __riscv_vwsub_vv_i64m4(op1_v, op2_v, vl) __riscv_th_vwsub_vv_i64m4(op1_v, op2_v, vl)
#define __riscv_vwsub_vv_i64m8(op1_v, op2_v, vl) __riscv_th_vwsub_vv_i64m8(op1_v, op2_v, vl)

#define __riscv_vwsubu_vv_u16m2(op1_v, op2_v, vl) __riscv_th_vwsubu_vv_u16m2(op1_v, op2_v, vl)
#define __riscv_vwsubu_vv_u16m4(op1_v, op2_v, vl) __riscv_th_vwsubu_vv_u16m4(op1_v, op2_v, vl)
#define __riscv_vwsubu_vv_u16m8(op1_v, op2_v, vl) __riscv_th_vwsubu_vv_u16m8(op1_v, op2_v, vl)
#define __riscv_vwsubu_vv_u32m1(op1_v, op2_v, vl) __riscv_th_vwsubu_vv_u32m1(op1_v, op2_v, vl)
#define __riscv_vwsubu_vv_u32m2(op1_v, op2_v, vl) __riscv_th_vwsubu_vv_u32m2(op1_v, op2_v, vl)
#define __riscv_vwsubu_vv_u32m4(op1_v, op2_v, vl) __riscv_th_vwsubu_vv_u32m4(op1_v, op2_v, vl)
#define __riscv_vwsubu_vv_u32m8(op1_v, op2_v, vl) __riscv_th_vwsubu_vv_u32m8(op1_v, op2_v, vl)
#define __riscv_vwsubu_vv_u64m1(op1_v, op2_v, vl) __riscv_th_vwsubu_vv_u64m1(op1_v, op2_v, vl)
#define __riscv_vwsubu_vv_u64m2(op1_v, op2_v, vl) __riscv_th_vwsubu_vv_u64m2(op1_v, op2_v, vl)
#define __riscv_vwsubu_vv_u64m4(op1_v, op2_v, vl) __riscv_th_vwsubu_vv_u64m4(op1_v, op2_v, vl)
#define __riscv_vwsubu_vv_u64m8(op1_v, op2_v, vl) __riscv_th_vwsubu_vv_u64m8(op1_v, op2_v, vl)

#define __riscv_vwsub_vx_i16m2(op1_v, op2_x, vl) __riscv_th_vwsub_vx_i16m2(op1_v, op2_x, vl)
#define __riscv_vwsub_vx_i16m4(op1_v, op2_x, vl) __riscv_th_vwsub_vx_i16m4(op1_v, op2_x, vl)
#define __riscv_vwsub_vx_i16m8(op1_v, op2_x, vl) __riscv_th_vwsub_vx_i16m8(op1_v, op2_x, vl)
#define __riscv_vwsub_vx_i32m1(op1_v, op2_x, vl) __riscv_th_vwsub_vx_i32m1(op1_v, op2_x, vl)
#define __riscv_vwsub_vx_i32m2(op1_v, op2_x, vl) __riscv_th_vwsub_vx_i32m2(op1_v, op2_x, vl)
#define __riscv_vwsub_vx_i32m4(op1_v, op2_x, vl) __riscv_th_vwsub_vx_i32m4(op1_v, op2_x, vl)
#define __riscv_vwsub_vx_i32m8(op1_v, op2_x, vl) __riscv_th_vwsub_vx_i32m8(op1_v, op2_x, vl)
#define __riscv_vwsub_vx_i64m1(op1_v, op2_x, vl) __riscv_th_vwsub_vx_i64m1(op1_v, op2_x, vl)
#define __riscv_vwsub_vx_i64m2(op1_v, op2_x, vl) __riscv_th_vwsub_vx_i64m2(op1_v, op2_x, vl)
#define __riscv_vwsub_vx_i64m4(op1_v, op2_x, vl) __riscv_th_vwsub_vx_i64m4(op1_v, op2_x, vl)
#define __riscv_vwsub_vx_i64m8(op1_v, op2_x, vl) __riscv_th_vwsub_vx_i64m8(op1_v, op2_x, vl)

#define __riscv_vwsubu_vx_u16m2(op1_v, op2_x, vl) __riscv_th_vwsubu_vx_u16m2(op1_v, op2_x, vl)
#define __riscv_vwsubu_vx_u16m4(op1_v, op2_x, vl) __riscv_th_vwsubu_vx_u16m4(op1_v, op2_x, vl)
#define __riscv_vwsubu_vx_u16m8(op1_v, op2_x, vl) __riscv_th_vwsubu_vx_u16m8(op1_v, op2_x, vl)
#define __riscv_vwsubu_vx_u32m1(op1_v, op2_x, vl) __riscv_th_vwsubu_vx_u32m1(op1_v, op2_x, vl)
#define __riscv_vwsubu_vx_u32m2(op1_v, op2_x, vl) __riscv_th_vwsubu_vx_u32m2(op1_v, op2_x, vl)
#define __riscv_vwsubu_vx_u32m4(op1_v, op2_x, vl) __riscv_th_vwsubu_vx_u32m4(op1_v, op2_x, vl)
#define __riscv_vwsubu_vx_u32m8(op1_v, op2_x, vl) __riscv_th_vwsubu_vx_u32m8(op1_v, op2_x, vl)
#define __riscv_vwsubu_vx_u64m1(op1_v, op2_x, vl) __riscv_th_vwsubu_vx_u64m1(op1_v, op2_x, vl)
#define __riscv_vwsubu_vx_u64m2(op1_v, op2_x, vl) __riscv_th_vwsubu_vx_u64m2(op1_v, op2_x, vl)
#define __riscv_vwsubu_vx_u64m4(op1_v, op2_x, vl) __riscv_th_vwsubu_vx_u64m4(op1_v, op2_x, vl)
#define __riscv_vwsubu_vx_u64m8(op1_v, op2_x, vl) __riscv_th_vwsubu_vx_u64m8(op1_v, op2_x, vl)

#define __riscv_vwsub_wv_i16m2(op1_wv, op2_v, vl) __riscv_th_vwsub_wv_i16m2(op1_wv, op2_v, vl)
#define __riscv_vwsub_wv_i16m4(op1_wv, op2_v, vl) __riscv_th_vwsub_wv_i16m4(op1_wv, op2_v, vl)
#define __riscv_vwsub_wv_i16m8(op1_wv, op2_v, vl) __riscv_th_vwsub_wv_i16m8(op1_wv, op2_v, vl)
#define __riscv_vwsub_wv_i32m1(op1_wv, op2_v, vl) __riscv_th_vwsub_wv_i32m1(op1_wv, op2_v, vl)
#define __riscv_vwsub_wv_i32m2(op1_wv, op2_v, vl) __riscv_th_vwsub_wv_i32m2(op1_wv, op2_v, vl)
#define __riscv_vwsub_wv_i32m4(op1_wv, op2_v, vl) __riscv_th_vwsub_wv_i32m4(op1_wv, op2_v, vl)
#define __riscv_vwsub_wv_i32m8(op1_wv, op2_v, vl) __riscv_th_vwsub_wv_i32m8(op1_wv, op2_v, vl)
#define __riscv_vwsub_wv_i64m1(op1_wv, op2_v, vl) __riscv_th_vwsub_wv_i64m1(op1_wv, op2_v, vl)
#define __riscv_vwsub_wv_i64m2(op1_wv, op2_v, vl) __riscv_th_vwsub_wv_i64m2(op1_wv, op2_v, vl)
#define __riscv_vwsub_wv_i64m4(op1_wv, op2_v, vl) __riscv_th_vwsub_wv_i64m4(op1_wv, op2_v, vl)
#define __riscv_vwsub_wv_i64m8(op1_wv, op2_v, vl) __riscv_th_vwsub_wv_i64m8(op1_wv, op2_v, vl)

#define __riscv_vwsubu_wv_u16m2(op1_wv, op2_v, vl) __riscv_th_vwsubu_wv_u16m2(op1_wv, op2_v, vl)
#define __riscv_vwsubu_wv_u16m4(op1_wv, op2_v, vl) __riscv_th_vwsubu_wv_u16m4(op1_wv, op2_v, vl)
#define __riscv_vwsubu_wv_u16m8(op1_wv, op2_v, vl) __riscv_th_vwsubu_wv_u16m8(op1_wv, op2_v, vl)
#define __riscv_vwsubu_wv_u32m1(op1_wv, op2_v, vl) __riscv_th_vwsubu_wv_u32m1(op1_wv, op2_v, vl)
#define __riscv_vwsubu_wv_u32m2(op1_wv, op2_v, vl) __riscv_th_vwsubu_wv_u32m2(op1_wv, op2_v, vl)
#define __riscv_vwsubu_wv_u32m4(op1_wv, op2_v, vl) __riscv_th_vwsubu_wv_u32m4(op1_wv, op2_v, vl)
#define __riscv_vwsubu_wv_u32m8(op1_wv, op2_v, vl) __riscv_th_vwsubu_wv_u32m8(op1_wv, op2_v, vl)
#define __riscv_vwsubu_wv_u64m1(op1_wv, op2_v, vl) __riscv_th_vwsubu_wv_u64m1(op1_wv, op2_v, vl)
#define __riscv_vwsubu_wv_u64m2(op1_wv, op2_v, vl) __riscv_th_vwsubu_wv_u64m2(op1_wv, op2_v, vl)
#define __riscv_vwsubu_wv_u64m4(op1_wv, op2_v, vl) __riscv_th_vwsubu_wv_u64m4(op1_wv, op2_v, vl)
#define __riscv_vwsubu_wv_u64m8(op1_wv, op2_v, vl) __riscv_th_vwsubu_wv_u64m8(op1_wv, op2_v, vl)

#define __riscv_vwsub_wx_i16m1(op1_wx, op2_x, vl) __riscv_th_vwsub_wx_i16m1(op1_wx, op2_x, vl)
#define __riscv_vwsub_wx_i16m2(op1_wx, op2_x, vl) __riscv_th_vwsub_wx_i16m2(op1_wx, op2_x, vl)
#define __riscv_vwsub_wx_i16m4(op1_wx, op2_x, vl) __riscv_th_vwsub_wx_i16m4(op1_wx, op2_x, vl)
#define __riscv_vwsub_wx_i16m8(op1_wx, op2_x, vl) __riscv_th_vwsub_wx_i16m8(op1_wx, op2_x, vl)
#define __riscv_vwsub_wx_i32m1(op1_wx, op2_x, vl) __riscv_th_vwsub_wx_i32m1(op1_wx, op2_x, vl)
#define __riscv_vwsub_wx_i32m2(op1_wx, op2_x, vl) __riscv_th_vwsub_wx_i32m2(op1_wx, op2_x, vl)
#define __riscv_vwsub_wx_i32m4(op1_wx, op2_x, vl) __riscv_th_vwsub_wx_i32m4(op1_wx, op2_x, vl)
#define __riscv_vwsub_wx_i32m8(op1_wx, op2_x, vl) __riscv_th_vwsub_wx_i32m8(op1_wx, op2_x, vl)
#define __riscv_vwsub_wx_i64m1(op1_wx, op2_x, vl) __riscv_th_vwsub_wx_i64m1(op1_wx, op2_x, vl)
#define __riscv_vwsub_wx_i64m2(op1_wx, op2_x, vl) __riscv_th_vwsub_wx_i64m2(op1_wx, op2_x, vl)
#define __riscv_vwsub_wx_i64m4(op1_wx, op2_x, vl) __riscv_th_vwsub_wx_i64m4(op1_wx, op2_x, vl)
#define __riscv_vwsub_wx_i64m8(op1_wx, op2_x, vl) __riscv_th_vwsub_wx_i64m8(op1_wx, op2_x, vl)

#define __riscv_vwsubu_wx_u16m1(op1_wx, op2_x, vl) __riscv_th_vwsubu_wx_u16m1(op1_wx, op2_x, vl)
#define __riscv_vwsubu_wx_u16m2(op1_wx, op2_x, vl) __riscv_th_vwsubu_wx_u16m2(op1_wx, op2_x, vl)
#define __riscv_vwsubu_wx_u16m4(op1_wx, op2_x, vl) __riscv_th_vwsubu_wx_u16m4(op1_wx, op2_x, vl)
#define __riscv_vwsubu_wx_u16m8(op1_wx, op2_x, vl) __riscv_th_vwsubu_wx_u16m8(op1_wx, op2_x, vl)
#define __riscv_vwsubu_wx_u32m1(op1_wx, op2_x, vl) __riscv_th_vwsubu_wx_u32m1(op1_wx, op2_x, vl)
#define __riscv_vwsubu_wx_u32m2(op1_wx, op2_x, vl) __riscv_th_vwsubu_wx_u32m2(op1_wx, op2_x, vl)
#define __riscv_vwsubu_wx_u32m4(op1_wx, op2_x, vl) __riscv_th_vwsubu_wx_u32m4(op1_wx, op2_x, vl)
#define __riscv_vwsubu_wx_u32m8(op1_wx, op2_x, vl) __riscv_th_vwsubu_wx_u32m8(op1_wx, op2_x, vl)
#define __riscv_vwsubu_wx_u64m1(op1_wx, op2_x, vl) __riscv_th_vwsubu_wx_u64m1(op1_wx, op2_x, vl)
#define __riscv_vwsubu_wx_u64m2(op1_wx, op2_x, vl) __riscv_th_vwsubu_wx_u64m2(op1_wx, op2_x, vl)
#define __riscv_vwsubu_wx_u64m4(op1_wx, op2_x, vl) __riscv_th_vwsubu_wx_u64m4(op1_wx, op2_x, vl)
#define __riscv_vwsubu_wx_u64m8(op1_wx, op2_x, vl) __riscv_th_vwsubu_wx_u64m8(op1_wx, op2_x, vl)


enum __RISCV_VXRM {
  __RISCV_VXRM_RNU = 0,
  __RISCV_VXRM_RNE = 1,
  __RISCV_VXRM_RDN = 2,
  __RISCV_VXRM_ROD = 3,
};
typedef __rvv_bool64_t vbool64_t;
typedef __rvv_bool32_t vbool32_t;
typedef __rvv_bool16_t vbool16_t;
typedef __rvv_bool8_t vbool8_t;
typedef __rvv_bool4_t vbool4_t;
typedef __rvv_bool2_t vbool2_t;
typedef __rvv_bool1_t vbool1_t;
typedef __rvv_int8mf8_t vint8mf8_t;
typedef __rvv_uint8mf8_t vuint8mf8_t;
typedef __rvv_int8mf8x2_t vint8mf8x2_t;
typedef __rvv_uint8mf8x2_t vuint8mf8x2_t;
typedef __rvv_int8mf8x3_t vint8mf8x3_t;
typedef __rvv_uint8mf8x3_t vuint8mf8x3_t;
typedef __rvv_int8mf8x4_t vint8mf8x4_t;
typedef __rvv_uint8mf8x4_t vuint8mf8x4_t;
typedef __rvv_int8mf8x5_t vint8mf8x5_t;
typedef __rvv_uint8mf8x5_t vuint8mf8x5_t;
typedef __rvv_int8mf8x6_t vint8mf8x6_t;
typedef __rvv_uint8mf8x6_t vuint8mf8x6_t;
typedef __rvv_int8mf8x7_t vint8mf8x7_t;
typedef __rvv_uint8mf8x7_t vuint8mf8x7_t;
typedef __rvv_int8mf8x8_t vint8mf8x8_t;
typedef __rvv_uint8mf8x8_t vuint8mf8x8_t;
typedef __rvv_int8mf4_t vint8mf4_t;
typedef __rvv_uint8mf4_t vuint8mf4_t;
typedef __rvv_int8mf4x2_t vint8mf4x2_t;
typedef __rvv_uint8mf4x2_t vuint8mf4x2_t;
typedef __rvv_int8mf4x3_t vint8mf4x3_t;
typedef __rvv_uint8mf4x3_t vuint8mf4x3_t;
typedef __rvv_int8mf4x4_t vint8mf4x4_t;
typedef __rvv_uint8mf4x4_t vuint8mf4x4_t;
typedef __rvv_int8mf4x5_t vint8mf4x5_t;
typedef __rvv_uint8mf4x5_t vuint8mf4x5_t;
typedef __rvv_int8mf4x6_t vint8mf4x6_t;
typedef __rvv_uint8mf4x6_t vuint8mf4x6_t;
typedef __rvv_int8mf4x7_t vint8mf4x7_t;
typedef __rvv_uint8mf4x7_t vuint8mf4x7_t;
typedef __rvv_int8mf4x8_t vint8mf4x8_t;
typedef __rvv_uint8mf4x8_t vuint8mf4x8_t;
typedef __rvv_int8mf2_t vint8mf2_t;
typedef __rvv_uint8mf2_t vuint8mf2_t;
typedef __rvv_int8mf2x2_t vint8mf2x2_t;
typedef __rvv_uint8mf2x2_t vuint8mf2x2_t;
typedef __rvv_int8mf2x3_t vint8mf2x3_t;
typedef __rvv_uint8mf2x3_t vuint8mf2x3_t;
typedef __rvv_int8mf2x4_t vint8mf2x4_t;
typedef __rvv_uint8mf2x4_t vuint8mf2x4_t;
typedef __rvv_int8mf2x5_t vint8mf2x5_t;
typedef __rvv_uint8mf2x5_t vuint8mf2x5_t;
typedef __rvv_int8mf2x6_t vint8mf2x6_t;
typedef __rvv_uint8mf2x6_t vuint8mf2x6_t;
typedef __rvv_int8mf2x7_t vint8mf2x7_t;
typedef __rvv_uint8mf2x7_t vuint8mf2x7_t;
typedef __rvv_int8mf2x8_t vint8mf2x8_t;
typedef __rvv_uint8mf2x8_t vuint8mf2x8_t;
typedef __rvv_int8m1_t vint8m1_t;
typedef __rvv_uint8m1_t vuint8m1_t;
typedef __rvv_int8m1x2_t vint8m1x2_t;
typedef __rvv_uint8m1x2_t vuint8m1x2_t;
typedef __rvv_int8m1x3_t vint8m1x3_t;
typedef __rvv_uint8m1x3_t vuint8m1x3_t;
typedef __rvv_int8m1x4_t vint8m1x4_t;
typedef __rvv_uint8m1x4_t vuint8m1x4_t;
typedef __rvv_int8m1x5_t vint8m1x5_t;
typedef __rvv_uint8m1x5_t vuint8m1x5_t;
typedef __rvv_int8m1x6_t vint8m1x6_t;
typedef __rvv_uint8m1x6_t vuint8m1x6_t;
typedef __rvv_int8m1x7_t vint8m1x7_t;
typedef __rvv_uint8m1x7_t vuint8m1x7_t;
typedef __rvv_int8m1x8_t vint8m1x8_t;
typedef __rvv_uint8m1x8_t vuint8m1x8_t;
typedef __rvv_int8m2_t vint8m2_t;
typedef __rvv_uint8m2_t vuint8m2_t;
typedef __rvv_int8m2x2_t vint8m2x2_t;
typedef __rvv_uint8m2x2_t vuint8m2x2_t;
typedef __rvv_int8m2x3_t vint8m2x3_t;
typedef __rvv_uint8m2x3_t vuint8m2x3_t;
typedef __rvv_int8m2x4_t vint8m2x4_t;
typedef __rvv_uint8m2x4_t vuint8m2x4_t;
typedef __rvv_int8m4_t vint8m4_t;
typedef __rvv_uint8m4_t vuint8m4_t;
typedef __rvv_int8m4x2_t vint8m4x2_t;
typedef __rvv_uint8m4x2_t vuint8m4x2_t;
typedef __rvv_int8m8_t vint8m8_t;
typedef __rvv_uint8m8_t vuint8m8_t;
typedef __rvv_int16mf4_t vint16mf4_t;
typedef __rvv_uint16mf4_t vuint16mf4_t;
typedef __rvv_int16mf4x2_t vint16mf4x2_t;
typedef __rvv_uint16mf4x2_t vuint16mf4x2_t;
typedef __rvv_int16mf4x3_t vint16mf4x3_t;
typedef __rvv_uint16mf4x3_t vuint16mf4x3_t;
typedef __rvv_int16mf4x4_t vint16mf4x4_t;
typedef __rvv_uint16mf4x4_t vuint16mf4x4_t;
typedef __rvv_int16mf4x5_t vint16mf4x5_t;
typedef __rvv_uint16mf4x5_t vuint16mf4x5_t;
typedef __rvv_int16mf4x6_t vint16mf4x6_t;
typedef __rvv_uint16mf4x6_t vuint16mf4x6_t;
typedef __rvv_int16mf4x7_t vint16mf4x7_t;
typedef __rvv_uint16mf4x7_t vuint16mf4x7_t;
typedef __rvv_int16mf4x8_t vint16mf4x8_t;
typedef __rvv_uint16mf4x8_t vuint16mf4x8_t;
typedef __rvv_int16mf2_t vint16mf2_t;
typedef __rvv_uint16mf2_t vuint16mf2_t;
typedef __rvv_int16mf2x2_t vint16mf2x2_t;
typedef __rvv_uint16mf2x2_t vuint16mf2x2_t;
typedef __rvv_int16mf2x3_t vint16mf2x3_t;
typedef __rvv_uint16mf2x3_t vuint16mf2x3_t;
typedef __rvv_int16mf2x4_t vint16mf2x4_t;
typedef __rvv_uint16mf2x4_t vuint16mf2x4_t;
typedef __rvv_int16mf2x5_t vint16mf2x5_t;
typedef __rvv_uint16mf2x5_t vuint16mf2x5_t;
typedef __rvv_int16mf2x6_t vint16mf2x6_t;
typedef __rvv_uint16mf2x6_t vuint16mf2x6_t;
typedef __rvv_int16mf2x7_t vint16mf2x7_t;
typedef __rvv_uint16mf2x7_t vuint16mf2x7_t;
typedef __rvv_int16mf2x8_t vint16mf2x8_t;
typedef __rvv_uint16mf2x8_t vuint16mf2x8_t;
typedef __rvv_int16m1_t vint16m1_t;
typedef __rvv_uint16m1_t vuint16m1_t;
typedef __rvv_int16m1x2_t vint16m1x2_t;
typedef __rvv_uint16m1x2_t vuint16m1x2_t;
typedef __rvv_int16m1x3_t vint16m1x3_t;
typedef __rvv_uint16m1x3_t vuint16m1x3_t;
typedef __rvv_int16m1x4_t vint16m1x4_t;
typedef __rvv_uint16m1x4_t vuint16m1x4_t;
typedef __rvv_int16m1x5_t vint16m1x5_t;
typedef __rvv_uint16m1x5_t vuint16m1x5_t;
typedef __rvv_int16m1x6_t vint16m1x6_t;
typedef __rvv_uint16m1x6_t vuint16m1x6_t;
typedef __rvv_int16m1x7_t vint16m1x7_t;
typedef __rvv_uint16m1x7_t vuint16m1x7_t;
typedef __rvv_int16m1x8_t vint16m1x8_t;
typedef __rvv_uint16m1x8_t vuint16m1x8_t;
typedef __rvv_int16m2_t vint16m2_t;
typedef __rvv_uint16m2_t vuint16m2_t;
typedef __rvv_int16m2x2_t vint16m2x2_t;
typedef __rvv_uint16m2x2_t vuint16m2x2_t;
typedef __rvv_int16m2x3_t vint16m2x3_t;
typedef __rvv_uint16m2x3_t vuint16m2x3_t;
typedef __rvv_int16m2x4_t vint16m2x4_t;
typedef __rvv_uint16m2x4_t vuint16m2x4_t;
typedef __rvv_int16m4_t vint16m4_t;
typedef __rvv_uint16m4_t vuint16m4_t;
typedef __rvv_int16m4x2_t vint16m4x2_t;
typedef __rvv_uint16m4x2_t vuint16m4x2_t;
typedef __rvv_int16m8_t vint16m8_t;
typedef __rvv_uint16m8_t vuint16m8_t;
typedef __rvv_int32mf2_t vint32mf2_t;
typedef __rvv_uint32mf2_t vuint32mf2_t;
typedef __rvv_int32mf2x2_t vint32mf2x2_t;
typedef __rvv_uint32mf2x2_t vuint32mf2x2_t;
typedef __rvv_int32mf2x3_t vint32mf2x3_t;
typedef __rvv_uint32mf2x3_t vuint32mf2x3_t;
typedef __rvv_int32mf2x4_t vint32mf2x4_t;
typedef __rvv_uint32mf2x4_t vuint32mf2x4_t;
typedef __rvv_int32mf2x5_t vint32mf2x5_t;
typedef __rvv_uint32mf2x5_t vuint32mf2x5_t;
typedef __rvv_int32mf2x6_t vint32mf2x6_t;
typedef __rvv_uint32mf2x6_t vuint32mf2x6_t;
typedef __rvv_int32mf2x7_t vint32mf2x7_t;
typedef __rvv_uint32mf2x7_t vuint32mf2x7_t;
typedef __rvv_int32mf2x8_t vint32mf2x8_t;
typedef __rvv_uint32mf2x8_t vuint32mf2x8_t;
typedef __rvv_int32m1_t vint32m1_t;
typedef __rvv_uint32m1_t vuint32m1_t;
typedef __rvv_int32m1x2_t vint32m1x2_t;
typedef __rvv_uint32m1x2_t vuint32m1x2_t;
typedef __rvv_int32m1x3_t vint32m1x3_t;
typedef __rvv_uint32m1x3_t vuint32m1x3_t;
typedef __rvv_int32m1x4_t vint32m1x4_t;
typedef __rvv_uint32m1x4_t vuint32m1x4_t;
typedef __rvv_int32m1x5_t vint32m1x5_t;
typedef __rvv_uint32m1x5_t vuint32m1x5_t;
typedef __rvv_int32m1x6_t vint32m1x6_t;
typedef __rvv_uint32m1x6_t vuint32m1x6_t;
typedef __rvv_int32m1x7_t vint32m1x7_t;
typedef __rvv_uint32m1x7_t vuint32m1x7_t;
typedef __rvv_int32m1x8_t vint32m1x8_t;
typedef __rvv_uint32m1x8_t vuint32m1x8_t;
typedef __rvv_int32m2_t vint32m2_t;
typedef __rvv_uint32m2_t vuint32m2_t;
typedef __rvv_int32m2x2_t vint32m2x2_t;
typedef __rvv_uint32m2x2_t vuint32m2x2_t;
typedef __rvv_int32m2x3_t vint32m2x3_t;
typedef __rvv_uint32m2x3_t vuint32m2x3_t;
typedef __rvv_int32m2x4_t vint32m2x4_t;
typedef __rvv_uint32m2x4_t vuint32m2x4_t;
typedef __rvv_int32m4_t vint32m4_t;
typedef __rvv_uint32m4_t vuint32m4_t;
typedef __rvv_int32m4x2_t vint32m4x2_t;
typedef __rvv_uint32m4x2_t vuint32m4x2_t;
typedef __rvv_int32m8_t vint32m8_t;
typedef __rvv_uint32m8_t vuint32m8_t;
typedef __rvv_int64m1_t vint64m1_t;
typedef __rvv_uint64m1_t vuint64m1_t;
typedef __rvv_int64m1x2_t vint64m1x2_t;
typedef __rvv_uint64m1x2_t vuint64m1x2_t;
typedef __rvv_int64m1x3_t vint64m1x3_t;
typedef __rvv_uint64m1x3_t vuint64m1x3_t;
typedef __rvv_int64m1x4_t vint64m1x4_t;
typedef __rvv_uint64m1x4_t vuint64m1x4_t;
typedef __rvv_int64m1x5_t vint64m1x5_t;
typedef __rvv_uint64m1x5_t vuint64m1x5_t;
typedef __rvv_int64m1x6_t vint64m1x6_t;
typedef __rvv_uint64m1x6_t vuint64m1x6_t;
typedef __rvv_int64m1x7_t vint64m1x7_t;
typedef __rvv_uint64m1x7_t vuint64m1x7_t;
typedef __rvv_int64m1x8_t vint64m1x8_t;
typedef __rvv_uint64m1x8_t vuint64m1x8_t;
typedef __rvv_int64m2_t vint64m2_t;
typedef __rvv_uint64m2_t vuint64m2_t;
typedef __rvv_int64m2x2_t vint64m2x2_t;
typedef __rvv_uint64m2x2_t vuint64m2x2_t;
typedef __rvv_int64m2x3_t vint64m2x3_t;
typedef __rvv_uint64m2x3_t vuint64m2x3_t;
typedef __rvv_int64m2x4_t vint64m2x4_t;
typedef __rvv_uint64m2x4_t vuint64m2x4_t;
typedef __rvv_int64m4_t vint64m4_t;
typedef __rvv_uint64m4_t vuint64m4_t;
typedef __rvv_int64m4x2_t vint64m4x2_t;
typedef __rvv_uint64m4x2_t vuint64m4x2_t;
typedef __rvv_int64m8_t vint64m8_t;
typedef __rvv_uint64m8_t vuint64m8_t;
typedef __rvv_float16mf4_t vfloat16mf4_t;
typedef __rvv_float16mf4x2_t vfloat16mf4x2_t;
typedef __rvv_float16mf4x3_t vfloat16mf4x3_t;
typedef __rvv_float16mf4x4_t vfloat16mf4x4_t;
typedef __rvv_float16mf4x5_t vfloat16mf4x5_t;
typedef __rvv_float16mf4x6_t vfloat16mf4x6_t;
typedef __rvv_float16mf4x7_t vfloat16mf4x7_t;
typedef __rvv_float16mf4x8_t vfloat16mf4x8_t;
typedef __rvv_float16mf2_t vfloat16mf2_t;
typedef __rvv_float16mf2x2_t vfloat16mf2x2_t;
typedef __rvv_float16mf2x3_t vfloat16mf2x3_t;
typedef __rvv_float16mf2x4_t vfloat16mf2x4_t;
typedef __rvv_float16mf2x5_t vfloat16mf2x5_t;
typedef __rvv_float16mf2x6_t vfloat16mf2x6_t;
typedef __rvv_float16mf2x7_t vfloat16mf2x7_t;
typedef __rvv_float16mf2x8_t vfloat16mf2x8_t;
typedef __rvv_float16m1_t vfloat16m1_t;
typedef __rvv_float16m1x2_t vfloat16m1x2_t;
typedef __rvv_float16m1x3_t vfloat16m1x3_t;
typedef __rvv_float16m1x4_t vfloat16m1x4_t;
typedef __rvv_float16m1x5_t vfloat16m1x5_t;
typedef __rvv_float16m1x6_t vfloat16m1x6_t;
typedef __rvv_float16m1x7_t vfloat16m1x7_t;
typedef __rvv_float16m1x8_t vfloat16m1x8_t;
typedef __rvv_float16m2_t vfloat16m2_t;
typedef __rvv_float16m2x2_t vfloat16m2x2_t;
typedef __rvv_float16m2x3_t vfloat16m2x3_t;
typedef __rvv_float16m2x4_t vfloat16m2x4_t;
typedef __rvv_float16m4_t vfloat16m4_t;
typedef __rvv_float16m4x2_t vfloat16m4x2_t;
typedef __rvv_float16m8_t vfloat16m8_t;
typedef __rvv_float32mf2_t vfloat32mf2_t;
typedef __rvv_float32mf2x2_t vfloat32mf2x2_t;
typedef __rvv_float32mf2x3_t vfloat32mf2x3_t;
typedef __rvv_float32mf2x4_t vfloat32mf2x4_t;
typedef __rvv_float32mf2x5_t vfloat32mf2x5_t;
typedef __rvv_float32mf2x6_t vfloat32mf2x6_t;
typedef __rvv_float32mf2x7_t vfloat32mf2x7_t;
typedef __rvv_float32mf2x8_t vfloat32mf2x8_t;
typedef __rvv_float32m1_t vfloat32m1_t;
typedef __rvv_float32m1x2_t vfloat32m1x2_t;
typedef __rvv_float32m1x3_t vfloat32m1x3_t;
typedef __rvv_float32m1x4_t vfloat32m1x4_t;
typedef __rvv_float32m1x5_t vfloat32m1x5_t;
typedef __rvv_float32m1x6_t vfloat32m1x6_t;
typedef __rvv_float32m1x7_t vfloat32m1x7_t;
typedef __rvv_float32m1x8_t vfloat32m1x8_t;
typedef __rvv_float32m2_t vfloat32m2_t;
typedef __rvv_float32m2x2_t vfloat32m2x2_t;
typedef __rvv_float32m2x3_t vfloat32m2x3_t;
typedef __rvv_float32m2x4_t vfloat32m2x4_t;
typedef __rvv_float32m4_t vfloat32m4_t;
typedef __rvv_float32m4x2_t vfloat32m4x2_t;
typedef __rvv_float32m8_t vfloat32m8_t;
typedef __rvv_float64m1_t vfloat64m1_t;
typedef __rvv_float64m1x2_t vfloat64m1x2_t;
typedef __rvv_float64m1x3_t vfloat64m1x3_t;
typedef __rvv_float64m1x4_t vfloat64m1x4_t;
typedef __rvv_float64m1x5_t vfloat64m1x5_t;
typedef __rvv_float64m1x6_t vfloat64m1x6_t;
typedef __rvv_float64m1x7_t vfloat64m1x7_t;
typedef __rvv_float64m1x8_t vfloat64m1x8_t;
typedef __rvv_float64m2_t vfloat64m2_t;
typedef __rvv_float64m2x2_t vfloat64m2x2_t;
typedef __rvv_float64m2x3_t vfloat64m2x3_t;
typedef __rvv_float64m2x4_t vfloat64m2x4_t;
typedef __rvv_float64m4_t vfloat64m4_t;
typedef __rvv_float64m4x2_t vfloat64m4x2_t;
typedef __rvv_float64m8_t vfloat64m8_t;
#define __riscv_v_intrinsic_overloading 1

#ifdef __cplusplus
}
#endif // __cplusplus
#endif // __RISCV_VECTOR_H
